***********************************************************
* MASTER FILE
**********************************************************

clear all 
set more off 
cap log close 

global pgm /home/group/main/coanpal/private/oecd_lab_mkt_conc/JHR_Replication/pgm 
global logs /home/group/main/coanpal/private/oecd_lab_mkt_conc/JHR_Replication/logs 

log using ${logs}/tracktime.log, text replace     
display "Start Time: $S_TIME  $S_DATE"
log close

* 0. define paths and set seeds
do ${pgm}/AA_define_paths_set_seed.do // declare paths to folders + set seed

* 1A. build cross-walks for municipalities and occupations
do ${pgm}/gen_raccordo_cp_isco.do // cross-walk for occupations >> from cp11 to isco08
do ${pgm}/gen_municipalities.do // cross-walk for municipalities >> from all ever existed to those active in 2019 (Italy's munis have underwent splitting or mergers over time)
* 1B: attach to each municipality its nUTFUA (OECD functional urban area) and FA (functional area: labelled fuax/extended_fua in the code, FA in the paper)
do ${pgm}/gen_NUTS3.do // attach to each muni its NUTS3
do ${pgm}/gen_FUAs.do // attach to each municipality its FUA 
do ${pgm}/gen_extended_FUAs.do // attach to each municipality its FA

* 2. create worker-level datasets 
do ${pgm}/datasetCO_basic_cleaning.do // basic cleaning of raw data, produce starting dataset 
do ${pgm}/datasetCO_identify_new_hires_y.do // identify new hires; main specification: employer=firmXmuni, new hire=year concept
do ${pgm}/datasetCO_gen_chars_new_hires_y.do // gen outcomes for new hires (current, future, past); main specification: employer=firmXmuni, new hire=year concept
do ${pgm}/datasetCO_identify_new_hires_y_firm.do // identify new hires; alternative specification: employer=firm, new hire=year concept
do ${pgm}/datasetCO_gen_chars_new_hires_y_firm.do // gen outcomes for new hires (current, future, past); alternative specification: employer=firm, new hire=year concept
do ${pgm}/datasetCO_identify_new_hires_m12.do // identify new hires; alternative specification: employer=firmXmuni, new hire=month concept
do ${pgm}/datasetCO_gen_chars_new_hires_m12.do // gen outcomes for new hires (current); alternative specification: employer=firmXmuni, new hire=month concept
do ${pgm}/gen_char_lavoratore.do /// gen demographic characteristics of workers (gender, age, place of birth, education, citizenship)

* 3. create LLM (occXgeo)-level dataset 
do ${pgm}/gen_hh_index_new_hire_y.do // gen hh index; main specification: employer=firmXmuni, new hire=year concept; occupation=4 digit  
do ${pgm}/gen_iv_new_hire_y.do // gen standard IV for hh index; main specification: employer=firmXmuni, new hire=year concept; occupation=4 digit 
do ${pgm}/gen_hh_index_new_hire_y_firm.do // gen hh index; alternative specification: employer=firm, new hire=year concept; occupation=4 digit  
do ${pgm}/gen_iv_new_hire_y_firm.do // gen standard IV for hh index; alternative specification: employer=firm, new hire=year concept; occupation=4 digit 
do ${pgm}/gen_hh_index_new_hire_m12.do // gen hh index; alternative specification: employer=firmXmuni, new hire=month concept; occupation=4 digit 
do ${pgm}/gen_hh_index_new_hire_y_occ2d.do // gen hh index; alternative specification: employer=firmXmuni, new hire=year concept; occupation=2 digit
do ${pgm}/gen_iv_new_hire_y_occ2d.do // gen standard IV for hh index; alternative specification: employer=firmXmuni, new hire=year concept; occupation=2 digit
do ${pgm}/gen_iv_new_hire_y_altIV.do // gen alternative IV for hh index; main specification: employer=firmXmuni, new hire=year concept; occupation=4 digit
* notes: hh=herfindalh index of concentration 
*        standard IV= average of leave-one-out (log) of 1/Nfirms across other geo areas in the same occupation-year 
*        alternative IV= average of leave-one-out (log) hh across across other geo areas in the same occupation-year

* 4. carry out descriptive analysis 
do ${pgm}/sum_stat_hh_distribution.do // distribution of weighted hh (mean, sd, percentiles)    
do ${pgm}/sum_stat_workers.do // sum stats on new hires 
do ${pgm}/sum_stat_numbocc.do // sum stats on number of occupations by firm-by-municipality 
do ${pgm}/sum_stat_typecontr_byHH.do // sum stats on new hired on temporary contracts by HH decile 
do ${pgm}/corr_hh_firmXmuni_vs_firm // correlation between (i) hh with employer=firmXmuni and (ii) hh with employer=firm
do ${pgm}/corr_hh_year_vs_month12 // correlation between (i) hh with new hire=year concept and (ii) new hire=month concept 

* 5. run regressions based on the main specification: employer=firmXmuni, new hire=year concept, LLM is FA-by-4digit occupation 
do ${pgm}/rep_run_regressions_main.do // main specification   
do ${pgm}/rep_run_regressions_het_BYAGE.do // heterogeneity by age (young vs non young); FAS only
do ${pgm}/rep_run_regressions_het_BYGENDER.do // heterogeneity by gender; FAS only 
do ${pgm}/rep_run_regressions_het_BYEDU.do // heterogeneity by education (low vs high-definition 1); FAS only
do ${pgm}/rep_run_regressions_het_BYCIT.do // heterogeneity by citizenship (ita vs other); FAS only

do ${pgm}/rep_run_regressions_quasiexogenous.do // calls "${pgm}/quasiex.do" to run Conley et al. Results displayed on screen (and log file); FAS only

*6. run regressions based on alternative specifications 
do ${pgm}/rep_run_regressions_nuts3_fuaX.do // geo=nuts3 or FUAs
do ${pgm}/rep_run_regressions_firm.do // employer=firm; FAS only
do ${pgm}/rep_run_regressions_occ2d.do // occupation=2 digit; FAS only 
do ${pgm}/gen_occupation_shares.do // gen nationwide 4-digit occupation shares among new hires; to be run before "${pgm}/rep_run_regressions_main_share_occ.do" 
do ${pgm}/rep_run_regressions_share_occ.do // additional control: nationwide 4-digit occupation shares; FAS only
do ${pgm}/rep_run_regressions_altIV.do // alternative IV; FAS only
 
cap log close
log using ${logs}/tracktime.log, text append 
display "End Time: $S_TIME  $S_DATE"
log close
