***********************************
* CORRELATION BETWEEN HH INDEXES
* firmXmuni vs firm 
* year concept of hiring
***********************************

clear all 
set more off 
cap log close 

global output ${tab_regressioni} 

local x first 
local g fuaX 
local c 1 
local t 1

* open dataset of HHs based on firmXmuni IDs 
use ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'.dta, clear  
keep `g' contratto_ID_occ_`x'_c anno hh_new_hire tot_new_hire 
rename (hh_new_hire tot_new_hire) (hh_new_hire_firmXmuni tot_new_hire_firmXmuni)

* merge with dataset based on firm ID 
merge 1:1 `g' contratto_ID_occ_`x'_c anno using ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'_firm.dta, keepusing(hh_new_hire tot_new_hire) 
keep if _merge == 3
drop    _merge 
rename (hh_new_hire tot_new_hire) (hh_new_hire_firm tot_new_hire_firm)

* drop markets with missing occupation or geographical area
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')

* log of HH indexes     
gen ln_firmXmuni = ln(hh_new_hire_firmXmuni)
gen ln_firm      = ln(hh_new_hire_firm) 

* correlation coefficient 
gen weights = ""
gen corr    = .
corr ln_firmXmuni ln_firm 
replace corr     = r(rho) in 1 
replace weights  = "Weights: No" in 1
corr ln_firmXmuni ln_firm [aw=tot_new_hire_firm]
replace corr     = r(rho) in 2
replace weights  = "Weights: Yes" in 2
preserve 
keep corr weights 
order weights corr 
keep if corr != .
export excel using "${output}/corr_firmXmuni_vs_firm.xls", sheet("Correlation coeff", replace) keepcellfmt
restore 

*Stata Routine for regression coefficients:
* The data must be by occupation, FUAX and year.
* The data should contain the HHI and the number of hires for each cell
* The HHI should vary between 0 and 1 (divide by 10000 if it varies between 0 and 10000)
* In the next 4 lines, include the name of your variables as indicated
global logHHIf      ln_firm // replace with the varname of the log HHI using firm identifiers
global logHHIfm     ln_firmXmuni // replace with the varname of the log HHI using firmXmunicipality identifiers
global Hires        tot_new_hire_firm // replace with the varname containing the number of new hires per cell (based on firm ids)
global Countryname  "Italy" // replace with the name of your country

label var $logHHIf  "log HHI (based on firm identifiers)"
label var $logHHIfm "log HHI (based on firmXmunicipality identifiers)"
twoway scatter $logHHIfm $logHHIf, msize(tiny) title($Countryname)  scheme(s2color)
graph export "${grafici}/HHIfmHHIf_$Countryname.png", as(png) replace

gen coeff = .
regr $logHHIfm $logHHIf [pw=$Hires]
replace coeff = _b[$logHHIf] in 1
preserve 
keep coeff
keep if coeff != .
export excel using "${output}/corr_firmXmuni_vs_firm.xls", sheet("Regression coeff", replace) keepcellfmt
restore 







