****************************************************
* GEN CURRENT OUTCOMES OF NEW HIRES 
* firmXmuni ID
* month concept of new hires
****************************************************

clear all 
set more off 
cap log close


**-----------------------------------**
** CURRENT SITUATION 
**-----------------------------------**


forvalues y = 2013/2018 {
	global y `y'
	
	di "++++ this is year ${y}"
	
        * extract list of new hires of year $y, at the triple (worker, firm, muni) level  
	gzuse ${dta}/new_hires_m12.dta.gz, clear 
	keep if anno == ${y}
	keep id_lavoratore id_datorelavoro codcomunelavoro19 
	save ${dta}/new_hires${y}_m12.dta, replace // new hires of year $y 
	
	* merge such list to the starting dataset 
	gzuse ${dta}/datasetCO_start.dta.gz, clear

	merge m:1 id_lavoratore id_datorelavoro codcomunelavoro19 using ${dta}/new_hires${y}_m12.dta
	keep if _merge == 3 // keep only triples (worker, firm, muni) where the worker is a new hire in the firmXmuni in year $y 
	drop    _merge 
		
	gen on${y} = year(data_inizio) <= ${y} & year(data_fine) >= ${y} 
	keep if on${y} == 1 // keep only contracts between the worker and the firmXmuni that are active in year $y
	drop on${y}
	
	* flag the FIRST contract between the worker and the firmXmuni active in year $y
        * order contracts by (i) earliest start date; (ii) latest end date 
	* in case of reamining ties, pick one randomly (seeds ensure reproducibility)
	gen     data_fine_fict = data_fine 
        replace data_fine_fict = mdy(12,31,2099) if data_fine_fict == .
	format data_fine_fict %td
        gen     data_fineinv   = - data_fine_fict
	
	duplicates report id_lavoratore id_datorelavoro codcomunelavoro19 data_inizio data_fineinv random
	bys id_lavoratore id_datorelavoro codcomunelavoro19 (data_inizio data_fineinv random): gen n = _n 
	gen first_contract = (n == 1)
		
	* number of days worked at the firmXmuni in year $y  
        bys id_lavoratore id_datorelavoro codcomunelavoro19: gen N=_N
	
	* group 1: workers with just one contract with the firmXmuni active in year $y 
	preserve 
	keep if N == 1 
	gen tenure_c = min(data_fine, mdy(12,31,${y}))-max(data_inizio, mdy(1,1,${y})) + 1 
	drop N 
	save ${dta}/group1_m.dta, replace 
	restore
	
	di "count #1"
	count 
	
	* group 2: workers with more than one contract with the firmXmuni active in year $y: procedure to avoid double-counting in case of overlapping spells 
	drop if N == 1
	local i = mdy(1,1,${y})
        local f = mdy(12,31,${y})
        forvalues d = `i'/`f' {
  	   gen temp = data_inizio <= `d' & data_fine >= `d' // contract is active in day `d' of year $y
	   bys id_lavoratore id_datorelavoro codcomunelavoro19: egen on_day`d' = max(temp) // max() to avoide double-counting of days if a worker holds two contracts with the firmXmuni in day `d'
	   drop temp  
        }
	egen tenure_c = rowtotal(on_day*)
	drop on_day* 
	drop N 
	append using ${dta}/group1_m.dta
	rm  ${dta}/group1_m.dta
	
	di "count #2"
	count 
	
	* keep one row per triple (worker, firm, muni) that records: (a) attributes of the first contract; (b) total number of days worked across all contracts 
	keep if first_contract == 1
	rename data_inizio        contratto_ID_start_first_c
	rename data_fine          contratto_ID_end_first_c
	rename data_trasf         contratto_ID_tra_first_c
	format contratto_ID_start_first_c contratto_ID_end_first_c contratto_ID_tra_first_c %td
	
	replace codtipocontratto = subinstr(codtipocontratto,".","",.)
	replace codtipocontratto = subinstr(codtipocontratto,"0","",.)
	rename codtipocontratto   contratto_ID_tipo_first_c
	rename codtipoorario      contratto_ID_orario_first_c 
	replace codsettore       = subinstr(codsettore,".","",.)
	rename codsettore         contratto_ID_sec_first_c 
	rename isco08_4d          contratto_ID_occ_first_c
		
        * keep only relevant variables 
        keep id_lavoratore id_datorelavoro codcomunelavoro19 tenure_c contratto_ID_*_first_c
	gen anno = ${y}
	
	gzsave ${dta}/new_hires${y}_m12_current_situation.dta.gz, replace 
  
  
        
}
	
	
***--------------------------------------------***
*** FINAL MERGE AND APPEND  
***--------------------------------------------***
 
gzuse ${dta}/new_hires2013_m12_current_situation.dta.gz, clear
forvalues y = 2014/2018 {
	global y `y'
	gzappend using ${dta}/new_hires${y}_m12_current_situation.dta.gz 
} 
 

save ${dta}/dataset_new_hires_m12.dta, replace 

** erase intermediate files 

forvalues y = 2013/2018 {
	global y `y'
	cap rm ${dta}/new_hires${y}_m12_current_situation.dta.gz 
}
	
	
	
	
	
	

