****************************************************
* GEN CURRENT, PAST AND FUTURE OUTCOMES OF NEW HIRES 
* firm ID
* year concept of new hires
****************************************************

clear all 
set more off 
cap log close


**-----------------------------------**
** CURRENT SITUATION 
**-----------------------------------**


forvalues y = 2013/2018 {
	global y `y'
        
	di "++++This is year ${y}++++"
	* extract list of new hires of year $y, at the couple (worker, firm) level  
	gzuse ${dta}/new_hires_y_firm.dta.gz, clear 
	keep if anno == ${y}
	keep id_lavoratore id_datorelavoro
	save ${dta}/new_hires${y}_y_firm.dta, replace // new hires of year $y 
	
	* merge such list to the starting dataset 
	gzuse ${dta}/datasetCO_start.dta.gz, clear

	merge m:1 id_lavoratore id_datorelavoro using ${dta}/new_hires${y}_y_firm.dta
	keep if _merge == 3 // keep only couples (worker, firm) where the worker is a new hire in the firm in year $y 
	drop    _merge 
		
	gen on${y} = year(data_inizio) <= ${y} & year(data_fine) >= ${y} 
	keep if on${y} == 1 // keep only contracts between the worker and the firm that are active in year $y
	drop on${y}
	
	* flag the FIRST contract between the worker and the firm active in year $y
        * order contracts by (i) earliest start date; (ii) latest end date 
	* in case of reamining ties, pick one randomly (seeds ensure reproducibility)
	gen     data_fine_fict = data_fine 
        replace data_fine_fict = mdy(12,31,2099) if data_fine_fict == .
	format data_fine_fict %td
        gen     data_fineinv   = - data_fine_fict
	
	duplicates report id_lavoratore id_datorelavoro data_inizio data_fineinv random
	bys id_lavoratore id_datorelavoro (data_inizio data_fineinv random): gen n = _n 
	gen first_contract = (n == 1)
		
	* number of days worked at the firm in year $y
	bys id_lavoratore id_datorelavoro: gen N=_N
	
	* group 1: workers with just one contract with the firm active in year $y 
	preserve 
	keep if N == 1 
	gen tenure_c = min(data_fine, mdy(12,31,${y}))-max(data_inizio, mdy(1,1,${y})) + 1 
	drop N 
	save ${dta}/group1_y_firm.dta, replace 
	restore 
	
	di "count #1"
	count 
	
	* group 2: workers with more than one contract with the firm active in year $y: procedure to avoid double-counting in case of overlapping spells 
	drop if N == 1
	local i = mdy(1,1,${y})
        local f = mdy(12,31,${y})
        forvalues d = `i'/`f' {
  	   gen temp = data_inizio <= `d' & data_fine >= `d' // contract is active in day `d' of year $y
	   bys id_lavoratore id_datorelavoro: egen on_day`d' = max(temp) // max() to avoide double-counting of days if a worker holds two contracts with the firm in day `d'
	   drop temp  
        }
	egen tenure_c = rowtotal(on_day*)
	drop on_day*
	drop N 
	append using ${dta}/group1_y_firm.dta
	rm  ${dta}/group1_y_firm.dta
	
	di "count #2"
	count 
	
	* keep one row per couple (worker, firm) that records: (a) attributes of the first contract; (b) total number of days worked across all contracts 
	keep if first_contract == 1
	rename data_inizio        contratto_ID_start_first_c
	rename data_fine          contratto_ID_end_first_c
	rename data_trasf         contratto_ID_tra_first_c
	format contratto_ID_start_first_c contratto_ID_end_first_c contratto_ID_tra_first_c %td
	
	replace codtipocontratto = subinstr(codtipocontratto,".","",.)
	replace codtipocontratto = subinstr(codtipocontratto,"0","",.)
	rename codtipocontratto   contratto_ID_tipo_first_c
	rename codtipoorario      contratto_ID_orario_first_c 
	replace codsettore       = subinstr(codsettore,".","",.)
	rename codsettore         contratto_ID_sec_first_c 
	rename isco08_4d          contratto_ID_occ_first_c
	rename codcomunelavoro19  contratto_ID_comune_first_c
	
	
        * keep only relevant variables 
        keep id_lavoratore id_datorelavoro tenure_c contratto_ID_*_first_c
	gen anno = ${y}
	
	gzsave ${dta}/new_hires${y}_y_firm_current_situation.dta.gz, replace 
  
  
        
}
	
	
 	
	
**---------------------------------**
** FUTURE SITUATION  
**---------------------------------**

* NB: future (y+1) info is not available for new hires of 2018 (since we do not have data on 2019)
* hence, the loop runs over 2013-2017 
forvalues y = 2013/2017 {
	global y  `y'
	global yf = ${y}+1
	
	di "++++ current year is ${y}, future year is ${yf}"
	
	* extract list of new hires of year $y at the couple (worker, firm) level
	gzuse ${dta}/new_hires_y_firm.dta.gz, clear 
	keep if anno == ${y}
	keep id_lavoratore id_datorelavoro 
	save ${dta}/new_hires${y}_y_firm.dta, replace // new hires of year $y 
	
	* merge such list to the starting dataset 
	gzuse ${dta}/datasetCO_start.dta.gz, clear

	merge m:1 id_lavoratore id_datorelavoro using ${dta}/new_hires${y}_y_firm.dta
	keep if _merge == 3 // keep only couples (worker, firm) where the worker is a new hire in the firm in year $y 
	drop    _merge 
		
	gen on${yf} = year(data_inizio) <= ${yf} & year(data_fine) >= ${yf} 
	d on${yf}
	keep if on${yf} == 1 // keep only contracts between the worker and the firm that are active in year $yf = $y + 1
	drop on${yf}
	
	gen temp=year(data_inizio)
	ta temp 
	drop temp 
	gen temp=year(data_fine)
	ta temp 
	drop temp 
	
	* transformed = 1 if one across all contracts active in year $yf between the worker and the firm is trasformed by the end of year $yf 
	 gen temp =(data_trasf<=mdy(12,31,${yf}))
	 sum data_trasf if temp==1
         bys id_lavoratore id_datorelavoro: egen trasformed = max(temp)
         drop temp
	 
	 * conv_by_next_year = 1 if either trasformed = 1 or the worker has with the firm a contract that starts in year $yf and is permanent 
	 gen     conv_by_next_year = 0 
	 replace conv_by_next_year = 1 if conv_by_next_year == 0 & trasformed == 1 
	 replace codtipocontratto = subinstr(codtipocontratto,".","",.)
         replace codtipocontratto = subinstr(codtipocontratto,"0","",.)
         gen temp = (codtipocontratto == "A1") if codtipocontratto != ""
	 table codtipocontratto, stat(mean temp)
         bys id_lavoratore id_datorelavoro: egen temp2 = max(temp)
         drop temp 
         replace conv_by_next_year = 1 if conv_by_next_year == 0 & temp2 == 1
         drop temp2 
	 
         * number of days worked at the firm in year $yf 
	 bys id_lavoratore id_datorelavoro : gen N=_N
	 
	 * group 1: workers with just one contract with the firm active in year $y 
	 preserve 
	 keep if N == 1 
	 gen tenure_f = min(data_fine, mdy(12,31,${yf}))-max(data_inizio, mdy(1,1,${yf})) + 1 
	 drop N 
	 save ${dta}/group1_y_firm.dta, replace 
	 restore 
	 
	 di "count #1"
	 count 
	
	* group 2: workers with more than one contract with the firm active in year $y: procedure to avoid double-counting in case of overlapping spells 
	 drop if N == 1
	 local if = mdy(1,1,${yf}) // first day of year $yf 
         local ff = mdy(12,31,${yf}) // last day of year $yf
	 
         forvalues d = `if'/`ff' {
  	    gen temp = data_inizio <= `d' & data_fine >= `d' // contract is active in day `d' of year $y
	    bys id_lavoratore id_datorelavoro: egen on_day`d' = max(temp) // max() to avoide double-counting of days if a worker holds two contracts with the firm in day `d'
	    drop temp  
         }
	 egen tenure_f = rowtotal(on_day*)
	 drop on_day* 
	 drop N 
	 append using ${dta}/group1_y_firm.dta
	 rm ${dta}/group1_y_firm.dta
	 
	 di "count #2"
	 count 

         *keep one record for the couple (worker, firm) which records: (a) number of days worked across all contracts in year $yf; (b) trasformed, conv_by_next_year   
	 duplicates drop id_lavoratore id_datorelavoro, force 
         keep id_lavoratore id_datorelavoro tenure_f trasformed conv_by_next_year 
	 
	 *merge again with list of new hires in year $y 
	 merge 1:1 id_lavoratore id_datorelavoro using ${dta}/new_hires${y}_y_firm.dta
	 * records with _merge == 2 are workers who have NO contracts active with the firm in year $yf 
	 replace tenure_f          = 0 if _merge == 2 
	 replace trasformed        = 0 if _merge == 2 
	 replace conv_by_next_year = 0 if _merge == 2
	 drop _merge 
	 
	 gen anno = ${y}
	 
         gzsave ${dta}/new_hires${y}_y_firm_future_situation.dta.gz, replace
	 
}



**---------------------------------**
** PAST SITUATION 
**---------------------------------**	


forvalues y = 2013/2018 {
        global y  `y'
	global yp = ${y}-1
	
	di "++++ current year is ${y}, past year is ${yp}"
	
	* extract list of new hires of year $y   
	gzuse ${dta}/new_hires_y_firm.dta.gz, clear 
	keep if anno == ${y}
	* at the couple (worker, firm) level 
	keep id_lavoratore id_datorelavoro
	save ${dta}/new_hires${y}_y_firm.dta, replace // new hires of year $y
	* at the WORKER level
	duplicates drop id_lavoratore, force 
	keep id_lavoratore  
	save ${dta}/new_hires${y}_y_firm_lav.dta, replace // new hires of year $y
	
	* merge such list to the starting dataset 
	gzuse ${dta}/datasetCO_start.dta.gz, clear

	merge m:1 id_lavoratore using ${dta}/new_hires${y}_y_firm_lav.dta
	keep if _merge == 3 // keep only workers who are new hires in year $y 
	drop _merge 
	rm ${dta}/new_hires${y}_y_firm_lav.dta
	
	gen on${yp} = year(data_inizio) <= ${yp} & year(data_fine) >= ${yp} 
	d on${yp}
	keep if on${yp} == 1 // keep only contracts of workers hired in year $y that were active in year $yp=$y-1 
	drop on${yp}
	
	* keep one observation per worker 
	duplicates drop id_lavoratore, force  
	* empl_past_year = 1 if a worker hired in year $y had a contract active in year $yp=$y-1
	* by definition of new hire, such contracts are with firm different from that(those) that hired the worker in year $y
        gen empl_past_year = 1 
	keep id_lavoratore empl_past_year
	
	* merge again with the new hire list 
	merge 1:m id_lavoratore using  ${dta}/new_hires${y}_y_firm.dta
	
	* records with _merge == 2 are workers who have NO contract active in year $yp 
	replace empl_past_year = 0 if _merge == 2 
	drop _merge
	
	* keep relevant variables
	keep id_lavoratore id_datorelavoro empl_past_year  
	gen anno = ${y}
	
	gzsave ${dta}/new_hires${y}_y_firm_past_situation.dta.gz, replace
	
}




	
	
***--------------------------------------------***
*** FINAL MERGE AND APPEND  
***--------------------------------------------***

* current 
gzuse ${dta}/new_hires2013_y_firm_current_situation.dta.gz, clear
forvalues y = 2014/2018 {
	global y `y'
	gzappend using ${dta}/new_hires${y}_y_firm_current_situation.dta.gz 
} 
save ${dta}/new_hires_y_firm_current_situation.dta, replace 

* future 
gzuse ${dta}/new_hires2013_y_firm_future_situation.dta.gz, clear
forvalues y = 2014/2017 {
	global y `y'
	gzappend using ${dta}/new_hires${y}_y_firm_future_situation.dta.gz 
} 
save ${dta}/new_hires_y_firm_future_situation.dta, replace 

* past 
gzuse ${dta}/new_hires2013_y_firm_past_situation.dta.gz, clear
forvalues y = 2014/2018 {
	global y `y'
	gzappend using ${dta}/new_hires${y}_y_firm_past_situation.dta.gz 
} 
save ${dta}/new_hires_y_firm_past_situation.dta, replace

* merge current, future, past  	
use ${dta}/new_hires_y_firm_current_situation.dta, clear 
rm ${dta}/new_hires_y_firm_current_situation.dta
merge 1:1 anno id_lavoratore id_datorelavoro using ${dta}/new_hires_y_firm_future_situation.dta
drop _merge 
rm ${dta}/new_hires_y_firm_future_situation.dta
merge 1:1 anno id_lavoratore id_datorelavoro using ${dta}/new_hires_y_firm_past_situation.dta
drop _merge 
rm ${dta}/new_hires_y_firm_past_situation.dta 
save ${dta}/dataset_new_hires_y_firm.dta, replace 

* erase intermediate files

forvalues y = 2013/2018 {
	global y `y'
	cap rm ${dta}/new_hires${y}_y_firm_current_situation.dta.gz 
	cap rm ${dta}/new_hires${y}_y_firm_future_situation.dta.gz
	cap rm ${dta}/new_hires${y}_y_firm_past_situation.dta.gz
}	
	
	
	
	

