***********************
* GEN CHAR LAVORATORE
***********************

clear all 
set more off
cap log close 

gzuse ${dati}/CO_SOMM_II_2019_BDI.dta.gz, clear

keep id_lavoratore codgenere datanascitalavoratore codtitolostudio codcittadinanza

encode codtitolostudio, gen(temp)
bys id_lavoratore: egen min = min(temp)
bys id_lavoratore: egen max = max(temp)
count if min!= max // codtitolostudio è invariante within lavoratore 
drop temp min max 
bys id_lavoratore: egen sd = sd(codcittadinanza)
sum sd // cittadinanza è invariante within lavoratore 
 

bys id_lavoratore: gen n=_n 
keep if n == 1 // keep one record for each worker 


gen data_nascita = date(datanascitalavoratore,"MDY")
format data_nascita %td
gen anno_nascita = year(data_nascita)

gen donna = (codgenere == "F") if codgenere != ""

gen citita = (codcittadinanza == 0) if codcittadinanza != .

** NB: codtitolostudio = "00" should refer to people with no education; 
** however, the incidence is so high, even among young people, that more likely refer to people with missing info
** hence I put these people into the category "Not available"
replace codtitolostudio = trim(codtitolostudio)
gen     edu = 0 if codtitolostudio == "00" | codtitolostudio == "N." 
replace edu = 1 if codtitolostudio == "10"
replace edu = 2 if codtitolostudio == "20"
replace edu = 3 if codtitolostudio == "30"
replace edu = 4 if codtitolostudio == "40"
replace edu = 5 if codtitolostudio == "50" | codtitolostudio == "60" | codtitolostudio == "70" | ///
                   codtitolostudio == "71" | codtitolostudio == "72" | codtitolostudio == "73" | codtitolostudio == "74"
replace edu = 6 if codtitolostudio == "80" | codtitolostudio == "81" | codtitolostudio == "83" | codtitolostudio == "90"		
label define edu 0 "No title/not available" 1 "None/primary" 2 "Lower secondary" 3 "Upper secondary - 3-year diploma" 4 "Upper secondary - 5-year diploma" /// 
                 5 "Tertiary" 6 "Post-tertiary"
label values edu edu

recode edu (1 2=1 "Less than upper secondary") (3 4=2 "Upper secondary") (5 6=3 "Tertiary") (0=4 "Not available"), gen(edu_3cat)



keep id_lavoratore donna anno_nascita edu_3cat citita  
 
save ${dta}/lavoratori_char_invarianti.dta, replace 
