********************************
* GEN HH INDEX 
* firm ID
* month concept of hiring
********************************

clear all 
set more off 
cap log close 


use ${dta}/dataset_new_hires_m12.dta, clear

gen new_hire = 1

** step 0: merge info about geographical area

rename codcomunelavoro19 codice_comune_belfiore2019

merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_extended_fua_comuni_2019.dta, keepusing(extended_fua) // extended FUAs
drop if _merge == 2 
drop    _merge

rename codice_comune_belfiore2019 codcomunelavoro19

rename (extended_fua) (fuaX)

local x first 

** step 1: apply filters  

** 1. focus on 05-82, 90, 92-96 sectors

gen temp = real(substr(contratto_ID_sec_`x'_c,1,2))
keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96)
ta temp  
drop temp 
 
** 2. keep only permanent, temporary and apprentice contracts 
 gen temp = substr(contratto_ID_tipo_`x'_c,1,2)
 drop if temp != "A1" & temp != "A2" & temp != "A3" // drop all contracts different from the standard permanent, fixed-term and apprentice ones 
 drop temp 
 ta contratto_ID_tipo_`x'_c
 

** 3. keep only workers with short tenure 

 drop if tenure_c < 28 // we use 28 because it is the minimum number of days in a month
 sum tenure_c
 

** step 2: collapse hiring at the yearXfirmXmuniXoccupation level
local g fuaX 
local x first

* drop markets with missing occupation or geographical areas
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')	 	 
	
collapse (sum)  new_hire /// 
         (first) `g', ///
 	 by(anno id_datorelavoro codcomunelavoro19 contratto_ID_occ_`x'_c)
 
** step 3: compute HH index at the LLM(i.e.geoXocc)-by-year level 

bys anno contratto_ID_occ_`x'_c `g': egen tot_new_hire = total(new_hire) // total new hires in the LLM
gen sh_new_hire  = new_hire/tot_new_hire // share of new hire accruing to each firmXmuni 
gen sh2_new_hire = sh_new_hire^2 // square of the share of new hire accruing to each firmXmuni 
bys anno contratto_ID_occ_`x'_c `g': gen Nfirms = _N // number of hiring firms
hhi new_hire, by(anno contratto_ID_occ_`x'_c `g') // user-written command to compute HH - I use it to double check that I have computed it right by hand

collapse (sum)   hh = sh2_new_hire ///
         (first) hhi_new_hire tot_new_hire Nfirms, ///
	 by(anno contratto_ID_occ_`x'_c `g')
rename hh           hh_new_hire 
rename hhi_new_hire hh_new_hire_stata_cmd

 
save ${dta}/hh_index_contratto_`x'_`g'_tipo1_tenure1_month12.dta, replace // save the dataset at the LLM-by-year level 








