********************************
* GEN HH INDEX 
* firmXmuni ID 
* year concept of hiring
********************************

clear all 
set more off 
cap log close 


**
use ${dta}/dataset_new_hires_y.dta, clear

gen new_hire = 1

** step 0: merge info about geographical area
 
rename codcomunelavoro19 codice_comune_belfiore2019

merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_nuts3_2019.dta, keepusing(sigla_prov2019) // nuts3
drop if _merge == 2 
drop    _merge 

merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_fua_comuni_2019.dta, keepusing(cod_fua) // FUAs
drop if _merge == 2 
drop    _merge

merge m:1 codice_comune_belfiore2019 using ${dta}/elenco_extended_fua_comuni_2019.dta, keepusing(extended_fua) // extended FUAs
drop if _merge == 2 
drop    _merge

rename codice_comune_belfiore2019 codcomunelavoro19

rename (sigla_prov2019 cod_fua extended_fua) (nuts3 fua fuaX)

** step 1. apply filters 

** 1. focus on 05-82, 90, 92-96 sectors
 gen temp = real(substr(contratto_ID_sec_first_c,1,2))
 keep if (temp >= 5 & temp <= 82) | temp == 90 | (temp >= 92 & temp <= 96) 
 ta temp 
 drop temp
 
** 2. keep only permanent, temporary and apprenticeship contracts 
 gen temp = substr(contratto_ID_tipo_first_c,1,2)
 drop if temp != "A1" & temp != "A2" & temp != "A3" // drop all contracts different from the standard permanent, fixed-term and apprentice ones 
 drop temp 
 ta contratto_ID_tipo_first_c
 

** 3. drop workers with short tenure 
 drop if tenure_c < 28 // we use 28 because it is the minimum number of days in a month
 sum tenure_c 


local geo fua fuaX nuts3
foreach g of local geo {

preserve 
local x first 
** step 2: collapse hiring at the yearXfirmXmuniXocc level (`g' is invariant within firmXmuni)

* drop markets where we miss either the occupation or the geographical areas 	 
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')	 

collapse (sum)   new_hire /// 
         (first) `g', ///
	 by(anno id_datorelavoro codcomunelavoro19 contratto_ID_occ_`x'_c)
	 
** step 3: compute HH index at the LLM (i.e.geoXocc) level 

bys anno contratto_ID_occ_`x'_c `g': egen tot_new_hire = total(new_hire) // total new hires in the LLM-year
gen sh_new_hire  = new_hire/tot_new_hire // share of new hire accruing to each firmXmuni in the LLM-year 
gen sh2_new_hire = sh_new_hire^2 // square of the share of new hire accruing to each firmXmuni in the LLM-year 
bys anno contratto_ID_occ_`x'_c `g': gen Nfirms = _N // number of hiring firmXmuni in the LLM-year 

hhi new_hire, by(anno contratto_ID_occ_`x'_c `g') // user-written command to compute HH - I use it to double check that I have computed it right by hand

collapse (sum)   hh = sh2_new_hire ///
         (first) hhi_new_hire tot_new_hire Nfirms, ///
	 by(anno contratto_ID_occ_`x'_c `g')
rename hh hh_new_hire 
rename hhi_new_hire hh_new_hire_stata_cmd

save ${dta}/hh_index_contratto_`x'_`g'_tipo1_tenure1.dta, replace // save the dataset at the LLM level 
restore 

}



