
/*
* The data are those of your regression sample.
* In the next 3 lines, include the name of your variables as indicated
global Dvar XX // replace XX with the varname of your dependent variable
global LHHI YY // replace YY with the varname of the log HHI
global IV WW // replace WW with the varname of the (log) IV
global fixed "FF" // replace FF with the list of your covariates
global cluster "CC" // replace CC with the variable containing the cluster dimensions
* e.g. in FRA (wage reg.) global fixed = "id occ#geo firm#mun#an firm#nic age ftpt Hire Emp1y"
* Your baseline specification (the one in the main tables) should be, therefore, of the type:
* ivreghdfe $Dvar ( $LHHI = $IV), absorb($fixed)  cluster($cluster)
*/


* reduced form
reghdfe $Dvar $IV, abs($fixed) cluster($cluster)

* derive minimum notional gamma (the one of the reduced form) 
global G = _b[ $IV ]
global seG = _se[ $IV ]

* partialling out key variables
keep if $Dvar !=.& $LHHI !=.& $IV !=.
reghdfe $Dvar , abs($fixed) residuals(Dvar_e)
reghdfe $LHHI , abs($fixed) residuals(lhhi_e)
reghdfe $IV , abs($fixed) residuals(IV_e)

* using plausexog to quickly find a candidate for the minimum gamma for which beta is still significant
scalar max = 0
local n = 0
while `n'>$G { 
local n = `n'+ ($G / 30) 
disp in red `n'
plausexog uci Dvar_e (lhhi_e = IV_e), gmin(`n') gmax(0) level(0.90) vce(cluster $cluster)
scalar ub = e(ub_lhhi_e)
scalar max1 = max
scalar max = `n'
if ub>0 {
	local n = $G - 1
	}
}	

disp ub
disp max1

* refining the search for the minimum gamma for which beta is still significant
ge Y1=.
local n = max1
while `n'<0 {
disp "gamma = " `n'
replace Y1=$Dvar -( $IV * `n')
ivreghdfe Y1 ( $LHHI = $IV), abs($fixed) level(90) cluster($cluster)
scalar ub = _b[ $LHHI ]+1.64*_se[ $LHHI ]
scalar gmin = `n'
*disp "min gamma = " gmin 
if ub<0 {
	local n = 1
	}
local n=`n' - ($G / 30)
}

* output for the table
disp "reduced form gamma = " $G // to be reported in row (1)
disp "standard error of reduced form gamma = " $seG // to be reported in row (1) below the gamma
disp "min gamma = " gmin // to be reported in row (2)
