**********************************
* SUM STAT HH INDEX 
**********************************

clear all 
set more off 
cap log close 

global output ${tab_sumstat}

local x first 
local g fuaX 
local c 1 
local t 1

****************************************
* MAIN SPECIFICATION: FIRMxMUNI ID
****************************************

use ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'.dta, replace
* drop markets with missing occupation or geographic area
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')

*Stata Routine:
* The data must be by occupation, FUAX and year.
* The data should contain the HHIs and the number of hires for each cell
* The HHI should vary between 0 and 1 (divide by 10000 if it varies between 0 and 10000)
* In the next 2 lines, include the name of your variables as indicated

global HHI   hh_new_hire // replace with the varname of the HHI
global Hires tot_new_hire // replace with the varname containing the number of new hires

gen     stat  = "mean" in 1 
replace stat  = "sd"   in 2 
replace stat  = "p25"  in 3
replace stat  = "p50"  in 4 
replace stat  = "p75"  in 5
replace stat  = "p90"  in 6
gen     value = .

sum $HHI [w=$Hires] if $HHI!=0&$HHI!=., detail
replace value = `r(mean)' in 1 
replace value = `r(sd)'   in 2
replace value = `r(p25)'  in 3
replace value = `r(p50)'  in 4
replace value = `r(p75)'  in 5
replace value = `r(p90)'  in 6 

preserve 
keep stat value 
keep if value != .
export excel ${output}/hh_index_distribution.xlsx, firstrow(var) sheet("FirmXmuni", replace)  keepcellfmt
restore 


****************************************
* MAIN SPECIFICATION: FIRM
****************************************
use ${dta}/hh_index_contratto_`x'_`g'_tipo`c'_tenure`t'_firm.dta, replace
* drop markets with missing occupation or geographic area
drop if mi(contratto_ID_occ_`x'_c) | mi(`g')

*Stata Routine:
* The data must be by occupation, FUAX and year.
* The data should contain the HHIs and the number of hires for each cell
* The HHI should vary between 0 and 1 (divide by 10000 if it varies between 0 and 10000)
* In the next 2 lines, include the name of your variables as indicated

global HHI   hh_new_hire // replace with the varname of the HHI
global Hires tot_new_hire // replace with the varname containing the number of new hires

gen     stat = "mean" in 1 
replace stat = "sd"   in 2 
replace stat = "p25"  in 3
replace stat = "p50"  in 4 
replace stat = "p75"  in 5
replace stat = "p90"  in 6
gen value = .

sum $HHI [w=$Hires] if $HHI!=0&$HHI!=., detail
replace value = `r(mean)' in 1 
replace value = `r(sd)'   in 2
replace value = `r(p25)'  in 3
replace value = `r(p50)'  in 4
replace value = `r(p75)'  in 5
replace value = `r(p90)'  in 6

preserve 
keep stat value 
keep if value != .
export excel ${output}/hh_index_distribution.xlsx, firstrow(var) sheet("Firm", replace)  keepcellfmt
restore 


