*THIS CODE:

*[1] OPENS THE PANEL DATASET "IDANUPD" (AVAILABLE FROM STATISTICS DENMARK) AND CREATES INDIVIDUAL FILES FOR EACH YEAR;
*[2] MERGES DATA ON GEOGRAPHICAL AREAS AVAILABLE FROM THE OECD (list_of_municipalities_in_functional_urban_areas.xlsx and nuts3.csv), AND STATISTICS DENMARK (dar.dta);
*[3] MERGES DATA FROM THE DATASETS "IDAPUPD" AND "IDASUPD" (AVAILABLE FROM STATISTICS DENMARK);
*[4] PRODUCES idanupd10-18.dta, YEAR-SPECIFIC DATASETS TO BE USED LATER IN THE ANALYSIS;
*[5] APPENDS THE DATASETS IN [4] TO CREATE A NEW PANEL SUITABLE FOR THE ANALYSIS (idanupd9_18.dta).

*IDANUPD
use "idanupd.dta", clear
preserve
keep if idanupdsourceyear == 2009
compress
save idanupd_9, replace
restore
forval x = 10(1)18 {
preserve
keep if idanupdsourceyear == 20`x'
compress
save idanupd_`x', replace
restore
}

*IDAPUPD
use "idapupd.dta", clear
forval x = 2009(1)2018 {
preserve
keep if idapupdsourceyear == `x'
compress
save idapupd_`x', replace
restore
}

*IDASUPD
use "idasupd01.dta", clear
preserve
keep if idasupd01sourceyear == 2009
compress
save idasupd01_9, replace
restore
forval x = 10(1)18 {
preserve
keep if idasupd01sourceyear == 20`x'
compress
save idasupd01_`x', replace
restore
}

import excel "list_of_municipalities_in_functional_urban_areas.xlsx", sheet("List of municipalities") firstrow case(lower) clear
keep if iso3 == "DNK"
keep core1 functionalurbanareaid functionalurbanareaname municipalityname municipalityname municipalityid municipalityoecdid
rename functionalurbanareaid codefua
rename functionalurbanareaname fuaname
rename municipalityname sognenavnoecd
rename municipalityid sognekode 
gen fua=real(substr(codefua, 3, 3))
sort sognekode 
duplicates drop codefua fuaname sognekode, force
tempfile fua
save `fua', replace

import delimited "nuts3.csv", clear
tostring kom nuts3, replace
tempfile nuts3
sort kom
save `nuts3', replace

use "dar.dta", clear
duplicates drop sognekode, force
sort kom
merge m:1 kom using `nuts3'
rename nuts3 dep
drop if _merge == 2
drop _merge

merge 1:1 sognekode using `fua'
drop if _merge == 2
drop _merge

*fua1: real FUA only
gen fua1 = codefua
tab fua1, missing
egen minfua = min(fua), by(dep)

*fua2: also NUTS3 regions where no municipality is part of a FUA
gen fua2 = codefua
replace fua2 = dep if fua == . & minfua == .
tab fua2, missing

*fua4 minimalist approach: NUTS3 regions, where those that are entirely part of the same real FUA are merged together
gen du = (fua2!="")
egen mindu=min(du), by(dep)

preserve
collapse fua, by(codefua dep)
collapse (count) countfua = fua, by(dep)
sort dep
save temp, replace
restore
sort dep
merge m:1 dep using temp
drop _merge
erase temp.dta

gen fua4 = fua2 if countfua == 1|countfua==0
replace fua4=dep if mindu == 0
tab fua4, missing

*fua0: FUAs + rest of NUTS3
gen fua0 = fua2
replace fua0 = dep if fua0 == ""
tab fua0, missing

*fuaX: FUAs + rest of NUTS3 if covering at least XX% of municipalities (Extended FUAs)
egen ratiocomfua=mean(du), by(dep)
gen fuaX = fua2
replace fuaX = dep if fuaX == "" & ratiocomfua <.3
tab fuaX, missing

keep sognekode fu*
sort sognekode
tempfile fuas
save `fuas', replace

gen pi = 1
collapse pi, by(fua1 fua2 fuaX)
drop pi
sort fuaX
save nested_fua, replace

use "dar.dta", clear
keep kom opgikom sognekode
duplicates drop kom opgikom, force
tempfile dar
sort kom opgikom
save `dar', replace


forval year = 9(1)18 {
*foreach year in 9 {
	
if `year' == 9 {
use "idapupd_200`year'.dta"
} 
else {
use "idapupd_20`year'.dta"
}

keep pnr aldernov*
tempfile idapupd
duplicates drop pnr, force
sort pnr
save `idapupd', replace

use "idasupd01_`year'.dta" 
keep lbnr kom opgikom
tempfile idasupd01
sort lbnr
save `idasupd01', replace

use "idanupd_`year'.dta", clear
sort lbnr
merge m:1 lbnr using `idasupd01', update
drop if _merge == 2
drop _merge

sort kom
merge m:1 kom using `nuts3'
rename nuts3 dep
drop _merge

sort kom opgikom
merge m:1 kom opgikom using `dar', update
drop if _merge == 2
drop _merge

sort sognekode
merge m:1 sognekode using `fuas'
drop if _merge == 2
drop _merge

drop fua0

sort pnr
merge m:1 pnr using `idapupd'
drop if _merge == 2
drop _merge

destring idanupdsourceyear, replace
destring ansaar, replace
replace ansaar = ansaar - 2000
gen ar = idanupdsourceyear - 2000
rename cvrnr cvr

tostring kom, replace

tostring cvr, replace

tostring sognekode, replace

gen komcvr = kom + cvr
compress

gen sognecvr = sognekode + cvr
compress

compress
save idanupd`year'.dta, replace
}

*Share of business sector in each occupation at the national X year level

clear
gen year = ""
save HHI\bs_pcs4, replace

foreach year in 9 10 11 12 13 14 15 16 17 18 {
	
	use idanupd`year'.dta, clear
	
	*drop non employees
	*DROP THE SELF-EMPLOYED
	drop if type_2008 == "S"

	*keep if hours > 0
	keep if loentimer > 0
	
	*cleanup occupational data
	tostring disco_kode, replace
	replace disco_kode=upper(disco_kode)
	replace disco_kode = substr(disco_kode, 1, 4)
					
	gen pcs = disco_kode
	drop if mi(pcs)

	*construction of the share of employees in the business sector
	gen bs = (arb_hoved_bra_db07 >= 51000 & arb_hoved_bra_db07 < 840000)
	
	collapse bs, by(pcs)
	gen year = "`year'"
	sort pcs year
	append using HHI\bs_pcs4
	drop if year == ""
	sort pcs year
	save HHI\bs_pcs4, replace
	
}


use idanupd9.dta, clear
append using idanupd10.dta
append using idanupd11.dta
append using idanupd12.dta
append using idanupd13.dta
append using idanupd14.dta
append using idanupd15.dta
append using idanupd16.dta
append using idanupd17.dta
append using idanupd18.dta

gen year = idanupdsourceyear - 2000
replace ansdage_2008 = ansdage if ansdage_2008 == .
gen full_time = [(loentimer / ansdage_2008)*7] >= 30
					
gen emp_prev_year = lonmtilb		
gen emp_next_year = lonmtilb		

tostring disco_kode, replace
replace disco_kode=upper(disco_kode)
replace disco_kode = substr(disco_kode, 1, 4)
					
gen pcs = disco_kode

egen nic = group(lbnr)
	
save idanupd9_18.dta, replace

exit