*THIS CODE:

*[1] GENERATES THE MAIN INSTRUMENTAL VARIABLES USED IN THE ARTICLE AND CREATES THE MAIN DATASET TO BE USED FOR THE ANALYSIS (FIRST FOR 4-DIGIT ISCO CODES, THEN FOR 2-DIGIT AND 3-DIGIT ISCO CODES).
*[2] GENERATES AN ADDITIONAL DATASET STARTING A YEAR EARLIER FOR THE ANALYSIS BASED ON ARNOLD 2021.

clear
clear matrix
clear mata
set maxvar 120000

local minyear 11
local maxyear 18
local aggregate komcvr cvr
local aggregateL komcvr cvr
local m = 1
local x = 2
local zone fuaX dep fua1
local zoneL fuaX dep fua1
local vars "ln_hourly_wage ln_hhi ln_hhi_E arb_hoved zone_num year cvr pnr pcs kom full_time stable_job emp_prev_year emp_next_year lbnr Hire IV_*"

*DISCO 4

foreach zone of loc zoneL {

foreach aggregate of loc aggregateL {

clear
forval year = 20`minyear'(1)20`maxyear' {
	use idapupd_`year'
	keep pnr kon_n
	gen year = `year' - 2000
	destring pnr, replace
	tempfile gender_`year'
	save `gender_`year''
}

clear
forval year = 20`minyear'(1)20`maxyear' {
append using `gender_`year''
}
sort pnr year
tempfile gender
save `gender'


*CREATE EMPTY DATASET
clear
gen pi = .
save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", replace

*CREATE INSTRUMENTS
use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear

levelsof `zone', loc(listzone)
foreach geo of loc listzone {
    	
	disp "`geo'"

	use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear
		
		drop if `zone' == "`geo'"
				
	gen IV_mH = log(1/nb_Dm)		
	gen IV_mE = log(1/nb_E)
	gen IV_mHC = log(1/nb_Dm) if Z_E >= 5
	gen IV_mEC = log(1/nb_Dm) if Z_P0 >= 5
	gen IV_S = log(Share_E)

	collapse IV_*, by(pcs year)
		
	gen `zone' = "`geo'"

	append using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta"

	cap drop pi
	compress
	sort `zone' pcs year
	save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", replace
}

use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear
sort `zone' pcs year
merge 1:1 `zone' pcs year using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta"
drop if _merge == 2
drop _merge
tab year
sort `zone' pcs year
tempfile HHI
save `HHI', replace	


forval year = `minyear'(1)`maxyear' {

				local year_1 = `year' - 1
				di `year_1'
				
				use idanupd`year_1', clear
				drop if type_2008 == "E"
				keep cvr pnr kom
				rename kom kom_prev_
				duplicates drop pnr cvr kom, force
				by pnr cvr, sort: gen counter = _n
				reshape wide kom_prev_, i(pnr cvr) j(counter)
				sort pnr cvr
				tempfile prev_year
				save `prev_year', replace				


	use idanupd`year', clear
		
	gen stable_job = (ansxfrem == "U") 
	replace stable_job = . if ansxfrem == ""
	
	replace ansdage_2008 = ansdage if ansdage_2008 == .
	gen full_time = [(loentimer / ansdage_2008)*7] >= 30
					
	gen emp_prev_year = lonmtilb		
	gen emp_next_year = lonmtilb		
					
	destring idanupdsourceyear, replace
	gen year = idanupdsourceyear - 2000
	tostring year, replace

	*cleanup occupational data
	tostring disco_kode, replace
	replace disco_kode = upper(disco_kode)
	replace disco_kode = substr(disco_kode, 1, 4)
			
	gen pcs = disco_kode
	drop if mi(pcs)

	sort `zone' pcs year

	merge m:1 `zone' pcs year using `HHI'
	drop _merge

	gen ln_yearly_wage = ln(smalt_loen_beloeb)
	gen ln_daily_wage = ln(smalt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage = ln(smal_timeloen)

	gen ln_yearly_wage_broad = ln(bredt_loen_beloeb)
	gen ln_daily_wage_broad = ln(bredt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage_broad = ln(bredt_loen_beloeb / loentimer)

	gen ln_hhi = ln(Share_E)
	gen ln_hhi_E = ln(EmpH)

	egen zone_num = group(`zone')

				*DROP THE SELF-EMPLOYED
				drop if type_2008 == "S"

				*DROP AGRICULTURAL, PUBLIC SECTOR, AND HOUSEHOLD WORKERS WITH SOME EXCEPTIONS (e.g., RECREATIONAL ACTIVITIES)
				drop if arb_hoved_bra_db07 < 51000
				drop if (arb_hoved_bra_db07 >= 840000 & arb_hoved_bra_db07 < 900000) | (arb_hoved_bra_db07 >= 910000 & arb_hoved_bra_db07 < 920000) | arb_hoved_bra_db07 >= 970000
								
				drop if loentimer == 0

				*PEOPLE WHO MOVED WITHIN THE SAME COMPANY
					
				if "`aggregate'" == "cvr" {
				
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2")
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/				
				
				}
				
				if "`aggregate'" == "komcvr" {
									
				preserve
				keep if ansxtilb == "T1" | ansxtilb == "T2"
				sort pnr cvr
				merge pnr cvr using `prev_year'
				tab _m
				drop if _m == 2
				drop _m
				gen transf_within_munic = (kom == kom_prev_1)
				capture replace transf_within_munic = 1 if (kom == kom_prev_2) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_3) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_4) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_5) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_6) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_7) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_8) 
				tab transf_within_munic
				
				tempfile transfers
				save `transfers', replace
				restore

				count
				drop if ansxtilb == "T1" | ansxtilb == "T2"
				count
				append using `transfers'
				count
												
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2") & transf_within_munic == 1

				drop transf_within_munic
				count				
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/
				
				}
												
				**** define new hires
				**** case 0: no filtering
				
				if `m' == 0 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				sum Hire
							
				disp `x' " 2"
				}
				}

				if `m' == 1 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				replace Hire = . if ansdage_2008 < 30
							
				disp `x' " 2"
				}
				}
					
	
	
	*keep if Hire
	count
	
	******keep `vars'
	******keep if ln_hourly_wage != .

	tempfile temp`year'
	save `temp`year''
}

clear 

forval year = `minyear'(1)`maxyear' {
	append using `temp`year''
}

	destring year, replace	
	destring cvr, replace
	destring pnr, replace

	egen id = group(pnr)
	egen occ = group(pcs)
	cap drop geo
	egen geo = group(`zone')	
	egen firm=group(cvr)
	egen munic = group(kom)

	egen nic = group(lbnr)
	
	egen cluster=group(`zone' occ year)
	
	merge m:1 pnr year using `gender'
	drop if _merge == 2
	drop _merge
	
save "data_for_regressions_`minyear'_`maxyear'_`aggregate'`zone'.dta", replace

}

}

*DISCO 2 & 3

forval d = 2(1)3 {

foreach zone in fuaX {

foreach aggregate of loc aggregateL {

clear
forval year = 20`minyear'(1)20`maxyear' {
	use idapupd_`year'
	keep pnr kon_n
	gen year = `year' - 2000
	destring pnr, replace
	tempfile gender_`year'
	save `gender_`year''
}

clear
forval year = 20`minyear'(1)20`maxyear' {
append using `gender_`year''
}
sort pnr year
tempfile gender
save `gender'


*CREATE EMPTY DATASET
clear
gen pi = .
save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta", replace

*CREATE INSTRUMENTS
use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta", clear

levelsof `zone', loc(listzone)
foreach geo of loc listzone {
    	
	disp "`geo'"

	use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta", clear
		
		drop if `zone' == "`geo'"
				
	gen IV_mH = log(1/nb_Dm)		
	gen IV_mE = log(1/nb_E)
	gen IV_mHC = log(1/nb_Dm) if Z_E >= 5
	gen IV_mEC = log(1/nb_Dm) if Z_P0 >= 5
	gen IV_S = log(Share_E)

	collapse IV_*, by(pcs year)
		
	gen `zone' = "`geo'"

	append using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta"

	cap drop pi
	compress
	sort `zone' pcs year
	save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta", replace
}

use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta", clear
sort `zone' pcs year
merge 1:1 `zone' pcs year using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs`d'`m'_DISCO`d'.dta"
drop if _merge == 2
drop _merge
tab year
sort `zone' pcs year
tempfile HHI
save `HHI', replace	


forval year = `minyear'(1)`maxyear' {

				local year_1 = `year' - 1
				di `year_1'
				
				use idanupd`year_1', clear
				drop if type_2008 == "E"
				keep cvr pnr kom
				rename kom kom_prev_
				duplicates drop pnr cvr kom, force
				by pnr cvr, sort: gen counter = _n
				reshape wide kom_prev_, i(pnr cvr) j(counter)
				sort pnr cvr
				tempfile prev_year
				save `prev_year', replace				


	use idanupd`year', clear
		
	gen stable_job = (ansxfrem == "U") 
	replace stable_job = . if ansxfrem == ""
	
	replace ansdage_2008 = ansdage if ansdage_2008 == .
	gen full_time = [(loentimer / ansdage_2008)*7] >= 30
					
	gen emp_prev_year = lonmtilb		
	gen emp_next_year = lonmtilb		
					
	destring idanupdsourceyear, replace
	gen year = idanupdsourceyear - 2000
	tostring year, replace

	*cleanup occupational data
	tostring disco_kode, replace
	replace disco_kode = upper(disco_kode)
	replace disco_kode = substr(disco_kode, 1, `d')
			
	gen pcs = disco_kode
	drop if mi(pcs)

	sort `zone' pcs year

	merge m:1 `zone' pcs year using `HHI'
	drop _merge

	gen ln_yearly_wage = ln(smalt_loen_beloeb)
	gen ln_daily_wage = ln(smalt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage = ln(smal_timeloen)  /*EQUAL TO smalt_loen_beloeb / loentimer*/

	gen ln_yearly_wage_broad = ln(bredt_loen_beloeb)
	gen ln_daily_wage_broad = ln(bredt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage_broad = ln(bredt_loen_beloeb / loentimer)

	gen ln_hhi = ln(Share_E)
	gen ln_hhi_E = ln(EmpH)

	egen zone_num = group(`zone')

				*drop non employees
				*DROP THE SELF-EMPLOYED
				drop if type_2008 == "S"

				*keep industries & nbhours>0
				*DROP AGRICULTURAL, PUBLIC SECTOR, AND HOUSEHOLD WORKERS WITH SOME EXCEPTIONS (e.g., RECREATIONAL ACTIVITIES)
				drop if arb_hoved_bra_db07 < 51000
				drop if (arb_hoved_bra_db07 >= 840000 & arb_hoved_bra_db07 < 900000) | (arb_hoved_bra_db07 >= 910000 & arb_hoved_bra_db07 < 920000) | arb_hoved_bra_db07 >= 970000
								
				drop if loentimer == 0

				*PEOPLE WHO MOVED WITHIN THE SAME COMPANY
					
				if "`aggregate'" == "cvr" {
				
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2")
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/				
				
				}
				
				if "`aggregate'" == "komcvr" {
									
				preserve
				keep if ansxtilb == "T1" | ansxtilb == "T2"
				sort pnr cvr
				merge pnr cvr using `prev_year'
				tab _m
				drop if _m == 2
				drop _m
				gen transf_within_munic = (kom == kom_prev_1)
				capture replace transf_within_munic = 1 if (kom == kom_prev_2) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_3) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_4) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_5) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_6) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_7) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_8) 
				tab transf_within_munic
				
				tempfile transfers
				save `transfers', replace
				restore

				count
				drop if ansxtilb == "T1" | ansxtilb == "T2"
				count
				append using `transfers'
				count
												
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2") & transf_within_munic == 1

				drop transf_within_munic
				count				
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/
				
				}
								
				*headcount 		
				*gen headcount = 1
				
				**** define new hires
				**** case 0: no filtering
				
				if `m' == 0 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				sum Hire
							
				disp `x' " 2"
				}
				}

				if `m' == 1 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				replace Hire = . if ansdage_2008 < 30
				*sum Hire
							
				disp `x' " 2"
				}
				}
					
		
	count
	
	******keep `vars'
	******keep if ln_hourly_wage != .

	tempfile temp`year'
	save `temp`year''
}

clear 

forval year = `minyear'(1)`maxyear' {
	append using `temp`year''
}

	destring year, replace	
	destring cvr, replace
	destring pnr, replace

	egen id = group(pnr)
	egen occ = group(pcs)
	cap drop geo
	egen geo = group(`zone')	
	egen firm=group(cvr)
	egen munic = group(kom)

	egen nic = group(lbnr)
	
	egen cluster=group(`zone' occ year)
	
	merge m:1 pnr year using `gender'
	drop if _merge == 2
	drop _merge
		
save "data_for_regressions_`minyear'_`maxyear'_`aggregate'`zone'_DISCO`d'.dta", replace

}

}

}

clear
clear matrix
clear mata
set maxvar 120000

local minyear 10
local maxyear 18
local aggregate komcvr cvr
local aggregateL komcvr cvr
local m = 1
local x = 2
local zone fuaX dep fua1
local zoneL fuaX dep fua1
local vars "ln_hourly_wage ln_hhi ln_hhi_E arb_hoved zone_num year cvr pnr pcs kom full_time stable_job emp_prev_year emp_next_year lbnr Hire IV_*"

*DISCO 4

foreach zone of loc zoneL {

foreach aggregate of loc aggregateL {

clear
forval year = 20`minyear'(1)20`maxyear' {
	use idapupd_`year'
	keep pnr kon_n
	gen year = `year' - 2000
	destring pnr, replace
	tempfile gender_`year'
	save `gender_`year''
}

clear
forval year = 20`minyear'(1)20`maxyear' {
append using `gender_`year''
}
sort pnr year
tempfile gender
save `gender'


*CREATE EMPTY DATASET
clear
gen pi = .
save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", replace

*CREATE INSTRUMENTS
use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear

levelsof `zone', loc(listzone)
foreach geo of loc listzone {
    	
	disp "`geo'"

	use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear
		
		drop if `zone' == "`geo'"
				
	gen IV_mH = log(1/nb_Dm)		
	gen IV_mE = log(1/nb_E)
	gen IV_mHC = log(1/nb_Dm) if Z_E >= 5
	gen IV_mEC = log(1/nb_Dm) if Z_P0 >= 5
	gen IV_S = log(Share_E)

	collapse IV_*, by(pcs year)
		
	gen `zone' = "`geo'"

	append using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta"

	cap drop pi
	compress
	sort `zone' pcs year
	save "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", replace
}

use "HHI\HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta", clear
sort `zone' pcs year
merge 1:1 `zone' pcs year using "HHI_IV\FIN_HHI`x'_HP_`aggregate'`zone'_pcs4`m'.dta"
drop if _merge == 2
drop _merge
tab year
sort `zone' pcs year
tempfile HHI
save `HHI', replace	


forval year = `minyear'(1)`maxyear' {

				local year_1 = `year' - 1
				di `year_1'
				
				use idanupd`year_1', clear
				drop if type_2008 == "E"
				keep cvr pnr kom
				rename kom kom_prev_
				duplicates drop pnr cvr kom, force
				by pnr cvr, sort: gen counter = _n
				reshape wide kom_prev_, i(pnr cvr) j(counter)
				sort pnr cvr
				tempfile prev_year
				save `prev_year', replace				


	use idanupd`year', clear
		
	gen stable_job = (ansxfrem == "U") 
	replace stable_job = . if ansxfrem == ""
	
	replace ansdage_2008 = ansdage if ansdage_2008 == .
	gen full_time = [(loentimer / ansdage_2008)*7] >= 30
					
	gen emp_prev_year = lonmtilb		
	gen emp_next_year = lonmtilb		
					
	destring idanupdsourceyear, replace
	gen year = idanupdsourceyear - 2000
	tostring year, replace

	*cleanup occupational data
	tostring disco_kode, replace
	replace disco_kode = upper(disco_kode)
	replace disco_kode = substr(disco_kode, 1, 4)
			
	gen pcs = disco_kode
	drop if mi(pcs)

	sort `zone' pcs year

	merge m:1 `zone' pcs year using `HHI'
	drop _merge

	gen ln_yearly_wage = ln(smalt_loen_beloeb)
	gen ln_daily_wage = ln(smalt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage = ln(smal_timeloen)

	gen ln_yearly_wage_broad = ln(bredt_loen_beloeb)
	gen ln_daily_wage_broad = ln(bredt_loen_beloeb / ansdage_2008)
	gen ln_hourly_wage_broad = ln(bredt_loen_beloeb / loentimer)

	gen ln_hhi = ln(Share_E)
	gen ln_hhi_E = ln(EmpH)

	egen zone_num = group(`zone')

				*DROP THE SELF-EMPLOYED
				drop if type_2008 == "S"

				*DROP AGRICULTURAL, PUBLIC SECTOR, AND HOUSEHOLD WORKERS WITH SOME EXCEPTIONS (e.g., RECREATIONAL ACTIVITIES)
				drop if arb_hoved_bra_db07 < 51000
				drop if (arb_hoved_bra_db07 >= 840000 & arb_hoved_bra_db07 < 900000) | (arb_hoved_bra_db07 >= 910000 & arb_hoved_bra_db07 < 920000) | arb_hoved_bra_db07 >= 970000
								
				drop if loentimer == 0

				*PEOPLE WHO MOVED WITHIN THE SAME COMPANY
					
				if "`aggregate'" == "cvr" {
				
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2")
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/				
				
				}
				
				if "`aggregate'" == "komcvr" {
									
				preserve
				keep if ansxtilb == "T1" | ansxtilb == "T2"
				sort pnr cvr
				merge pnr cvr using `prev_year'
				tab _m
				drop if _m == 2
				drop _m
				gen transf_within_munic = (kom == kom_prev_1)
				capture replace transf_within_munic = 1 if (kom == kom_prev_2) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_3) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_4) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_5) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_6) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_7) 
				capture replace transf_within_munic = 1 if (kom == kom_prev_8) 
				tab transf_within_munic
				
				tempfile transfers
				save `transfers', replace
				restore

				count
				drop if ansxtilb == "T1" | ansxtilb == "T2"
				count
				append using `transfers'
				count
												
				gen not_new_hire = (ansxtilb == "T1" | ansxtilb == "T2") & transf_within_munic == 1

				drop transf_within_munic
				count				
				drop if ansxtilb == "U" & ansaar == `year' /*INCONSISTENCY BETWEEN ANSAAR AND ANSXTILB*/
				
				}
												
				**** define new hires
				**** case 0: no filtering
				
				if `m' == 0 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				sum Hire
							
				disp `x' " 2"
				}
				}

				if `m' == 1 {
				
				if `x' == 2 {
				*construction of the indicators for presence in November of the current year and absence in November of the previous year
				*(in Denmark this can be done by checking whether the variable "year of first employment", ansaar, takes value equal to the current year)

				gen Hire = (ansaar == `year') & not_new_hire != 1
				replace Hire = . if ansdage_2008 < 30
							
				disp `x' " 2"
				}
				}
					
	
	
	*keep if Hire
	count
	
	******keep `vars'
	******keep if ln_hourly_wage != .

	tempfile temp`year'
	save `temp`year''
}

clear 

forval year = `minyear'(1)`maxyear' {
	append using `temp`year''
}

	destring year, replace	
	destring cvr, replace
	destring pnr, replace

	egen id = group(pnr)
	egen occ = group(pcs)
	cap drop geo
	egen geo = group(`zone')	
	egen firm=group(cvr)
	egen munic = group(kom)

	egen nic = group(lbnr)
	
	egen cluster=group(`zone' occ year)
	
	merge m:1 pnr year using `gender'
	drop if _merge == 2
	drop _merge
	
save "data_for_regressions_`minyear'_`maxyear'_`aggregate'`zone'.dta", replace

}

}


exit