
*****************************************************
************* ARNOLD'S HHI **************************
*****************************************************


cd "C:\Users\Public\Documents\Europe"
set more off 

cap log c
log using ArnoldHHI.log, replace

*****************************************************
************* ARNOLD'S HHI **************************
*****************************************************


***** First step: create a database with variables for observations at t and at t-1 (to avoid tsetting)
use PanelbaseFUA.dta, clear
ge dp2=dp
replace dp2=finremu-debremu+1 if dp==.
ge PFysircom=(dp2!=.)

collapse (max) PFysircom, by(nninouv sircom year)
destring year, ge(an)
compress
replace an=an-1
drop if an==9
sort nninouv sircom an

save PFsircom, replace

collapse (max) PFysircom, by(nninouv an)
rename PFy PFy
sort nninouv an
save PF, replace

** individuals one year ago
use PanelbaseFUA.dta, clear

destring year, ge(an)
replace an=an+1
drop if an>=17

*** first condition: main job one year ago should be at least 9 months duration (and full time)
ge ftpt=(ce=="C") 
keep if ftpt==1
ge dp2=dp
replace dp2=finremu-debremu+1 if dp==.
keep if dp2>=270

keep an sir sircom nninouv nic dp2 pcs nbheur netnet 

rename pcs pcs_1
rename dp2 dp2_1
rename nbheur nbheur_1
rename netnet netnet_1

keep if regexm(pcs,"^[0-9][0-9][0-9][A-Z]") // keep occupations with correct pcs code
drop if mi(pcs)
sort nninouv sircom nic an
save indiv_origin, replace // individuals one year ago dataset

*** construct a variable identifying those who remain in the firmXmunicipality the year after
use PanelbaseFUA.dta, clear

destring year, ge(an)
drop if an==9

ge dp2=dp
replace dp2=finremu-debremu+1 if dp==.
keep if dp2>=30

*keep industries
					keep if (substr(apet, 1, 2)>="05"&substr(apet, 1, 2)<="82")|substr(apet, 1, 2)=="90"| ///
						substr(apet, 1, 2)>="92"&substr(apet, 1, 2)<="96"

* ge ftpt variable
ge ftpt=(ce=="C")

*cleanup						
drop debremu finremu filtre s_brut contrat_travail apen2
drop age dp ce sx catjur domempl apet2 entsir ancsir ditot di416 educ epci LIBEPCI dep fua1 fuaX lau1 NAME_1 sirepci sirlau1
drop netnetr
	
* find stayers the year after
drop if an==17
sort nninouv sircom an
merge m:1 nninouv sircom an using PFsircom 
drop if _m==2
drop _m

**** stability condition: keep only those who stay in the same job the year after
keep if ftpt==1
keep if PFy==1				

* merging with records of the previous year					
sort nninouv sircom nic an
merge 1:1 nninouv sircom nic an using indiv_origin
ren _m mergeorigin

save temp_t, replace

*** second step: identifying the main job previous year among those with at least 30 days duration
* looping over years
foreach y of numlist 10/16 {
	use temp_t, clear

	ge p1=1 



	keep if an==`y'

	* second condition: pick that with the same occupation, if there is any
	ge occorigin=""
	levelsof pcs_1, local(pcs)

	foreach p of local pcs {
		disp `y' "  `p'"
		ge p1_`p'=(pcs_1=="`p'")
		egen maxp1_`p'=max(p1_`p'), by(nninouv)
		replace occorigin="`p'" if pcs=="`p'"&maxp1_`p'==1
		drop p1_`p' maxp1_`p'
	}
	
	* indicators for max duration, max hours and max salary
	egen maxdp=max(dp2_1), by(nninouv)	
	egen maxh=max(nbheur_1)	if abs(maxdp-dp2_1)<1, by(nninouv)
	egen maxw=max(netnet_1)	if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1, by(nninouv)
	
	* third condition: pick the one with the longest duration, if there are no ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&occorigin==""
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2

	* fourth condition: among the ties, pick the one with the longest hours, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	fifth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	sixth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin==""
	egen mode=mode(occmode), by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode

	* 	seventh condition: among the new ties, pick one at random
	set seed 1
	ge u=runiform()
	ge d=abs((_n/_N)-u)
	egen mind=min(d) if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin=="", by(nninouv)
	ge occmode=pcs_1 if abs(maxdp-dp2_1)<1&abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&abs(mind-d)<0.00000001&occorigin==""
	egen mode=mode(occmode), by(nninouv)
	replace occorigin=mode if occorigin==""
	drop mode occmode
	
	
	* saving

	keep if pcs!=""
	keep if occorigin!=""
	
	save temp_t`y', replace
	
}

* third step: squared occupation matrix containing employment in origin and destination occupations
use HHI\HHI1_HPsircomtfuaX_pcs41, clear
collapse (sum) Z_P0, by(pcs)
ge one=1
ren Z_P0 Z_P00 // destination employment
sort one
save pcs_list, replace
ren pcs occorigin
ren Z_P0 Z_P01 // origin employment
sort one
joinby one using pcs_list
keep pcs occorigin Z_P01 Z_P00
sort pcs occorigin
save pcs_squared, replace

* fourth step: transition probabilities and factors (that is relative probabilities divided by relative employment)
clear
set obs 1
ge v1=.
save tprob, replace

foreach y of numlist 10/16 {
	use temp_t`y', clear
	collapse (sum) p1, by(occorigin pcs)
	replace p1=0 if p1==.
	ge year="20`y'"
	save tprob`y', replace
	append using tprob
	save tprob, replace

	
}

drop if p1==.

* summing frequencies over years
collapse (sum) p1, by(pcs occorigin)
sort pcs occorigin
	merge 1:1 pcs occorigin using pcs_squared
	drop if _m==1
	replace p1=0 if p1==.
* marginal distributions	
	egen den1=total(p1), by(occorigin)
	egen den0=total(p1), by(pcs)
* probability of a given occupation the year before conditional on the occupation of origin	
	ge prob=p1/den1
	replace prob=0 if prob==.
* proability of remaining in the same occupation conditional on the occupation of origin
	ge tden=prob if occorigin==pcs
* reporting the probability of remaining in the same occupation conditional on the occupation of origin on all couples with the same occorigin	
	egen den=max(tden), by(occorigin)
* relative probability (as in Arnold's formula)	
	ge relprob=prob/den
* relative factor (as in Arnolds's: (Prob_m_to_k/Prob_m_to_m)/(E(Lk)/E(Lm)) )	
	* assumption E(Lk/ELm) in Arnold can be approximated by Z_P00/Z_P01
	ge relfactor=relprob*(Z_P01/Z_P00)
	
	drop den tden den1 den0 Z_P00 Z_P01 _m
	sort pcs
	compress
save tprob, replace	
	
* fifth step: denominators of shares

foreach y of numlist 10/17 {
use HHI\HHI1_HPsircomtfuaX_pcs41, clear
keep if year=="`y'"
keep pcs fuaX year Z_P0
sort pcs
joinby pcs using tprob
ge Z_P0prob=Z_P0*relprob
ge Z_P0factor=Z_P0*relfactor
ge one=(pcs==occorigin)
ge Z_P1 = Z_P0*one
collapse (sum) Z_P0p Z_P0f Z_P1, by(occorigin fuaX year)
ren occorigin pcs
compress
sort pcs fuaX year
save ArnDen`y', replace 

}

* sixth step: numerator of shares and final calculation


				clear
						* create an empty dataset
						gen year=""
						save HHI\HHI1_AsircomtfuaX_pcs41, replace 
						
					foreach year in 10 11 12 13 14 15 16 17 {
					
					
					disp   "`year'"
					
					***** Part I: compute aggregates at the `zone'XpcsXyear (geo area by occupation by year) level
					use DADSpostes`year',clear 
					
						*drop interns
					drop if typ_emploi=="S"
					drop if typ_emploi=="I"
				
					*keep nbhours>0
					keep if nbheur>0

					* headcount: number of workers that are present in the last day of the year
					gen headcount=(ind_3112==1) 
					
					**** define new hires and employment
					
					*** first step: construct indicators of presence and absence in the same plant for the current and the previous year
					* construction of the indicators for presence in the current year and absence in the previous year 
						ge P0 = (ind_3112!=.)&duree>=30
						ge A1 = (ind_3112_1==.)
					
					*** second step: construct indicators of absence in the firm for the previous year
					egen minA1 = min(A1), by(ident_s sircomt)
					
					*** third step: effectively define new hires
					gen Hire = (P0==1&minA1==1)
							disp `x' "  2" /* this is just a counter to check the advancement of the loop */

					*keep industries
					keep if (substr(apet, 1, 2)>="05"&substr(apet, 1, 2)<="82")|substr(apet, 1, 2)=="90"| ///
						substr(apet, 1, 2)>="92"&substr(apet, 1, 2)<="96"
							
	
					* cleanup occupation data 
					replace pcs=upper(pcs)
					keep if strlen(pcs)==4 
					keep if regexm(pcs,"^[0-9][0-9][0-9][A-Z]")

					replace pcs=substr(pcs,1,4) 
					drop if mi(pcs) 	
					
						* collapse at the firm level
						collapse (sum) P0, by(sircomt fuaX pcs)
						
	
						* compute the total number of firmXmunicipalities
						preserve
						collapse P0, by(sircomt fuaX)
						drop P0
						ge number=_n
	
						sort sircomt fuaX
						save sf, replace
						restore
						
						sort sircomt fuaX
						merge m:1 sircomt fuaX using sf
						drop _m
						
						
						*** create an indicator for block-by-block joinby
						ge N=floor(number/10000) 
						drop number
						sum N
						global max=r(max)+1
						disp $max
						
						compress
						save P0_`year', replace
							
				*looping over occupations (1st digit) to compute empty datasets	(1-6 because there are only 6 1-digit occupations in PCS-ESE)
				foreach pcs1 of numlist 1/6 {	
				
				disp "`pcs1'"
					* compute Arnold's numerators
					clear
					set obs 1
					ge v1=1
					compress
					save ArnNum`year'`pcs1', replace
				}	
					* looping over blocks of firmXmunicipalities and occupations (1st digit) (to avoid too large intermediate datasets)
					local x=0	
					while `x' < $max {
						disp `x'
			
										
						use P0_`year', clear
							keep if N==`x'
							sort pcs
						
						*joinby transition probabilities
						joinby pcs using tprob
						
						* compute numerator of shares
						
						* bricks to construct Arnold's shares 
						ge Hprob=P0*relprob // alternative but incorrect way
						ge Hfactor=P0*relfactor
						* brick to construct standard HHI (to check consistency)
						ge one=(pcs==occorigin)
						ge H1 = P0*one

						* computing the numerator of shares as weighted sum (as in Arnold)
						collapse (sum) Hp Hf H1, by(sircomt occorigin fuaX)
						ren occorigin pcs
						drop if Hfactor==0
						drop if fuaX==""
						
						* appending (looping on occupations - again to avoid too large intermediate datasets)
						compress
					foreach pcs1 of numlist 1/6 {	
										disp "`pcs1'"
 
						preserve
						keep if substr(pcs,1,1)=="`pcs1'"

						append using ArnNum`year'`pcs1'
						sort pcs fuaX				
						save ArnNum`year'`pcs1', replace
						restore
					}
									local x = `x'+1					
						
						}
						
						** final loop to compute Arnold's HHI
		
					foreach pcs1 of numlist 1/6 {	
										disp "`pcs1'"
										
						use ArnNum`year'`pcs1', clear				
						drop if v1==1
					
					
					* merge with local labour market Arnold aggregates
						merge m:1 pcs fuaX using ArnDen`year'
						keep if _m==3

					* squared shares of employment using Arnold factors	
						gen HHI_A=(Hfactor/Z_P0factor)^2
					* squared shares of employment using Arnold probabilities (incorrect way)	
						gen HHI_a=(Hprob/Z_P0prob)^2
						
					* check term
						gen HHI_H=(H1/Z_P1)^2

						
					* drop further errors in the occupation and geographical area variables, if any
						drop if pcs=="."
						drop if fuaX==""
		
				collapse (sum) HHI_a HHI_A HHI_H, by(fuaX pcs)

						gen year="`year'"
						
					* append to previous years, if any
						append using HHI\HHI1_AsircomtfuaX_pcs41
					* saving
						drop if year==""
						save HHI\HHI1_AsircomtfuaX_pcs41, replace 
						
						erase ArnNum`year'`pcs1'.dta
						
					}
				}

	
	
	
	
	cap log close
	
	
	
	clear
	