
cap log c
log using contractregressionsData.log, replace


* preparing data for contract regression

use PanelbaseFUA.dta, clear
ge dp2=dp
replace dp2=finremu-debremu+1 if dp==. // comleting spell duration variable if missing
keep if dp2>=30 // keep if at least 30 days in the job

* drop 2009
drop if year=="09" 

*keep industries
keep if (substr(apet, 1, 2)>="05"&substr(apet, 1, 2)<="82")|substr(apet, 1, 2)=="90"| ///
	substr(apet, 1, 2)>="92"&substr(apet, 1, 2)<="96"

* drop useless vars
drop filtre s_brut apen2 netnet entsir ancsir

ge ftpt=(ce=="C") // full-time dummy
ge perm = (contrat_travail=="01") if contrat_travail!="" // perm or temp (not reliable except for new hires)

* ge variables needed for fixed effects
		destring year, ge(an) 
		ge pcs2=substr(pcs,1,2)

		egen firm=group(sir)
		egen mun=group(comt)
		egen occ=group(pcs)
		egen occ2=group(pcs2)
		

		egen geo=group(fuaX) 
		egen nuts=group(dep) 
		egen fua1_n=group(fua1) 
		egen lau1_n=group(lau1)
		egen epci_n=group(epci)
		egen ind=group(apet2)
		egen id=group(nninouv) 
		egen nic=group(nic4)
		egen ag=group(age)
		replace ag=0 if ag==.
		replace educ=0 if educ==.
					egen cluster=group(geo occ an)
					egen cluster2=group(nuts occ an)
					egen cluster3=group(fua1_n occ an)


		destring sx, replace // make gender a cardinal variable
compress
save precontract, replace // saving baseline dataset

cap log c
log using StatsContracts.log, replace

* STATISTICS (Table 1.1 and stats on permanent/temporary contracts mentioned in the text)


					* load data
					use precontract, clear


					* merge with present/absent the year before
					sort nninouv sircom sir an
					merge 1:1 nninouv sircom sir an using P1sircom
					drop if _m==2
					drop _m

					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

				* new hire and employed the year before variables
					ge Hire=(P1ysir!=1)
					ge Emp1y=(Hire*P1y==1)
					keep if Hire==1
				* merge with standard HHI data
					sort fuaX pcs year			
					qui merge m:1 fuaX pcs year using HHI\HHI1_HPsircomtfuaX_pcs41	
					keep if _m==3
					drop _m	
					ge logShare_E=log(Share_E) // log HHI
					
					compress
					
global EO = "Emp1y"


* stats
ge educ1=(educ==1)
ge educ2=(educ==2)
ge educ3=(educ==3)
ge educ4=(educ==0)

qui regress perm ftpt sx logShare_E $EO occ geo firm mun an nic ag educ // defining sample
* Statistics (rest of Table 1.1)
sum Share_E perm sx age ftpt educ1-educ4 Emp1y if e(sample)

* Share of permanent new hires in the lowest decile of the HHI distribution

* Use the same sample on which you have computed descriptive statistics for new hires in Table C1. Drop all other observations.
* In the next 2 lines, include the name of your variables as indicated
global HHI Share_E // replace YY with the varname of the HHI (or logHHI)
global perm perm // replace PP with the varname of your indicator variable for permanent contract

sum $HHI, detail
ge HHIp10=($HHI<=r(p10)&$HHI!=.)
sum $perm if HHIp10==1

* this is the mean share of perm contracts
disp "mean share perm contracts: " r(mean)
disp "std share perm contracts: " r(sd)




cap log c
log using contractregressionbaseline.log, replace

* REGRESSIONS BASELINE 4-DIGIT OCCUPATIONS (Tables 6; 2.13; 2.14; 2.15; 2.16; 2.20; 2.23; 2.24)  
* BASELINE: FUNCTIONAL AREAS (fuaX) and firmXmunicipality (sircomt) 
* OTHER TYPES OF GEO AREA: NUTS3 (dep) AND FUAs (fua1) (only IV only sircomt)
* OTHER TYPES OF EMPLOYER IDENTIFIERS (only fuaX only IV)
* OTHER INSTRUMENTS (pure leave one out - only fuaX only sircomt)




local aggregateL  sircomt siren sirepci sirlau1
local zoneL  fuaX dep fua1   

		foreach zone of loc zoneL {		
			foreach y of loc aggregateL {
				* running condition (to estimate only necessary regressions - saving time)
				if ("`zone'"=="fuaX"&"`y'"=="sircomt")|("`zone'"=="fuaX"&"`y'"!="sircomt")|("`zone'"!="fuaX"&"`y'"=="sircomt") {
				
					* load data	
					use precontract, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"

				* merging with appropriate presence/absence indicators the year before
					if "`y'"=="siren" {
						sort nninouv sir an
						merge 1:1 nninouv sir an using P1siren
						drop if _m==2
						drop _m
					}
					if "`y'"=="sircomt" {
						sort nninouv sircom sir an
						merge 1:1 nninouv sircom sir an using P1sircom
						drop if _m==2
						drop _m
					}
					if "`y'"=="sirepci" {
						sort nninouv sirepci sir an
						merge 1:1 nninouv sirepci sir an using P1sirepci
						drop if _m==2
						drop _m
					}
					if "`y'"=="sirlau1" {
						sort nninouv sirlau1 sir an
						merge 1:1 nninouv sirlau1 sir an using P1sirlau1
						drop if _m==2
						drop _m
					}
					
					drop P1m
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					* new hire and employed the year before indicators
					ge Hire=(P1ysir!=1)
					ge Emp1y=(Hire*P1y==1)
					keep if Hire==1 // limit sample
					drop P1*
					
					* merging with HHI data
					sort `zone' pcs year			
					merge m:1 `zone' pcs year using HHI\HHI1_HP`y'`zone'_pcs41	
					keep if _m==3
					drop _m	
					*creating logs
					ge logShare_E=log(Share_E)
					
					*merging with instruments
					merge m:1 `zone' pcs year using HHI_IV\FIN_HHI1_HP`y'`zone'_pcs41	
					drop if _m==2
					drop _m
					ren IV_S IV_HHI // renaming pure leave-one-out instrument
					
					compress
					
					* loading correct cluster variable
					if "`zone'"=="dep" {
						replace geo=nuts
						replace cluster=cluster2
					}
						if "`zone'"=="fua1" {
						replace geo=fua1_n
						replace cluster=cluster3
					}		

*defining fixed effects	
global fixed = "occ#geo firm#mun#an firm#nic ag educ ftpt sx Emp1y "
	if "`y'"=="sirepci" {
	global fixed = "occ#geo firm#epci_n#an firm#nic ag educ ftpt sx Emp1y "
	}
	if "`y'"=="sirlau1" {
	global fixed = "occ#geo firm#lau1_n#an firm#nic ag educ ftpt sx Emp1y "
	}	

if "`zone'"=="fuaX"&"`y'"=="sircomt" {		
	disp "First stage `var' MODEL 1"	
	reghdfe  logShare_E IV_mH if perm!=., absorb($fixed)  cluster(cluster) 
	disp "`var'  MODEL 1"
	disp "OLS"
	reghdfe perm logShare_E   $sample, absorb($fixed)  cluster(cluster) 
	}
	
	
disp "`var'  MODEL 1"
disp "IV"
ivreghdfe perm (logShare_E=IV_mH), absorb($fixed)  cluster(cluster) 

if "`zone'"=="fuaX"&"`y'"=="sircomt" {		

	disp "perm  MODEL 1"
	disp "Leave One Out IV"
	ivreghdfe perm (logShare_E=IV_HHI), absorb($fixed)  cluster(cluster) 

	}
	
}
}
}



cap log close
clear
	
			
****
