********************************************************************************
* Title: 04.b Estimate iv.do
* Description: This dofile estimates the corresponding Instrumental Variables (IVs)
* for the regression analysis.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* B. Log
********************************************************************************

	cap log close
	cap log using "$logs\04.b Estimate iv $date.log",replace

********************************************************************************
* C. Load and prepare the data
********************************************************************************
	
	cd "$input"
	use "collapse_by_year.dta",clear

	* Estimate the number of firms hiring
	cap drop firm_hiring
	gen firm_hiring=(one_cc2==1)

********************************************************************************
* D. Estimate IVs
********************************************************************************
	
	forval x=1/2 {
		forval fuas=1/3 {
			preserve
				
				if `x' == 1 {
					local varmarket "OCUP"
				}					
				if `x' == 2 {
					local varmarket "OCUP_2D"
				}

				* Count number of hiring for IV1-2
				bys IDENT_CC `varmarket' fua`fuas' year: gegen num_h=sum(one_cc2)
								
				* Keep only FirmxMunicipalities with new hires
				bys IDENT_CC `varmarket' fua`fuas' year: gegen d=max(firm_hiring)				
				keep if d==1
				
				* Keep only one obs per FirmXmuni X labor market X year
				gduplicates drop IDENT_CC `varmarket' fua`fuas' year, force 
				
				* Collapse
				drop if mi(`varmarket') | mi(fua`fuas')
				
				gcollapse (max) market`x'_`fuas' (sum) num_h firm_hiring (count) hfirm = firm_hiring,by(`varmarket' fua`fuas' year)
				sort `varmarket' fua`fuas' year
				save temp0, replace

				// create an empty dataset
				clear		
				ge pi=.
				save temp2, replace
				
				// Estimate IV
				
				// create a macro with the list of areas and loop around them
				use temp0, clear
				levelsof fua`fuas', loc(listzone) 
				foreach geo of loc listzone {				
						disp "`geo'"
								
				// re-input data
						use temp0
					*** keep only other areas
						drop if fua`fuas'==`geo' 		

					*** instruments
						ge iv`fuas'_1=log(1/hfirm) //log 1/N hiring firms
					*** averaging across areas					
						gcollapse iv`fuas'_1, by(`varmarket' year) 
					*** recreating the identifier for the previously dropped area (necessary for merging in the regressions)				
						ge fua`fuas'=`geo'
					*** append areas one by one
						append using temp2
					*** drop useless variable and saving
						cap drop pi
						compress
						sort fua`fuas' `varmarket' year				
						save  temp2, replace
					}
					*** merge with the data containing  variables by(OCUP fua`fuas' year)
						use temp0, clear
						merge 1:1 fua`fuas' `varmarket' year using temp2
						drop if _m==2
						drop _m

						sort fua`fuas' `varmarket' year 
						keep year market`x'_`fuas' iv`fuas'_1

						sort market`x'_`fuas' year 
						
						cd "$input"
						
						save "iv_`x'_`fuas'",replace

						cap erase temp2.dta		
			restore
		 }
	}
	
********************************************************************************
* E. Estimate IVs using HHIs
********************************************************************************
	
	use "$hhi\hhi_cc2_1_1_byear", clear
	
	sort market1_1
	merge m:1 market1_1 using "$intermediate_files\market1_1_correspondence", nogen keep(3) assert(2 3)

	// Estimate the IVS for each geographical level
	foreach x of numlist 1/1 {
		forval fuas=1/1 {
			preserve
				
				if `x' == 1 {
					local varmarket "OCUP"
				}
				
				drop if `varmarket'==.
				
				drop if fua`fuas'==.
				
				drop if mi(hhi) | hhi == 0
				
				gcollapse (max) market`x'_`fuas' (mean) hhi = hhi_`x'_`fuas',by(`varmarket' fua`fuas' year)
				sort `varmarket' fua`fuas' year
				save "$input\temp0", replace

				// create an empty dataset
				clear		
				ge pi=.
				save "$input\temp2", replace
				
				// IV
				
				// create a macro with the list of areas and loop around them
				use "$input\temp0", clear
				levelsof fua`fuas', loc(listzone) 
				foreach geo of loc listzone {				
						disp "`geo'"
								
				// re-input data
						use "$input\temp0"
					*** keep only other areas
						drop if fua`fuas'==`geo' 		

					*** instruments
						ge iv`fuas'_1=log(hhi) //log HHI hiring firms
					*** averaging across areas					
						gcollapse iv`fuas'_1, by(`varmarket' year) 
					*** recreating the identifier for the previously dropped area (necessary for merging in the regressions)				
						ge fua`fuas'=`geo'
					*** append areas one by one
						append using "$input\temp2"
					*** drop useless variable and saving
						cap drop pi
						compress
						sort fua`fuas' `varmarket' year				
						save "$input\temp2", replace
					}
					
					*** merge with the data containing  variables by(OCUP fua`fuas' year)
						use "$input\temp0", clear
						merge 1:1 fua`fuas' `varmarket' year using "$input\temp2"
						drop if _m==2
						drop _m
						
						keep year market`x'_`fuas' iv`fuas'_1

						sort market`x'_`fuas' year 
						
						cd "$input"
						save iv_hhi_`x'_`fuas',replace

						cap erase "$input\temp_v1.dta"
		
			restore
		 }
	}	
	
************************ END OF DOFILE *****************************************
	cap log close
	exit,clear
