********************************************************************************
* Title: 05. Regression analysis.do
* Description: This dofile runs the main regression analysis.
********************************************************************************
	
	clear
	set trace off
	global date: di %tdCYND daily("$S_DATE", "DMY")

********************************************************************************
* B. Log
********************************************************************************

		global date: di %tdCYND daily("$S_DATE", "DMY")

		cap log close
		cap log using "$logs\05. Regression analysis $date.log",replace

********************************************************************************
* C. Load and prepare the data
********************************************************************************
	
	cd "$input"	
	use data_sample,clear	

	// Merge HHIs	
		cd "$hhi"
		
		forval x=1/1 {

				forval y=1/3 {	

				*** Firm level
				
				cap drop _merge
				sort market`x'_`y' year
				merge m:1 market`x'_`y' year using hhi_`x'_`y'_byear,replace update
				keep if _merge==1|_merge==3|_merge==4|_merge==5
				
				cap drop _merge
				
				*** Firm x Municipality level
				
				cap drop _merge
				sort market`x'_`y' year
				merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
				keep if _merge==1|_merge==3|_merge==4|_merge==5
				
				rename hhi_`x'_`y' hhi_cc2_`x'_`y'
				
				cap drop _merge
				
			
				}
			}
		*** HHI
			gen lhhi_fua1=log(hhi_cc2_1_1)
			gen lhhi_fua2=log(hhi_cc2_1_2)
			gen lhhi_fua3=log(hhi_cc2_1_3)

	// Merge with IV estimates
	
		cd "$input"
		forval x=1/1 {
		cap drop _merge
		merge m:1 market1_`x' year using iv_`x'_1
		drop if _merge==2
		drop _merge

				}
			
	// Labelling
		label var iv1_1 "IV-1"
		label var lhhi_fua1 "lHHI"
		label var lhhi_fua2 "lHHI"	
		label var lhhi_fua3 "lHHI"	
		label var women "Women"
		label var dum_fix_t_1 "Any new contract in t-1"
		label var FTPT "Full time job"
	
********************************************************************************
*C. Run regressions
********************************************************************************

	keep if y_1!=.|y_2!=.	

	* Probability of having a permanent contracts | Probability of rehiring (OLS)
	*---------------------------------------------------------------------------
	
		** Stability
			reghdfe y_1 lhhi_fua1 i.women i.education i.dum_fix_t_1 i.FTPT,cluster(cluster1) a(year age firmXmunXyear market1_1)
			estimates store reg1_1_1

			qui reg y_1 lhhi_fua1 i.women i.education i.dum_fix_t_1 i.FTPT cluster1 year age firmXmunXyear market1_1
			local obs_reg1_1_1=e(N)		
	
		** Conversion
			reghdfe y_2 lhhi_fua1 i.women i.education i.dum_fix_t_1 i.FTPT,cluster(cluster1) a(year age firmXmunXyear market1_1)
			estimates store reg2_1_1

			qui reg y_2 lhhi_fua1 i.women i.education i.dum_fix_t_1 i.FTPT cluster1 year age firmXmunXyear market1_1
			local obs_reg2_1_1=e(N)			
	
	cd "$output"
	
	*** Export results
		esttab reg1_1_1 using "Table 2.13.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labor Market Concentration and Probability of being hired on a Permanent Contract – OLS estimates – New hires only.") addnotes("The obs are `obs_reg1_1_1'") star(* 0.10 ** 0.05 *** 0.01) replace
		esttab reg2_1_1 using "Table 2.25.tex",tex keep(lhhi_fua1) label se mtitles("Spain" ) title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – OLS estimates – New hires on temporary contracts only.") note("Clustered SE at LLM x Year") addnotes("The obs are `obs_reg2_1_1'") star(* 0.10 ** 0.05 *** 0.01) replace

	* Probability of having a permanent contracts | Probability of rehiring (2SLS)
	*---------------------------------------------------------------------------

		** Stability
		ivreghdfe y_1  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s1_)
		estimates store s_iv1_1

			matrix b=e(first)

			estadd scalar F0 = b[4,1] 
	 
		qui reg y_1 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
		local obs_s_iv1_1=e(N)	 		  
	 
		** Conversion
		ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(c1_)
		estimates store c_iv1_1

			matrix b=e(first)

			estadd scalar F0 = b[4,1] 

		qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
		local obs_c_iv1_1=e(N)	 					   
			
	* First stage 
	*---------------------------------------------------------------------------
	forval y=1/2 {
		if `y' == 1 {
			local pref = "fs"
		}
		if `y' == 2 {
			local pref = "fc"
		}
		
		reghdfe lhhi_fua1 iv1_1 i.women i.education i.dum_fix_t_1 i.FTPT if !mi(y_`y'),cluster(cluster1) a(year age firmXmunXyear market1_1)
		estimates store `pref'_1_1

		qui reg lhhi_fua1 iv1_1 i.women i.education i.dum_fix_t_1 i.FTPT cluster1 year age firmXmunXyear market1_1 if !mi(y_`y')
		local obs_`pref'_1_1=e(N)		 	 
	}
	
********************************************************************************
* D. Export results
********************************************************************************
	
	* First stage
	*---------------------------------------------------------------------------
	esttab fs_1_1 using "Table 2.14.tex",tex keep(iv1_1) label se mtitles("Spain") title("Labor Market Concentration and Probability of being hired on a Permanent Contract – New hires only – First Stage Equation") addnotes("The obs are `obs_fs_1_1'") ar2 r2 star(* 0.10 ** 0.05 *** 0.01) replace
	esttab fc_1_1 using "Table 2.26.tex",tex keep(iv1_1) label se mtitles("Spain") title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – – First Stage Equation – New hires on temporary contracts only") addnotes("The obs are `obs_fc_1_1'") ar2 r2 star(* 0.10 ** 0.05 *** 0.01) replace
	
	* Second stage
	*---------------------------------------------------------------------------
	esttab s_iv1_1 using "Table 6.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labor Market Concentration and Probability of being hired on a Permanent Contract – IV estimates – New hires only") addnotes("The obs are `obs_s_iv1_1'")  stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	esttab c_iv1_1 using "Table 7.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates – New hires on temporary contracts only") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace

******************** END OF THIS DOFILE ****************************************
	cap log close
	exit,clear
