********************************************************************************
* Title: 06. Robustness analysis.do
* Description: This dofile runs the robustness regressions.
********************************************************************************
	
	clear
	set trace off

********************************************************************************
* (1) At firm level
********************************************************************************

	if $rob1 == 1 {

********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - Firm level $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************

	cd "$input"
	use data_sample,clear	

	// Merge HHIs
	cd "$hhi"	
	forval x=1/1 {

			forval y=1/1 {	

			cap drop _merge
			sort market`x'_`y' year
			merge m:1 market`x'_`y' year using hhi_`x'_`y'_byear,replace update
			keep if _merge==1|_merge==3|_merge==4|_merge==5
			
			rename hhi_`x'_`y' hhi_`x'_`y'
			
			cap drop _merge		
			
			}
	}

		gen lhhi_fua1=log(hhi_1_1)

	// Merge IVs
	cd "$input"
	cap drop _merge
	merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen
	
	// Labelling
	label var iv1_1 "IV-1"
	label var lhhi_fua1 "lHHI"
	
********************************************************************************
* C. Regressions
********************************************************************************

	cd "$output"

	* Stability
	qui ivreghdfe y_1  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s1_)
	estimates store s_iv1_1

			matrix b=e(first)

			estadd scalar F0 = b[4,1] 
	 
	qui reg y_1 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
	local obs_s_iv1_1=e(N)	 		  	

	* Conversion
	qui ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(c1_)
	estimates store c_iv1_1

			matrix b=e(first)

			estadd scalar F0 = b[4,1] 

	qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
	local obs_c_iv1_1=e(N)	 					  
			
	* Export results
	esttab s_iv1_1 using "Table 2.20.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labor Market Concentration and Probability of being hired on a Permanent Contract – IV estimates – New hires only – Nationwide firms") addnotes("The obs are `obs_s_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	esttab c_iv1_1 using "Table 2.27.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates – New hires on temporary contracts only – Nationwide firms") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace

************************ END OF THIS DOFILE ************************************
	clear
	log close
	
	}

********************************************************************************
* (2) With interactions by age and gender
********************************************************************************

	if $rob2 == 1 {
	
********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - Interactions $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************

	cd "$input"
	use data_sample,clear	

	// Merge HHIs	
	cd "$hhi"
	forval x=1/1 {

			forval y=1/1 {	
			
			cap drop _merge
			sort market`x'_`y' year
			merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
			keep if _merge==1|_merge==3|_merge==4|_merge==5
			
			rename hhi_`x'_`y' hhi_cc2_`x'_`y'
			
			cap drop _merge
				}
			}

	gen lhhi_fua1=log(hhi_cc2_1_1)

	// Merge IVs
	cd "$input"
	cap drop _merge
	merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen

	* Additional variables
	gen young=(age<=24)
	
	// Labelling
	label var lhhi_fua1 "lHHI"
	label var iv1_1 "IV-1"
	label var young "Young"		
	label var women "Women"		

********************************************************************************
* C. Regressions
********************************************************************************

	cd "$output"
	
	foreach var in young women {
	
		foreach dep in y_1 y_2 {
		
		if "`dep'" == "y_1" {
			local output "Figure 1 - Panel B"
			
			if "`var'" == "young" {
				local output "Figure 2 - Panel B"
			}
			
		local title "Temporary vs Permanent"
		}
		
		if "`dep'" == "y_2" {
			local output "Figure 1 - Panel C.tex"
			
			if "`var'" == "young" {
				local output "Figure 2 - Panel C.tex"
			}		
		
		local title "Conversion"		
		}
		
		
	cap drop hhi0 hhi1	
	gen hhi0=lhhi_fua1 if `var'==0
	replace hhi0=0 if !missing(lhhi_fua1) & missing(hhi0)
	gen hhi1=lhhi_fua1 if `var'==1	
	replace hhi1=0 if !missing(lhhi_fua1) & missing(hhi1)
	
	label var hhi0 "`var' = 0 x lHHI"
	label var hhi1 "`var' = 1 x lHHI"									

	*Stability - IVs
		
		qui reg `dep'  i.women i.education i.dum_fix_t_1 i.FTPT c.hhi0 c.hhi1 0.`var'#c.iv1_1 1.`var'#c.iv1_1 cluster1 year age firmXmunXyear market1_1
		local obs_s_1=e(N)	 								
		
		ivreghdfe `dep'  i.women i.education i.dum_fix_t_1 i.FTPT (c.hhi0 c.hhi1 =0.`var'#c.iv1_1 1.`var'#c.iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s_1)
		estimates store s_1

	* Export results
		matrix b=e(first)
		
		global F1 = e(widstat)
		
		test _b[hhi0]=_b[hhi1]
		global p_reg1 = r(p)

		esttab s_1 using "`output'",tex keep(hhi0 hhi1) label se /*
		*/ mtitles("Spain") title("`title'") addnotes("F-statistic is $F1" "P-value for equivalence of HHIs is $p_reg1" "The obs are `obs_s_1'") stats(N r2 , fmt(0 4) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(R^{2}\)"')) star(* 0.10 ** 0.05 *** 0.01) replace		
		
		}
	}	
	
************************ END OF THIS DOFILE ************************************
	clear
	log close	

	}

********************************************************************************
* (3) Regressions at Fua and Nuts3 level
********************************************************************************

	if $rob3 == 1 {

********************************************************************************
* A. Generate log
********************************************************************************
	
	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - Fua and Nuts3 $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************

	cd "$input"
	use data_sample,clear	

	// Merge HHIs		
	cd "$hhi"
	forval x=1/1 {

			forval y=2/3 {	

			cap drop _merge
			sort market`x'_`y' year
			merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
			keep if _merge==1|_merge==3|_merge==4|_merge==5
			
			rename hhi_`x'_`y' hhi_cc2_`x'_`y'
			
			cap drop _merge	
				}
			}

		gen lhhi_fua2=log(hhi_cc2_1_2)
		gen lhhi_fua3=log(hhi_cc2_1_3)

	// Merge IVs
	cd "$input"
	forval x=2/3 {
		cap drop _merge
		merge m:1 market1_`x' year using iv_1_`x', keep(1 3) nogen
	}
		
	// Labelling
	label var iv2_1 "IV-1"
	label var iv3_1 "IV-1"	
	label var lhhi_fua2 "lHHI"	
	label var lhhi_fua3 "lHHI"	
	label var women "Women"
	label var dum_fix_t_1 "Any new contract in t-1"
	label var FTPT "Full time job"
	
********************************************************************************
* C. Regressions
********************************************************************************	

	forval geolevel=2/3 {
		
		if `geolevel'==2 {
		local geo="nuts3"
		local title="NUTS3"
		local output1 "Table 2.24.tex"
		local output2 "Table 2.30.tex"
		}
		if `geolevel'==3 {
		local geo="fua"
		local title="FUAs"
		local output1 "Table 2.23.tex"
		local output2 "Table 2.29.tex"
		}

	* Stability
	ivreghdfe y_1  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua`geolevel'=iv`geolevel'_1) ,cluster(cluster`geolevel') a(year age firmXmunXyear market1_`geolevel') savefprefix(s1_)
	estimates store s_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 
 
	qui reg y_1 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua`geolevel' iv`geolevel'_1 cluster`geolevel' year age firmXmunXyear market1_`geolevel'
	local obs_s_iv1_1=e(N)	 

	* Conversion
	ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua`geolevel'=iv`geolevel'_1) ,cluster(cluster`geolevel') a(year age firmXmunXyear market1_`geolevel') savefprefix(c1_)
	estimates store c_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 

	qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua`geolevel' iv`geolevel'_1 cluster`geolevel' year age firmXmunXyear market1_`geolevel'
	local obs_c_iv1_1=e(N)	 				
  
	* Export results
	cd "$output"
	esttab s_iv1_1 using "`output1'",tex keep(lhhi_fua`geolevel') label se mtitles("Spain") title("Labor Market Concentration and Probability of being hired on a Permanent Contract – IV estimates – New hires only – Local Labor Markets based on `title'") addnotes("The obs are `obs_s_iv1_1'")  stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	esttab c_iv1_1 using "`output2'",tex keep(lhhi_fua`geolevel') label se mtitles("Spain") title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates – New hires on temporary contracts only – Local Labor markets based on `title'") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	}

************************ END OF THIS DOFILE ************************************
	clear	
	log close
	
	}

********************************************************************************
* (4) With share of occupations as a regressor
********************************************************************************

	if $rob4 == 1 {

********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - With share of occupations $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************
	
	cd "$input"
	use data_sample,clear	

	// Merge shares of occupation
	sort OCUP year
	merge m:1 OCUP year using "$input\intermediate_files\shocc",nogen keep(1 3)
		
	// Merge HHIs	
	cd "$hhi"
	forval x=1/1 {

			forval y=1/1 {	

			*Firm x Municipality level
			
			cap drop _merge
			sort market`x'_`y' year
			merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
			keep if _merge==1|_merge==3|_merge==4|_merge==5
			
			rename hhi_`x'_`y' hhi_cc2_`x'_`y'
			
			cap drop _merge
	
				}
			}

	gen lhhi_fua1=log(hhi_cc2_1_1)

	// Merge IVs
	cd "$input"
	cap drop _merge
	merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen
		
	// Labelling
	label var iv1_1 "IV-1"
	label var lhhi_fua1 "lHHI"
	label var women "Women"
	label var dum_fix_t_1 "Any new contract in t-1"
	label var FTPT "Full time job"
	label var shocc "Share of occupation"
	
********************************************************************************
* C. Regressions
********************************************************************************	

	****
	// Probability of rehiring (2SLS)
	****	

	*Conversion
	ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT shocc (lhhi_fua1=iv1_1),cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(c1_)
	estimates store c_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 

	qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1 shocc
	local obs_c_iv1_1=e(N)	 										
	
	***Export results
	cd "$output"
	esttab c_iv1_1 using "Table 2.32.tex",tex keep(lhhi_fua1) label se indicate("Share of occup = shocc") mtitles("Spain") title("Labor Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates – New hires on temporary contracts only – controlling for the share of 4-digit occupations in new hires at the national level") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	
************************ END OF THIS DOFILE ************************************
	clear
	log close
	
	}

********************************************************************************
* (5) Plausibly exogenous instrument regressions
********************************************************************************

	if $rob5 == 1 {

********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - Exogenous instrument $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************
	
	cd "$input"
	use data_sample,clear	
		
	// Install required ado files
	ssc install plausexog
	
	// Merge HHIs	
	cd "$hhi"
	forval x=1/1 {

			forval y=1/1 {	

			cap drop _merge
			sort market`x'_`y' year
			merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
			keep if _merge==1|_merge==3|_merge==4|_merge==5
			
			rename hhi_`x'_`y' hhi_cc2_`x'_`y'
			
			cap drop _merge
				}
			}

	gen lhhi_fua1=log(hhi_cc2_1_1)

	// Merge IVs
	cd "$input"
	cap drop _merge
	merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen
		
	// Labelling
	label var iv1_1 "IV-1"
	label var lhhi_fua1 "lHHI"
	label var women "Women"
	label var dum_fix_t_1 "Any new contract in t-1"
	label var FTPT "Full time job"

********************************************************************************
*C. Regressions
********************************************************************************

	global LHHI lhhi_fua1 // Log HHI
	global IV iv1_1 // Log IV
	global fixed "i.women i.education i.dum_fix_t_1 i.FTPT year age firmXmunXyear market1_1" // Covariates
	global cluster "cluster1" // Cluster dimensions	

	preserve
	
		global Dvar "y_2"
		
		reghdfe $Dvar $IV , abs($fixed ) cluster($cluster )

		* derive minimum notional gamma (the one of the reduced form) 
		global G = _b[ $IV ]
		global seG = _se[ $IV ]

		* partialling out key variables
		keep if $Dvar !=.& $LHHI !=.& $IV !=.
		reghdfe $Dvar , abs($fixed) residuals(Dvar_e)
		reghdfe $LHHI , abs($fixed) residuals(lhhi_e)
		reghdfe $IV , abs($fixed) residuals(IV_e)

		* using plausexog to quickly find a candidate for the minimum gamma for which beta is still significant
		scalar max = 0
		scalar max1 = max
		local n = 0
		local G=$G
		while `n'>`G' { 
		local n = `n'+ ($G / 30) 
		disp in ye `n'
		plausexog uci Dvar_e (lhhi_e = IV_e), gmin(`n') gmax(0) level(0.90) vce(cluster $cluster )
		scalar ub = e(ub_lhhi_e)
		scalar max1 = max
		scalar max = `n'
		if ub>0 {
			local n = $G - 1
			}
		}	

		* refining the serach for the minimum gamma for which beta is still significant

		ge Y1=.

		local n = max1
		scalar gmin = `n'
		while `n'<0 {
		disp "gamma = " `n'
		replace Y1=$Dvar -( $IV * `n')
		ivreghdfe Y1 ( $LHHI = $IV ), abs($fixed ) level(90) cluster($cluster )
		scalar ub = _b[ $LHHI ]+1.64*_se[ $LHHI ]
		scalar gmin = `n'
		local gmin = `n'
		if ub<0 {
			local n = 1
			}	
		local n=`n' - ($G / 30)
		}

		* output for Table 2.33
		disp "Results for conversion"
		disp "reduced form gamma = " $G // to be reported in row (1)
		disp "standard error of reduced form gamma = " $seG // to be reported in row (1) below the gamma

		disp "min gamma = " gmin // to be reported in row (2)
		
		
		* Prepare latex output
		clear
		set obs 10
		
			gen variables = ""
			label var variables "Dep. Var Conversion"
			
			gen spain = ""
			label var spain "Spain"
			
			replace variables = "(1) Reduced-form estimate of α from eq. (5)" in 2
			replace variables = "(2) Minimum γ for which β is significant at the 10% level in eq. (4) using 2SLS" in 6
			replace variables = "(2)/(1)" in 8
			
			replace spain = "$G ***" in 2
			replace spain = "($seG )" in 3
			
			replace spain = "`gmin'" in 6
			local ratio = `gmin'/$G
			
			replace spain = "`ratio'" in 8
				
			cd "$output"	
			texsave * using "Table 2.33.tex", replace varlabels	
		
	restore	
	
************************ END OF THIS DOFILE ************************************
	clear
	log close
	
	}

********************************************************************************
* (6) With 2-digit ISCO HHIs
********************************************************************************

	if $rob6 == 1 {
	
********************************************************************************
* A. Generate log
********************************************************************************
	
	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - 2-digit ISCO $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************

	cd "$input"		
	use data_sample,clear	

	// Merge HHIs
	cd "$hhi"

	cap drop _merge
	sort market2_1 year
	merge m:1 market2_1 year using hhi_cc2_2_1_byear,replace update
	keep if _merge==1|_merge==3|_merge==4|_merge==5
	
	rename hhi_2_1 hhi_cc2_2_1
	
	cap drop _merge
	
	compress

	gen lhhi_fua1=log(hhi_cc2_2_1)
	
	// Merge IVs
	cd "$input"
	cap drop _merge
	merge m:1 market2_1 year using iv_2_1, keep(1 3) nogen

	// Additional variables
	gen young=(age<=24)

	// Labelling
	label var lhhi_fua1 "lHHI"
	label var iv1_1 "IV-1"
	label var young "Young"		
	label var women "Women"		

********************************************************************************
* C. Regressions
********************************************************************************
	
	keep if y_1!=.|y_2!=.	

	* Stability
	ivreghdfe y_1  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market2_1) savefprefix(s1_)
	estimates store s_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 
 
	qui reg y_1 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market2_1
	local obs_s_iv1_1=e(N)	 		  

	* Conversion
	ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market2_1) savefprefix(c1_)
	estimates store c_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 

	qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market2_1
	local obs_c_iv1_1=e(N)	 					   

	* Export results
	cd "$output"
	esttab s_iv1_1 using "Table 2.21.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labour Market Concentration and Probability of being hired on a Permanent Contract – IV estimates – New hires only – HHI based on 2-digit occupations") addnotes("The obs are `obs_s_iv1_1'")  stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	esttab c_iv1_1 using "Table 2.28.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labour Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates – New hires on temporary contracts only – HHI based on 2-digit occupations") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace

************************ END OF THIS DOFILE ************************************
	clear
	log close	

	}

********************************************************************************
* (7) With leave-one-out HHI IV
********************************************************************************					

	if $rob7 == 1 {
	
********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - outside HHI IV $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************
	
	cd "$input"
	use data_sample,clear	

	// Merge HHIs	
		cd "$hhi"
		forval x=1/1 {

				forval y=1/1 {	
	
				cap drop _merge
				sort market`x'_`y' year
				merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
				keep if _merge==1|_merge==3|_merge==4|_merge==5
				
				rename hhi_`x'_`y' hhi_cc2_`x'_`y'
				
				cap drop _merge
				}
			}

		gen lhhi_fua1=log(hhi_cc2_1_1)
			
	// Merge IVs
		cd "$input"
		cap drop _merge
		merge m:1 market1_1 year using iv_hhi_1_1, keep(1 3) nogen
			
	// Labelling
		label var iv1_1 "IV-1"
		label var lhhi_fua1 "lHHI"
		label var women "Women"
		label var dum_fix_t_1 "Any new contract in t-1"
		label var FTPT "Full time job"
	
********************************************************************************
* C. Regressions
********************************************************************************
	
	keep if y_1!=.|y_2!=.

	* Stability
	ivreghdfe y_1  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s1_)
	estimates store s_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 
 
	qui reg y_1 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
	local obs_s_iv1_1=e(N)	 		  		 
		
	* Conversion
	ivreghdfe y_2  i.women i.education i.dum_fix_t_1 i.FTPT (lhhi_fua1=iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(c1_)
	estimates store c_iv1_1

		matrix b=e(first)

		estadd scalar F0 = b[4,1] 

	qui reg y_2 i.women i.education i.dum_fix_t_1 i.FTPT lhhi_fua1 iv1_1 cluster1 year age firmXmunXyear market1_1
	local obs_c_iv1_1=e(N)	 					   

	* Export results
	cd "$output"
	esttab s_iv1_1 using "Table 2.16.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labour Market Concentration and Probability of being hired on a Permanent Contract – New hires only – IV estimates using the leave-one-out HHI as an instrument") addnotes("The obs are `obs_s_iv1_1'")  stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	esttab c_iv1_1 using "Table 2.31.tex",tex keep(lhhi_fua1) label se mtitles("Spain") title("Labour Market Concentration and Conversions from Temporary to Permanent Contracts – IV estimates using the leave-one-out HHI as an instrument – New hires on temporary contracts only") addnotes("The obs are `obs_c_iv1_1'") stats(N F0, fmt(0 2) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(F\)"')) star(* 0.10 ** 0.05 *** 0.01) replace
	
************************ END OF THIS DOFILE ************************************
	clear
	log close			
	}

********************************************************************************
* (8) With interactions of nationality
********************************************************************************		

	if $rob8 == 1 {

********************************************************************************
* A. Generate log
********************************************************************************

	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - nationality $date.log",replace

********************************************************************************
* B. Load and prepare the data
********************************************************************************
	
	cd "$input"
	use data_sample,clear			

	// Merge HHIs	
		cd "$hhi"		
		forval x=1/1 {

				forval y=1/1 {	

				cap drop _merge
				sort market`x'_`y' year
				merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
				keep if _merge==1|_merge==3|_merge==4|_merge==5
				
				rename hhi_`x'_`y' hhi_cc2_`x'_`y'
				
				cap drop _merge
				}
			}

		gen lhhi_fua1=log(hhi_cc2_1_1)
			
		* HHI x Skills interaction	
		cap drop hhi0 hhi1	
		
		gen hhi0=lhhi_fua1 if spanish == 0
		replace hhi0=0 if !missing(lhhi_fua1) & missing(hhi0)
		
		gen hhi1=lhhi_fua1 if spanish == 1
		replace hhi1=0 if !missing(lhhi_fua1) & missing(hhi1)
	
		label var hhi0 "Foreign x lHHI"
		label var hhi1 "Spanish x lHHI"		
	
	// Merge IVs
		cd "$input"
		cap drop _merge
		merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen
		
	// Labelling
		label var iv1_1 "IV-1"
		label var lhhi_fua1 "lHHI"
		label var women "Women"
		label var dum_fix_t_1 "Any new contract in t-1"
		label var FTPT "Full time job"
		
********************************************************************************
* C. Regressions
********************************************************************************	
	
	keep if y_1!=.|y_2!=.	
	
	// Probability of having a permanent contracts | Probability of rehiring
		cd "$output"
		
			foreach dep in y_1 y_2 {
			
				if "`dep'" == "y_1" {
					local output "Figure 3B.tex"

				local title "Probability of being hired on a permanent contract (new hires only)"
				}
				
				if "`dep'" == "y_2" {
					local output "Figure 3C.tex"

				local title "Probability of being converted to a permanent contract (new hires on temporary contracts only)"		
				}

				*Stability - IVs
				
				qui reg `dep' i.women i.education i.dum_fix_t_1 i.FTPT c.hhi0 c.hhi1 0.spanish#c.iv1_1 1.spanish#c.iv1_1 cluster1 year age firmXmunXyear market1_1
				local obs_s_1=e(N)	 								
				
				ivreghdfe `dep' i.women i.education i.dum_fix_t_1 i.FTPT (c.hhi0 c.hhi1 = 0.spanish#c.iv1_1 1.spanish#c.iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s_1)
				estimates store s_1

				*Export results
				matrix b=e(first)
				
				global F1 = e(widstat)
				
				test _b[hhi0]=_b[hhi1]
				global p_reg1 = r(p)

				esttab s_1 using "`output'",tex keep(hhi0 hhi1) label se /*
				*/ mtitles("Spain") title("`title'") addnotes("F-statistic is $F1" "The obs are `obs_s_1'" "P-value is ${p_reg1}") stats(N r2 , fmt(0 4) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(R^{2}\)"')) star(* 0.10 ** 0.05 *** 0.01) replace		
				
			}
			
************************ END OF THIS DOFILE ************************************
	clear
	log close				
		}

********************************************************************************
* (9) With Interactions by education
********************************************************************************					

	if $rob9 == 1 {

********************************************************************************	
* A. Generate log
********************************************************************************	
	
	global date: di %tdCYND daily("$S_DATE", "DMY")

	cap log close
	cap log using "$logs\06. Robustness analysis - education interact $date.log",replace

********************************************************************************	
* B. Load and prepare the data
********************************************************************************

	cd "$input"
	use data_sample,clear			

	// Merge HHIs	
		cd "$hhi"
		forval x=1/1 {

				forval y=1/1 {	

				cap drop _merge
				sort market`x'_`y' year
				merge m:1 market`x'_`y' year using hhi_cc2_`x'_`y'_byear,replace update
				keep if _merge==1|_merge==3|_merge==4|_merge==5
				
				rename hhi_`x'_`y' hhi_cc2_`x'_`y'
				
				cap drop _merge
			
				}
			}

		gen lhhi_fua1=log(hhi_cc2_1_1)
			
		* HHI x Education interaction	
			
			** Construct educational levels
			gen education_cats = "Below upper secondary" if education == 1
			replace education_cats = "Upper secondary" if inrange(NIVEL_FORMA, 31, 41)
			replace education_cats = "Above upper secondary" if inrange(NIVEL_FORMA, 51, 61)			
			replace education_cats = "Below upper secondary" if mi(education_cats)
			
			gen educa = 1 if education_cats == "Below upper secondary" 
			replace educa = 2 if education_cats == "Upper secondary" | education_cats == "Above upper secondary" 		
			
			** Construct education interactions
			cap drop hhi0 hhi1	
			
			gen hhi0=lhhi_fua1 if educa == 1
			replace hhi0=0 if !missing(lhhi_fua1) & missing(hhi0)
			
			gen hhi1=lhhi_fua1 if educa == 2
			replace hhi1=0 if !missing(lhhi_fua1) & missing(hhi1)
		
			label var hhi0 "Lower educ. x lHHI"
			label var hhi1 "Higher educ. x lHHI"		
	
	// Merge IVs
		cd "$input"
		cap drop _merge
		merge m:1 market1_1 year using iv_1_1, keep(1 3) nogen
			
	// Labelling
		label var iv1_1 "IV-1"
		label var lhhi_fua1 "lHHI"
		label var women "Women"
		label var dum_fix_t_1 "Any new contract in t-1"
		label var FTPT "Full time job"
		
********************************************************************************	
* C. Regressions
********************************************************************************	
	
	keep if y_1!=.|y_2!=.	
	
		cd "$output"
		
			foreach dep in y_1 y_2 {
			
				if "`dep'" == "y_1" {
					local output "Figure 4B.tex"

				local title "Probability of being hired on a permanent contract (new hires only)"
				}
				
				if "`dep'" == "y_2" {
					local output "Figure 4C.tex"

				local title "Probability of being converted to a permanent contract (new hires on temporary contracts only)"		
				}

				*Stability - IVs
				
				qui reg `dep' i.women i.education i.dum_fix_t_1 i.FTPT c.hhi0 c.hhi1 1.educa#c.iv1_1 2.educa#c.iv1_1 cluster1 year age firmXmunXyear market1_1
				local obs_s_1=e(N)	 								
				
				ivreghdfe `dep' i.women i.education i.dum_fix_t_1 i.FTPT (c.hhi0 c.hhi1 = 1.educa#c.iv1_1 2.educa#c.iv1_1) ,cluster(cluster1) a(year age firmXmunXyear market1_1) savefprefix(s_1)
				estimates store s_1

				* Export results
				matrix b=e(first)
				
				global F1 = e(widstat)
				
				test _b[hhi0]=_b[hhi1]
				global p_reg1 = r(p)

				esttab s_1 using "`output'",tex keep(hhi0 hhi1) label se /*
				*/ mtitles("Spain") title("`title'") addnotes("F-statistic is $F1" "The obs are `obs_s_1'" "P-value is ${p_reg1}") stats(N r2 , fmt(0 4) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}")  labels(`"Observations"' `"\(R^{2}\)"')) star(* 0.10 ** 0.05 *** 0.01) replace		
				
			}		
************************ END OF THIS DOFILE ************************************
	clear
	log close				
	}				
		
************************ END OF THIS DOFILE ************************************
clear
exit,clear
