******************************************************************************************
*
*			
*		do-file:
*					this programme merges municipality/District data and FUA definitions and creates geographical areas based on FUAs and District classifications
*			
*
*
******************************************************************************************


clear
capture log close
log using ../log/mergeMunicipalitiesFUAsPRT.log, replace

**********************************************************
****** first step: input FUA data and drop other countries
**********************************************************

clear
import excel using "../Raw_data/list-of-municipalities-in-functional-urban-areas Portugal.xlsx", cellrange(A1:H58) sheet("list_mun") firstrow
* keep your own country
keep if ISO3=="PRT"

* generate standardised Portuguese municipality codes
ge codgeo_num=substr(OECDIDmunicipality, 6, 4)
label var codgeo_num "code of municipality"

* generate FUA numerical codes and rename alphanumeric codes
ge fua=real(substr(CODEoffunctionalurbanarea, 3, 3))
ren CODEoffunctionalurbanarea codefua

* keeping also names and  saving
keep codgeo_num fua codefua Name* CORE1
ren Namemun Municipio
duplicates drop
sort codgeo_num
save ../dta/FUAPRT, replace


**********************************************************
****** second step: merge FUA data and municipality/distritos names
**********************************************************
* Importing table with the hierarchic tree from District to municipalities and parishes

clear
import excel "../Raw_data/StatisticsPortugal_district_municipality_parish_correspondance.xlsx", sheet("Exportação de categorias") cellrange(B15) case(lower) clear
keep B C D
rename (B C D) (level code designation)

* Keeping level 2 of the hierarchy which contains all municipalities
keep if level=="2"

drop level
rename code codgeo_num
rename designation mun_name
* First two digits of the municipality's code identify the district so:

gen district=substr(codgeo_num, 1 , 2)

* Naming districts
	preserve
	* file with districts names and codes
	import excel "../Raw_data/StatisticsPortugal_district_municipality_parish_correspondance.xlsx", sheet("Exportação de categorias") cellrange(B15) case(lower) clear

	keep B C D
	rename (B C D) (level code designation)
	* Keeping level 1 of the hierarchy which contains all districts
	keep if level=="1"
	rename (code designation) (district district_name) 
	keep district district_name

	tempfile district
	save `district'

	restore

merge m:1 district using `district'
drop _merge		// all municipalities were matched

* merge with the FUA database via municipality names

merge 1:1 codgeo_num using ../dta/FUAPRT

* building a tracker of municipalities that are not part of a FUA
ren _merge mergefua


********************************************************************************
****** third step: creation of geographical area based on FUAs and equiv NUTS3 regions (Distritos)
********************************************************************************

* Rename District 

rename district dep

* fua1: real FUA only
ge fua1=codefua
egen minfua=min(fua), by(dep)

* auxiliar variable: also Distritos where no municipality is part of a FUA
ge fua_aux_2=codefua
replace fua_aux_2=dep if fua==.&minfua==.

*fuaX: FUAs + rest of Distritos if covering at least 70% of municipalities (Extended FUAs)
ge du=(fua_aux_2!="")
egen ratiocomfua=mean(du), by(dep)
ge fuaX=fua_aux_2
replace fuaX=dep if fuaX==""&ratiocomfua<.3

* change name of municipality identifier.
rename codgeo_num comt 

* compressing, cleaning and dropping duplicates

compress
keep   dep district_name comt mun_name fu* Name* CORE1 
duplicates drop
sort comt
save ../dta/mergedMunicipalitiesFUAsPRT, replace

* fua1 is a subset of fuaX, 
* HHIs can be constructed only for the most extensive classification (fuaX) to save computation time
* Then using, to obtain HHIs under fua1 it is enough to restrict the sample to geographical areas where fua1 is defined.
ge pi=1
collapse pi, by(fua1 fuaX)
drop pi
sort fuaX
save ../dta/nested_fua, replace





*****************************
log c
