******************************************************************************************
*
*			
*		do-file:
*					Computing HHI when:
*										- occupation is at the: 4-digit-level or 2-digit-level
*										- the geographical areas are: Functional Areas, or NUTS3 (Districts for Portugal), or FUAs
*										- firms identifiers are: nationwide firms or firm-by-municipality
*
*										- According to Arnold (2021)'s method_____________________________________line 261 onwards
*
******************************************************************************************

cap log c
clear
log using ../log/HHImaster.log, replace

*********** FIRST LOOP: excluding within-firm transfer from new hires

* HHI2_ month/year concept - the only one available for Portugal

local aggregateL siren sircomt	// firm or firmXmunicipality concept
local zoneL fuaX dep			// Functional Areas or Districts
local pcsD  pcs4 pcs2d // occupation at 4 or 2 digits
			
foreach m of numlist 1/1 {
	foreach x of numlist 2/2 {
		foreach zone of loc zoneL {
			foreach aggregate of loc aggregateL {
					foreach pcs of loc pcsD {
					clear
						*create an empty dataset
						gen year=.
						save ../dta/HHI/HHI`x'_HP`aggregate'`zone'_`pcs'`m', replace
						
						foreach a of numlist 2011/2019 {  
						local year=substr("`a'", 3, 2)
						disp "`aggregate'"
						disp "`year'"
						
						**** Part I: compute aggregates atthe `zone'XpcsXyear (geo area by occupation by  year) level
						use ../dta/QP/year`year'/FUAQP`year', clear

						*if 2 digit occupation 
						if "`pcs'"=="pcs2d" {
						 		drop pcs
								rename  prof2d_cpp10 pcs	
						}

										
						*drop non employees				
						keep if sitprof==3  
						
						*keep nbhors>0				
						keep if hnormais>0
						
						* headcount: number of employees with at least one month of tenure- this will be latter used during the collapse command 			
						gen headcount=(present==1) if dtadm<ym(20`year',9) 
			
						
						**** define new Hires
						
						*** First step: construct indicators for presence and absence in the same plant for the current and the previous year
						
						* First: merge to the current year (T) data from the previous year (T-1) based on id of worker, plant and firm
						preserve
							local year_1=`year'-1

							use ../dta/QP/year`year_1'/FUAQP`year_1'_1, clear	
							*if 2 digit occupation 
							if "`pcs'"=="pcs2d" {
									drop pcs
									rename  prof2d_cpp10 pcs	
							}
							*again only consider employees - drop non employees				
							keep if sitprof==3  
							
							*again only consider people working more then 0 hours 	
							keep if hnormais>0
							compress
							
							tempfile prevyear
							save `prevyear', replace
						restore
						
						*merge T with T-1
						merge 1:1 ident_s siren nic ano using `prevyear', gen(_mergeprevyear)

						
						
						* Construction of indicators for presence in October of the current year and absence in October of the previous year
						* And with at least one month of tenure
						ge P0=present!=. if dtadm<ym(20`year',9) 
						ge A1=present_1==. 
						
						*** second step: construct indicators of absence in the firm for the previous year (according to the definition of new hires according to month/year concept)
						egen minA1=min(A1), by(ident_s `aggregate')
						
						*** third step: effectively define new hires
						gen Hire=(P0==1&minA1==1)
							disp `x' " 2 "
							
						*keep industries
						keep if (CAEST2>=5 & CAEST2<=82) | CAEST2==90 | (CAEST2>=92 & CAEST2<=96)
						
						* cleanup occupation data
						if "`pcs'"=="pcs4" drop if pcs=="R999"
						
						if "`pcs'"=="pcs2d" drop if pcs=="R9"
						drop if mi(pcs)
						
						preserve
						* collapsing at the local labour market level
						collapse (sum) Z_E=Hire headcount Z_P0=P0, by(`zone' pcs)
						
						sort `zone' pcs
						*creating a temporary file for aggregate variables
						tempfile QP_P_pcs
						save `QP_P_pcs' , replace
						
							***** Part II: compute new hires at  the firmXyear level
						restore
						
						*collapse at the firm level
						collapse (sum) Hire P0, by( `aggregate' `zone' pcs)
						
						* merge with local labour market aggregates
						merge m:1 `zone' pcs using `QP_P_pcs'
						
						* squared shares of new hires
						gen Share_E=(Hire/Z_E)^2
						gen EmpH=(P0/Z_P0)^2
						
						* drop further errors in the occupation and geographical variables, if any
						drop if pcs==""
						drop if `zone'==""
						
						* set a counter of the number of hiring firms
						gen nb_Dm=1 if Hire!=.&Hire!=0
						* set a counter for employing firms
						ge nb_E=1 if P0!=.&P0!=0
						* aggregating at the LLM level and setting a year counter
						ge Hmax=sqrt(Share_E)
						ge Emax=sqrt(EmpH)
						
						collapse (sum) nb_Dm nb_E Share_E EmpH (mean) Z_E headcount Z_P0 (max) Hmax Emax, by(`zone' pcs)
						
						gen year=`a'
						if "`pcs'"=="pcs2d" rename  pcs pcs_2d
						
						* append to previous years, if any
						append using ../dta/HHI/HHI`x'_HP`aggregate'`zone'_`pcs'`m'
						* saving
						drop if year==.
						
						*if 2 digit occupation 
						if "`pcs'"=="pcs2d" {
							foreach var of varlist nb_Dm nb_E Share_E EmpH Z_E headcount Z_P0 Hmax Emax {
								rename `var' `var'_2d
							} 						 																	
						}

									
						save ../dta/HHI/HHI`x'_HP`aggregate'`zone'_`pcs'`m', replace
					}
				}
			}	
		}
	}
}


***** CREATING HHI FILES FOR FUA1 (that is nested in FUAX)


* creating fua1 files
local aggregateL siren sircomt
local pcsD  pcs4 pcs2d 

foreach m of numlist 1/1 {
	foreach x of numlist 2/2 {
		foreach aggregate of loc aggregateL {
				foreach pcs of loc pcsD {
					use ../dta/HHI/HHI`x'_HP`aggregate'fuaX_`pcs'`m', clear
					sort fuaX
					** the next line will merge the HHI data with the file containing the crossalk between FUAX and FUA1 and FUA2
					merge m:1 fuaX using ../dta/nested_fua
					drop if _m==2
					drop _m
					drop if fua1==""
					drop fuaX
					save ../dta/HHI/HHI`x'_HP`aggregate'fua1_`pcs'`m', replace
				}
		}
	}
}
		
clear 
cap log c

log using ../log/IVconstruction.log, replace

** SECOND LOOP: CONSTRUCTION of  INSTRUMENTS

*HHI2: month/year concept - only applicable to PORTUGAL
local aggregateL siren sircomt
local zoneL fuaX dep fua1
local pcsD  pcs4 pcs2d 

foreach m of numlist 1/1 {
	foreach x of numlist 2/2 {
		foreach zone of loc zoneL {
			foreach aggregate of loc aggregateL {
				foreach pcs of loc pcsD {
						* create an empty set
					clear
					ge pi=.
					* need to create new HHIIV folder
					save ../dta/HHI_IV/FIN_HHI`x'_HP`aggregate'`zone'_`pcs'`m', replace
					
					use  ../dta/HHI/HHI`x'_HP`aggregate'`zone'_`pcs'`m', clear // HHI database
					* create macro with the list of areas and loop around them
					levelsof `zone', loc(listzone)
					foreach geo of loc listzone {
						disp "`geo'"
						use  ../dta/HHI/HHI`x'_HP`aggregate'`zone'_`pcs'`m', clear // HHI database
						* keep only other areas
						drop if `zone'=="`geo'"
						
						* instruments
						ge IV_mH=log(1/nb_Dm) // log 1/N of hiring firms
						ge IV_mE=log(1/nb_E) // log 1/N employing firms
						ge IV_S=log(Share_E) // log HHI
						* averaging across areas
						collapse IV_*, by(pcs year)
						* recreating the identifier for the previosly dropped area (necessary for merging in the regression)
						ge `zone'="`geo'"
						* append areas one by one
						append using ../dta/HHI_IV/FIN_HHI`x'_HP`aggregate'`zone'_`pcs'`m'
						cap drop pi
						compress
						sort `zone' pcs year
						*if 2 digit occupation 
						if "`pcs'"=="pcs2d" {
							foreach var of varlist IV_mH IV_mE IV_S {
								rename `var' `var'_2d
							} 
								
						}
						save ../dta/HHI_IV/FIN_HHI`x'_HP`aggregate'`zone'_`pcs'`m', replace
					}
				}
			}
		}
	}
}



cap log c
clear
					
******************************************************************************************
******************************************************************************************
******************************************************************************************
******************	Computing HHI as in Arnold (2021)
******************************************************************************************
******************************************************************************************
******************************************************************************************


****************************************************************
*******************  Transition Prob (Arnolds HHI) ************
****************************************************************

cap log c
log using ../log/probtransition.log, replace

*** until 6th step we can work with regressions dataset

global panel = "PanelbaseFUA.dta"
global year= "year"
global maxyear = 2019
global maxyear1 = $maxyear1 - 1
global minyear = 2010
global newminyear = 2011



***** Preliminary step: construct a variable identifying new hires
use ../dta/PanelbaseFUA.dta, clear

*absent year before

ge P1m = 1


collapse (max) P1m, by(nninouv sircomt year)
* create a numeric variable for the year (will be used for merging)
gen an=year
* lagging one year
replace an=an+1
drop if an==$maxyear +1

* renaming variables for each level of aggregation
rename P1m P1msircom
sort nninouv sircomt an
save P1sircom_arnold, replace


collapse (max) P1m, by(nninouv an)
rename P1m P1m
sort nninouv an
save P1_arnold, replace


***** Second reliminary step: construct a variable identifying workers absent/present year after

use ../dta/PanelbaseFUA.dta, clear
ge PFm=1
 
collapse (max) PFm, by(nninouv sircomt year)
* create a numeric variable for the year (will be used for merging)
gen an=year
* lagging one year
replace an=an-1
drop if an==$minyear
rename PFm PFmsircom

sort nninouv sircomt an
save PFsircom_arnold, replace
collapse (max) PFm, by(nninouv  an)
rename PFm PFm
sort nninouv an
save PF_arnold, replace




***** First step: create a database with variabes for observation at t and t-1 (to avoid tsetting)
use ../dta/PanelbaseFUA.dta, clear

gen an=year
replace an=an+1
drop if an>=$maxyear

*** first condition for identification of main job: main job one year ago should be at least 9 months duration
keep if dtadm<ym(year,1)

rename pcs pcs_1
gen nbheur_1=hnormais+hextra
rename rganho netnet_1

keep an sircomt nic nninouv pcs_1 nbheur_1 netnet_1

keep if regexm(pcs,"^[0-9][0-9][0-9][0-9]")
drop if mi(pcs)

sort nninouv sircomt nic an
save indiv_origin, replace

* merging with variable containing current job matches

use ../dta/PanelbaseFUA.dta, clear

gen an=year
drop if an== $minyear

keep if dtadm<ym(year,9)

* keep industries
					
					destring apet2, replace					
					keep if (apet2>=5 & apet2<=82 )| apet2==90 | (apet2>=92 & apet2<=96)
	
sort nninouv sircomt an 
merge m:1 nninouv sircomt an  using P1sircom_arnold
drop if _m==2
drop _m

					sort nninouv an
					merge m:1 nninouv an using P1_arnold
					drop if _m==2
					drop _m
					ge Hirem=(P1msir!=1) 
					ge Emp1=(Hirem*P1m==1)

* find stayers the year after

drop if an==$maxyear1+1
sort nninouv sircomt an
merge m:1 nninouv sircomt an using PFsircom_arnold
drop if _m==2
drop _m
keep if reg_dur==1
keep if PFm==1


* renaming some variables
gen nbheur=hnormais+hextra
rename rganho netnet

					
* merging with records of the previous year

sort nninouv nic sircomt an 
merge 1:1 nninouv nic sircomt an using indiv_origin				
ren _m mergeorigin
					
* saving a temporary file containing, on the same line, 
save temp_t, replace


*** second step: identifying the main job previous year among those with at least 30 days duration
* looping over years
foreach y of numlist 2011 / 2018 {
	use temp_t, clear

	ge p1=1 


	* making dataset smaller
	

		*If there is only 1 observation for a given identifier then we cannot observe occupational mobility 	
		bysort nninouv: gen N=_N
		keep if N>1	
		drop N
	
	quietly des
	display "`r(N)'"
	* second condition: pick that with the same occupation, if there is any
	ge occorigin=""
	levelsof pcs_1, local(pcs)

	foreach p of local pcs {
		disp `y' "  `p'"
		ge p1_`p'=(pcs_1=="`p'")
		egen maxp1_`p'=max(p1_`p'), by(nninouv )
		replace occorigin="`p'" if pcs =="`p'"&maxp1_`p'==1
		drop p1_`p' maxp1_`p'
	}
	
	* indicators for max duration, max hours (if same duration) and max salary (if same duration and hours)
	egen maxh=max(nbheur_1)	, by(nninouv )
	egen maxw=max(netnet_1)	if abs(maxh-nbheur_1)<1, by(nninouv )
	
	** NOTE: in order to "transfer" the occupation of origin from one job match the year before to a current one, I use the operator "mode"
	* which works also for alphanumeric variables
	
	
	* third condition: among ties, pick the one with the longest hours, if there are no new ties 
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* fourth condition: among the new ties, pick the one with the highest salary, if there are no new ties
	* (occmode, tag, tag2 & mode play the same role as before)
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1
	duplicates tag nninouv if occmode!="", ge(tag)
	duplicates tag nninouv occmode if occmode!="", ge(tag2)
	egen mode=mode(occmode) if tag==tag2, by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode tag tag2
	
	* 	fifth condition: among the new ties, pick the most frequent, if there are no new ties
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin==""
	egen mode=mode(occmode), by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode

	* 	sixth  condition: among the new ties, pick one at random
	set seed 1
	ge u=runiform()
	ge d=abs((_n/_N)-u)
	egen mind=min(d) if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&occorigin=="", by(nninouv )
	ge occmode=pcs_1 if abs(maxh-nbheur_1)<1&abs(maxw-netnet_1)<1&abs(mind-d)<0.00000001&occorigin==""
	egen mode=mode(occmode), by(nninouv )
	gen a=mode!=""
	tab a
	tab a if occorigin==""
	drop a
	replace occorigin=mode if occorigin==""
	drop mode occmode
	
	quietly des
	display "`r(N)'"	
** cleaning up (normally not needed)
	keep if pcs!=""
	keep if occorigin!=""
	
	compress
	
	save temp_t`y', replace
	
}


*** third step: construct a squared matrix of occupation
use ../dta/HHI/HHI2_HPsircomtfuaX_pcs41, clear
collapse (sum) Z_P0, by(pcs )
ge one=1
ren Z_P0 Z_P00
sort one
save pcs_list, replace
ren pcs occorigin
ren Z_P0 Z_P01
sort one
joinby one using pcs_list
keep pcs occorigin Z_P01 Z_P00
sort pcs occorigin
save pcs_squared, replace


*** fourth step: transition probabilities and factors (that is relative probabilities divided by relative # of employment)

* create a frequency dataset by current and previous year occupations (main job only as defined above for previous year) 
clear
set obs 1
ge v1=.
save tprob, replace

foreach y of numlist 2011 / 2018 {
	use temp_t`y', clear
	collapse (sum) p1, by(occorigin pcs )
	replace p1=0 if p1==.
	ge year="`y'"
	append using tprob
	save tprob, replace

	
}

drop if p1==.

* summing frequency over years
collapse (sum) p1, by(pcs occorigin)
label var p1 "frequency of occupation couple"
sort pcs occorigin
merge 1:1 pcs occorigin using pcs_squared
drop if _m==1
replace p1=0 if p1==.
* marginal distributions
egen den1=total(p1), by(occorigin) // occupation year before
egen den0=total(p1), by(pcs ) // occupation current year
* probability of a given occupation the year before conditional on the occupation of origin
ge prob=p1/den1
replace prob=0 if prob==.
* probability of remaining in the same occupation conditional on the occupation of origin
ge tden=prob if occorigin==pcs
* reporting the probability of remaining in the same occupation conditional on the occupation of origin to all couples with same occorigin
	egen den=max(tden), by(occorigin)
* relative probability (as in Arnold's formula	
ge relprob=prob/den
* relative factor (as in Arnold's: (Prob_m_to_k/Prob_m_to_m)/(E(Lk/ELm)
* assumption E(Lk/ELm) in Arnold can be approximated by Z_P00/Z_P01
ge relfactor=relprob*(Z_P01/Z_P00)
drop den tden den1 den0 Z_P00 Z_P01 _m
sort pcs
	compress
save tprob, replace	
	

* fifth step: denominators of shares

foreach y of numlist 2011 / 2019 {
use ../dta/HHI/HHI2_HPsircomtfuaX_pcs41, clear
keep if year ==`y'
keep pcs fuaX year Z_P0
sort pcs
joinby pcs using tprob
ge Z_P0prob=Z_P0 * relprob
ge Z_P0factor=Z_P0 * relfactor
ge one=(pcs ==occorigin)
ge Z_P1 = Z_P0 * one
collapse (sum) Z_P0p Z_P0f Z_P1, by(occorigin fuaX year)
ren occorigin pcs
compress
sort pcs fuaX year
save ArnDen`y', replace 

}


log close
log using ../log/probtransition_6thstep.log, replace

* sixth step: numerator of shares and final calculation

				clear
						* create an empty dataset
						gen year=""
						save ../dta/HHI/ArnoldHHI, replace 
						
					foreach year of numlist 2011 / 2019 {
					
					
					disp   "`year'"
					local year2=substr("`year'", 3, 2)
				
					***** Part I: compute aggregates at the `zone'XpcsXyear (geo area by occupation by year) level
					use ../dta/QP/year`year2'/FUAQP`year2', clear
					

					
					keep if ano==`year'
					
						*other filters for the computation of HHIs (e.g. drop interns) 
					keep if sitprof==3 	
				
					*keep nbhours>0
					keep if hnormais>0 

					
				**** define new Hires and employment
				
				*** First step: construct indicators for presence and absence in the same plant for the current and the previous year
				
				* I will first merge to the current year data from the previous year based on id of worker, plant and firm
				preserve
				local year_1=`year2'-1

				use ../dta/QP/year`year_1'/FUAQP`year_1'_1, clear	
				*again only consider employees - drop non employees				
				keep if sitprof==3  
				*again only consider people working more then 0 hours - keep nbhors>0				
				keep if hnormais>0
				compress
				tempfile prevyear
				save `prevyear', replace
				restore
				
				merge 1:1 ident_s siren nic ano using `prevyear', gen(_mergeprevyear)

					* for consistency with French code:
					ren ident_s nninouv

				
				
				* Construction of indicators for presence in October of the current year and absence in October of the previous year
				* And with at least one month of tenure
				ge P0=present!=. if dtadm<ym(20`year2',9) 
				ge A1=present_1==. 
				
				*** second step: construct indicators of absence in the firm for the previous year (according to the different defimitions in cases 1, 2 and 3 - se just above)
				egen minA1=min(A1), by(nninouv sircomt)
				
				*** third step: effectively define new hires
				gen Hire=(P0==1&minA1==1)
					
				*keep industries
				keep if (CAEST2>=5 & CAEST2<=82) | CAEST2==90 | (CAEST2>=92 & CAEST2<=96)
				
				* cleanup occupation data
				drop if pcs=="R999"
				drop if mi(pcs) 	
					
						* collapse at the firm level
						collapse (sum) P0, by(sircomt fuaX pcs)
						
	
						* compute the total number of firmXmunicipalities
						preserve
						collapse P0, by(sircomt fuaX)
						drop P0
						ge number=_n
	
						sort sircomt fuaX
						save sf, replace
						restore
						
						sort sircomt fua
						merge m:1 sircomt fuaX using sf
						drop _m
						
						
						*** create an indicator for block-by-block joinby
						ge N=floor(number/10000) 
						drop number
						sum N
						global max=r(max)+1
						disp $max
						
						compress
						save P0_`year', replace
							
				*looping over occupations (1st digit) to compute empty datasets to be used for the numerator of shares


					foreach pcs1 of numlist 1/9 {	
				
				disp "`pcs1'"
					* compute 
					clear
					set obs 1
					ge v1=1
					compress
					save ArnNum`year'`pcs1', replace
				}	
				* looping blocks of firmXmunicipality and 1 digit occupations (to avoid too large intermediate datasets)
				* and compute Arnold's numerators of shares
					local x=0	
					while `x' < $max {
						disp `x'
			
										
						use P0_`year', clear
							keep if N==`x'
							sort pcs
						
						*joinby transition probabilities
						joinby pcs using tprob
						
						* compute numerator of shares
						
						* brick to construct Arnold's shares
						ge Hfactor=P0*relfactor
						* alternative way using only relative probabilities
						ge Hprob=P0*relprob
						* brick to construct standard HHI (to check consistency)
						ge one=(pcs ==occorigin)
						ge H1 = P0*one

						* computing numerator of shares as weighted sums (as in Arnold)
						collapse (sum) Hp Hf H1, by(sircomt occorigin fuaX )
						ren occorigin pcs
						drop if Hfactor==0
						drop if fuaX ==""
						
						*appending (looping on occupations - again to avoid too large datasets) 
						compress
					foreach pcs1 of numlist 1/9 {	
										disp "`pcs1'"
 
						preserve
						keep if substr(pcs ,1,1)=="`pcs1'"

						append using ArnNum`year'`pcs1'
						sort pcs fuaX				
						save ArnNum`year'`pcs1', replace
						restore
					}
									local x = `x'+1					
						
						}
					* looping over 1 digit occupations to compute final Arnold's HHI
					foreach pcs1 of numlist 1/9 {	
										disp "`pcs1'"
										
						use ArnNum`year'`pcs1', clear				
						drop if v1==1
					
					
					* merge with local labour market Arnold aggregate denominators
						merge m:1 pcs fuaX using ArnDen`year'
						keep if _m==3

					* squared shares of employment using Arnold factors	
						gen HHI_A=(Hfactor/Z_P0factor)^2
					* squared shares of employment using Arnold probabilities	
						gen HHI_a=(Hprob/Z_P0prob)^2
						
					* check term
						gen HHI_H=(H1/Z_P1)^2

						
					* drop further errors in the occupation and geographical area variables, if any
						drop if pcs ==""
						drop if fuaX ==""
		
				* calculating HHI by summing up squared shares
				collapse (sum) HHI_a HHI_A HHI_H, by(fuaX pcs)

						gen year="`year'"
						
					* append to previous years, if any
						append using ../dta/HHI/ArnoldHHI
					* saving
						drop if year==""
						
						label var HHI_A "Arnold's HHI"
						label var HHI_H "Standard HHI" // you might want to compare these values with those that you have already used in the regressions (they should be the same)
						
						save  ../dta/HHI/ArnoldHHI, replace 
						
						erase ArnNum`year'`pcs1'.dta
						
					}
				}

				log close					
					