******************************************************************************************
*
*			
*		do-file:
*					this programme produces the results for Portugal that are presented in the manuscript
*
*	Wage regressions:		Table 2 	   	  – results from regression in line 171 of this do-file
*	(lines 29 to 355)    	Table 3 		  – results from regression in line 197 (col 1), 202 (col 2), 207 (col 3), 212 (col 4) of this do-file
*							Footnote 31       – results from regression in line 255 and 260 of this do-file
*							Table 4 		  – results from regression in line 230 (panel A) and 238 (panel B) of this do-file
*							Table 5 		  – results from regression in line 254 of this do-file
*							Figure 1, panel a – results from regression in line 277 of this do-file
*					 		Figure 2, panel a – results from regression in line 298 of this do-file
*					 		Figure 3, panel a – results from regression in line 318 of this do-file
*					 		Figure 4, panel a – results from regression in line 342 of this do-file
*
*  Contract regressions:	Table 6 		  – results from regression in line 500 of this do-file
*	(lines 356 to 616) 		Table 8 		  – results from regression in line 515 (column 1) and 520 (column 2) of this do-file
*							Figure 1, panel b – results from regression in line 540 of this do-file
*					 		Figure 2, panel b – results from regression in line 560 of this do-file
*							Figure 3, panel b – results from regression in line 579 of this do-file
*							Figure 4, panel b – results from regression in line 602 of this do-file
*					 
******************************************************************************************
set more off
cap log c
log using ../log/Table1to5_Figure1to4panelA.log, replace

************************************************************************************
*********************** WAGE REGRESSIONS - lines 29 to 356 *************************
************************************************************************************


* the following big loop runs the wage regressions for
* category of hiring == 2: month/year concept 
* each different type of firm identifiers (firm, firmXmunicipality)
* each different type of geographical areas 

* the macro aggregateL include the list of type of identifiers (firm or firmXmunicipality)
* the macro zoneL include the list of type of geographical areas (fuaX, dep, or fua1)


local aggregateL  sircomt    // Main results use the firmXmunicipality identifier (see Appendix do files for the appendix results which use alternative firm identifiers)
local zoneL  fuaX 			// Main results use Functional Areas (fuaX) as geographical area (see Appendix do files for the appendix results which use alternative geo areas)
local wagevar wage_g_ft_m wage_g_ft wage_g	// Main results use monthly wage for fulltimers (wage_g_ft_m) or daily wages of fulltimers (wage_g_ft) or daily wages for all employees (wage_g) 

foreach var of loc wagevar   {				
		foreach y of loc aggregateL {	
			foreach zone of loc zoneL {		
				foreach x of numlist 2/2 { 			// x regards type of hiring concept here (2= month/year).

				
		
					* input data
					use prewage_compact, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "`var' HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"

					disp "*********************************************************************"
					disp "******************* DATA LOAD & PREPARATION: final steps ************"
					disp "*********************************************************************"
					
					* when monthly wage for fulltimers (wage_g_ft_m) or daily wages of fulltimers (wage_g_ft) is the dep variable, keep only full time employees
					if "`var'"=="wage_g_ft" |"`var'"=="wage_g_ft_m" {
						keep if ftpt==1
					}

					
					* merge with presence previous year
					if "`y'"=="siren" {
						sort nninouv sir an
						merge m:1 nninouv sir an using P1siren, gen(_m3)
						drop if _m3==2
						drop _m3
					}
					if "`y'"=="sircomt" {
						sort nninouv sircom sir an
						merge m:1 nninouv sircom sir an using P1sircom, gen(_m3)
						drop if _m3==2
						drop _m3
					}
	
					*drop P1m   
					sort nninouv an
					merge m:1 nninouv an using P1, gen(_m3)
					drop if _m3==2
					drop _m3

					* generate indicators for being new hire and employed the year before (if new hire)	Question

					* using the month/year concept, then one would define new hires as
					ge Hirem=(P1msir!=1) 
					ge Emp1=(Hirem*P1m==1)
					
					drop P1*
	
					* merge with HHI data
					sort `zone' pcs year			
					merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41 , gen(_m3)	
					keep if _m3==3
					drop _m3	
					* drop useless variables
					drop nb_E EmpH Z_P0 Hmax Emax
					
					* define logarithm of HHI
					ge logShare_E=log(Share_E)
*
					* merge with simple instruments
					merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs41	, gen(_m3)	
					drop if _m3==2
					drop _m3
					ren IV_S IV_HHI
					
					if "`var'"=="wage_g_ft_m" {
					
					* merge with collective barganing measure at industry-level
						merge m:1 apet2 using ../dta/idustry_share_cba
						drop if _m==2
						drop _m
					}
					
					compress
					
					* redefinition of the certain fixed effects and the clustering variable (according to the correct geographical area
					if "`zone'"=="dep" {
						replace geo=nuts
						replace cluster=cluster2
					}
						if "`zone'"=="fua1" {
						replace geo=fua1_n
						replace cluster=cluster3
					}		
					
					* educ variable
					gen educ=.
					replace educ=1 if habil1==1 | habil1==2 // educ_bel_upsec
					replace educ=2 if habil1==0 | habil1==3 //educ_upsec
					replace educ=3 if habil1>=4 & habil1<=8 //educ_ab_upsec
					replace educ=. if habil1==9 | habil1==. //educ_missing
					
					/* List of interest variable and instruments
					logShare_E: log HHI
					Instruments:
					IV_mH based on log number of hiring firms in other regions same occupation
					IV_mE based on log number of employing firms in other regions same occupation
					IV_HHI based on log HHI in other regions same occupation 
					*/
					
					
					disp "*********************************************************************"
					disp "******************* REGRESSIONS *************************************"
					disp "*********************************************************************"
					
					* Model: individual, LLM, firmXmunicipalityXyear, plant and individual age fixed effects	
										
				
					
					disp "******************* IV Models **************************************"
					
					 
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2: Labor market concentration and daily wages of full-timers – IV estimates. -----------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {

						global fixed = "id occ#geo firm#mun#an firm#nic age"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
					}
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 3, panel b: Labor Market Concentration and daily wages of full-timers as a function of collective bargaining coverage – IV estimates. --"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"					
					if "`var'"=="wage_g_ft_m" {
					
						*gen interaction with collective barganing
						foreach z of varlist logShare_E IV_mH {
							ge CB1_1_apet2_coarse`z'=CB1_1_apet2_coarse*`z'
							ge CB2_1_apet2_coarse`z'=CB2_1_apet2_coarse*`z'
							ge CB3_1_apet2_coarse`z'=CB3_1_apet2_coarse*`z'
							ge CB1_2_apet2_coarse`z'=CB1_2_apet2_coarse*`z'
							ge CB2_2_apet2_coarse`z'=CB2_2_apet2_coarse*`z'
							ge CB3_2_apet2_coarse`z'=CB3_2_apet2_coarse*`z'
						}					

						disp "----------- Column 1: Coverage share, Any CBA ---------------------------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1  (logShare_E CB1_1_apet2_coarselogShare_E=IV_mH CB1_1_apet2_coarseIV_mH)  , 		absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )

						disp "----------- Column 2: High coverage dummy, Any CBA  --------------------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1   (logShare_E CB1_2_apet2_coarselogShare_E=IV_mH CB1_2_apet2_coarseIV_mH)  , 	absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
									 
						disp "----------- Column 3: Coverage share, Sector CBA  --------------------------------------------"											
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1  (logShare_E CB2_1_apet2_coarselogShare_E=IV_mH CB2_1_apet2_coarseIV_mH)  , 		absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
						
						disp "----------- Column 4: High coverage dummy, Sector CBA  --------------------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1  (logShare_E CB2_2_apet2_coarselogShare_E=IV_mH CB2_2_apet2_coarseIV_mH)  , 		absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
						
						disp "----------- footnote 31: Coverage share, Sector and Firm CBA  -------------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1  (logShare_E CB2_1_apet2_coarselogShare_E CB3_1_apet2_coarselogShare_E=IV_mH CB2_1_apet2_coarseIV_mH CB3_1_apet2_coarseIV_mH)  , absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
						
						disp "----------- footnote 31: High coverage dummy, Sector and Firm CBA  -----------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1   (logShare_E CB2_2_apet2_coarselogShare_E CB3_2_apet2_coarselogShare_E=IV_mH CB2_2_apet2_coarseIV_mH CB3_2_apet2_coarseIV_mH)  , absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
						}
	
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 4: Labor market concentration and hourly wages – IV estimates. -------------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					
					disp "----------- Panel A: Full-Timers ---------------------------------------------------"
					
					if "`var'"=="wage_g_ft" {
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y'"
					disp "IV_mH"
					ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
					}
					disp "----------- Panel B: All employees ---------------------------------------------------"
					
					if "`var'"=="wage_g" {
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y'"
					disp "IV_mH"
					ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 )
					}				
							
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 5: Labor market concentration and daily wages of full-timers – New hires vs incumbents – IV estimates. ---------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {
	
						* Gen new Hire interaction
						foreach z  of varlist logShare_E IV_mH  {
							ge H`z' = Hire*`z'
						}
						
						global fixed = "id occ#geo firm#mun#an firm#nic age"
						disp "`var' `zone' `y' MODEL 1Hires"
						disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1 (logShare_E HlogShare_E =IV_mH HIV_mH),   absorb($fixed)  cluster(cluster)  partial( ftpt Hire Emp1 )
						test logShare_E + HlogShare_E =0 // this serves to compute the estimates that show absolute effects for incumbents/new hires
					}								
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 1, panel A: Effect of labor market concentration by gender --------------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {
						
						* gen gender interaction	
					destring sx, replace
					recode sx(2=0) // sx=1 for men and sx =2 for women recode so that sx=0 for woman
					gen man=sx==1
					gen woman=sx==0
						foreach z of varlist logShare_E IV_mH {
							ge W`z'=woman*`z'
							ge Man`z'=man*`z'
						}						
					
					*Model with an interaction HHI X dummy for being woman
							
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y' MODEL 1Gender"
					disp "IV_mH"
						ivreghdfe `var' ftpt Hire Emp1 (ManlogShare_E WlogShare_E=ManIV_mH WIV_mH),   absorb($fixed)  cluster(cluster)  partial( ftpt Hire Emp1 )
							test ManlogShare_E - WlogShare_E =0 
					}				
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 2, panel A: Effect of labor market concentration by age group -----------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {

					*gen youth interaction
					ge young=(age<=24&age!=.)
					gen old=(young==0 &age!=.)
						foreach z of varlist logShare_E IV_mH {
							ge Y`z'=young*`z'
							ge Old`z'=old*`z'
						}
						
					*Model an interaction HHI X dummy for being below 25
							
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y' MODEL 1Youth"
					disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 (OldlogShare_E YlogShare_E=OldIV_mH YIV_mH),  absorb($fixed)  cluster(cluster)  partial( ftpt Hire Emp1 )
								test OldlogShare_E - YlogShare_E =0 // this serves to compute the estimates that show absolute effects for young/old
					}	
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 3, panel A: Effect of labor market concentration by nationality ---------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {
					*gen Nat interaction
					ge PT= nacio=="PT"
					ge FR= PT==0
						foreach z of varlist logShare_E IV_mH {
							ge PT`z'=PT*`z'
							ge FR`z'=FR*`z'
						}
					*Model with an interaction HHI X dummy for being Portuguese or Foreign
												
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y' MODEL Nationality"
					disp "IV_mH"

					ivreghdfe wage_g_ft_m  ftpt Hire Emp1 (PTlogShare_E FRlogShare_E=PTIV_mH FRIV_mH),   absorb($fixed)  cluster(cluster)  partial( ftpt Hire Emp1 )
												test PTlogShare_E - FRlogShare_E =0 
					}			
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 4, panel A: Effect of labor market concentration by education  ----------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					if "`var'"=="wage_g_ft_m" {
					

					*gen Educ interaction
					ge educH=educ==3 | educ==2 
					ge educL=educH==0
					foreach z of varlist logShare_E IV_mH {
						ge EdH`z'=educH*`z'
						ge EdL`z'=educL*`z'
					}
					
	
					*Model an interaction HHI X dummy for having upper and above upper secondary education
												
					global fixed = "id occ#geo firm#mun#an firm#nic age"
					disp "`var' `zone' `y' MODEL 2EDUC"
					disp "IV_mH"

					ivreghdfe wage_g_ft_m  ftpt Hire Emp1 (EdHlogShare_E EdLlogShare_E=EdHIV_mH EdLIV_mH),   absorb($fixed)  cluster(cluster)  partial( ftpt Hire Emp1 )
												test EdHlogShare_E - EdLlogShare_E =0 
					
					
					}
				}
			}
		}
}



log close
clear


set more off 

cap log c
log using ../log/Table6to8_Figure1to5_panelB.log, replace

************************************************************************************
*********************** CONTRACT REGRESSIONS
************************************************************************************


* FULL SAMPLE

* the following big loop runs the contract regressions for
* category of hiring == 2: month/year concept 
* each different type of firm identifiers (firm, firmXmunicipality)
* each different type of geographical areas 

* the macro aggregateL include the list of type of identifiers (firm or firmXmunicipality)
* the macro zoneL include the list of type of geographical areas (fuaX, dep, or fua1)
* please refer to the data construction programmes for the description of the variables

local aggregateL  sircomt  
local zoneL fuaX   
local variable perm_m


foreach x of numlist 2/2 { 					// x regards type of hiring concept here (2= month/year).
		foreach zone of loc zoneL {		
			foreach y of loc aggregateL {
				foreach var of loc variable { 
				
				* input data
					use precontract_compact, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					
					
					disp "*********************************************************************"
					disp "******************* DATA LOAD & PREPARATION: final steps ************"
					disp "*********************************************************************"
					
					*merge with presence previous year 
					if "`y'"=="siren" {
						sort nninouv sir an
						merge m:1 nninouv sir an using P1siren
						drop if _m==2
						drop _m
					}
					if "`y'"=="sircomt" {
						sort nninouv sircom sir an
						merge m:1 nninouv sircom sir an using P1sircom
						drop if _m==2
						drop _m
					}
	
					
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					* generate indicators for being new hire (year and month/year definitions)	
					ge Hirem=(P1msir!=1)
					keep if Hirem==1
					* generate indicators for at work if new hire (year and month/year definitions)	
					ge Emp1=(Hirem*P1m==1)

					drop P1msir
	
					* merge with HHI
					sort `zone' pcs year			
					qui merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41	
					keep if _m==3
					drop _m	
					* drop useless variables
					drop nb_E EmpH Z_P0 Hmax Emax
					
					* log HHI
					ge logShare_E=log(Share_E)
*
					* merge with simple instruments
					qui merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs41	
					drop if _m==2
					drop _m
					ren IV_S IV_HHI

					* merge with collective barganing measure at industry-level
					merge m:1 apet2 using ../dta/idustry_share_cba
					drop if _m==2
					drop _m
					
					compress
					
					* redefine geo fixed effects and cluster variable if necessary
						if "`zone'"=="dep" {
						replace geo=nuts
						replace cluster=cluster2
					}
						if "`zone'"=="fua1" {
						replace geo=fua1_n
						replace cluster=cluster3
					}		
					recode sx(2=0) // sx=1 for men and sx =2 for women recode so that sx=0 for woman
										
				
					gen educ=.
					replace educ=1 if habil1==1 | habil1==2 // educ_bel_upsec
					replace educ=2 if habil1==0 | habil1==3 //educ_upsec
					replace educ=3 if habil1>=4 & habil1<=8 //educ_ab_upsec
					replace educ=4 if habil1==9 | habil1==. //educ_missing
																			
					/* List of interest variable and instruments
					logShare_E: log HHI
					Instruments:
					IV_mH based on log number of hiring firms in other regions same occupation
					IV_mE based on log number of employing firms in other regions same occupation
					IV_HHI based on log HHI in other regions same occupation
					*/
					
					disp "*********************************************************************"
					disp "******************* REGRESSIONS *************************************"
					disp "*********************************************************************"
					
					disp "******************* IV Models **************************************"
					
					* Model 1: LLM, firmXmunicipalityXyear, plant and individual age, educ and gender fixed effects, plus a dummy for open-ended the year before

					rename perm perm_m
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					global EO = "Emp1"
				
					disp "************ All new hires with temp contract in June, July, August  *********************"
					global sample = "if Hirem==1&dtadm>=ym(year ,6)&dtadm<=ym(year ,8)"					 
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 6: Labor market concentration and probability of being hired on a permanent contract – IV estimates – New hires only. ------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"

					disp "`var' `zone' `y' MODEL"
					disp "`z'"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH) $sample , 		absorb($fixed)  cluster(cluster) first partial(sx ftpt $EO )
					 					
					disp "-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 8: Labor market concentration and probability of being hired on a permanent contract as a function of collective bargaining coverage – IV estimate ------"
					disp "-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------"
					
						*gen interaction with collective barganing
						foreach z of varlist logShare_E IV_mH {
							ge CB2_1_apet2_coarse`z'=CB2_1_apet2_coarse*`z'
							ge CB2_2_apet2_coarse`z'=CB2_2_apet2_coarse*`z'
						}					
					
						disp "----------- Column 1: Coverage share, Sector CBA  --------------------------------------------"											
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' sx ftpt  $EO  (logShare_E CB2_1_apet2_coarselogShare_E=IV_mH CB2_1_apet2_coarseIV_mH) $sample , 		absorb($fixed)  cluster(cluster) 
						
						disp "----------- Column 2: High coverage dummy, Sector CBA  --------------------------------------------"
						disp "`var' `zone' `y'"
						disp "IV_mH"
						ivreghdfe `var' sx ftpt  $EO  (logShare_E CB2_2_apet2_coarselogShare_E=IV_mH CB2_2_apet2_coarseIV_mH) $sample , 		absorb($fixed)  cluster(cluster) 
							
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 1, panel B: Effect of labor market concentration by gender --------------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"						
					* gen gender interaction	
					destring sx, replace
					recode sx(2=0) // sx=1 for men and sx =2 for women recode so that sx=0 for woman
					gen man=sx==1
					gen woman=sx==0
						foreach z of varlist logShare_E IV_mH {
							ge W`z'=woman*`z'
							ge Man`z'=man*`z'
						}						
					
					*Model with an interaction HHI X dummy for being woman
							
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					disp "`var' `zone' `y' MODEL 1Gender"
					disp "IV_mH"
						ivreghdfe `var' sx ftpt $EO (ManlogShare_E WlogShare_E=ManIV_mH WIV_mH)  $sample , absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first
							test ManlogShare_E - WlogShare_E =0 
									
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 2, panel B: Effect of labor market concentration by age group -----------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"

					*gen youth interaction
					ge young=(age<=24&age!=.)
					gen old=(young==0 &age!=.)
						foreach z of varlist logShare_E IV_mH {
							ge Y`z'=young*`z'
							ge Old`z'=old*`z'
						}
						
					*Model an interaction HHI X dummy for being below 25
							
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					disp "`var' `zone' `y' MODEL 1Youth"
					disp "IV_mH"
					ivreghdfe `var' sx ftpt $EO (OldlogShare_E YlogShare_E=OldIV_mH YIV_mH)  $sample , absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first
								test OldlogShare_E - YlogShare_E =0 // this serves to compute the estimates that show absolute effects for young/old
						
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 3, panel B: Effect of labor market concentration by nationality ---------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					*gen Nat interaction
					ge PT= nacio=="PT"
					ge FR= PT==0
						foreach z of varlist logShare_E IV_mH {
							ge PT`z'=PT*`z'
							ge FR`z'=FR*`z'
						}
					*Model with an interaction HHI X dummy for being Portuguese or Foreign
												
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					disp "`var' `zone' `y' MODEL Nationality"
					disp "IV_mH"

					ivreghdfe `var' sx ftpt $EO (PTlogShare_E FRlogShare_E=PTIV_mH FRIV_mH)  $sample , absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first
												test PTlogShare_E - FRlogShare_E =0 
								
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Figure 4, panel B: Effect of labor market concentration by education  ----------------------------------------------------"
					disp "----------------------------------------------------------------------------------------------------------------------------------------"
					

					*gen Educ interaction
					ge educH=educ==3 | educ==2 
					ge educL=educH==0
					foreach z of varlist logShare_E IV_mH {
						ge EdH`z'=educH*`z'
						ge EdL`z'=educL*`z'
					}
					
	
					*Model an interaction HHI X dummy for having upper and above upper secondary education
												
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					disp "`var' `zone' `y' MODEL 2EDUC"
					disp "IV_mH"

					ivreghdfe `var' sx ftpt $EO (EdHlogShare_E EdLlogShare_E=EdHIV_mH EdLIV_mH)  $sample , absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first
												test EdHlogShare_E - EdLlogShare_E =0 
				
				}	
			}
		}
}




log close
clear
		
