******************************************************************************************
*
*			
*		do-file:
*					this programme produces the results for Portugal that are presented in Appendix 2
*
*
*	Wage regressions:		Table 2.1  – results from regression in line 228 of this do-file
*	(lines 37 to 436)    	Table 2.2  – results from regression in line 241 of this do-file
*							Table 2.3  – results from regression in line 251 of this do-file
*							Table 2.4  – results from regression in line 261 of this do-file
*							Table 2.5  – results from regression in line 296 of this do-file
*							Table 2.6  – results from regression in line 361 to 363 of this do-file
*							Table 2.8  – results from regression in line 376 of this do-file
*							Table 2.9  – results from regression in line 387 of this do-file
*							Table 2.10 – results from regression in line 398 of this do-file
*							Table 2.11 – results from regression in line 409 of this do-file
*							Table 2.12 – results from regression in line 420 of this do-file
*
*  Contract regressions:	Table 2.13 – results from regression in line 629 of this do-file
*	(lines 437 to 760) 		Table 2.14 – results from regression in line 641 of this do-file
*							Table 2.16 – results from regression in line 652 of this do-file
*							Table 2.17 – results from regression in line 662 of this do-file
*							Table 2.18 – results from regression in line 696 of this do-file
*							Table 2.20 – results from regression in line 707 of this do-file
*							Table 2.21 – results from regression in line 717 of this do-file
*							Table 2.22 – results from regression in line 727 of this do-file
*							Table 2.23 – results from regression in line 737 of this do-file
*							Table 2.24 – results from regression in line 748 of this do-file
*				 
******************************************************************************************
set more off

cap log c
log using ../log/Appendix2_Tables1to12.log, replace

************************************************************************************
*********************** WAGE REGRESSIONS - lines 37 to 436 *************************
************************************************************************************


* the following big loop runs the wage regressions for
* category of hiring == 2: month/year concept 
* each different type of firm identifiers (firm, firmXmunicipality)
* each different type of geographical areas (Functional Areas, NUTS-3 (districts for PT), and FUAs)

* the macro aggregateL include the list of type of identifiers (firm or firmXmunicipality)
* the macro zoneL include the list of type of geographical areas (fuaX, dep, or fua1)


local aggregateL  sircomt siren  
local zoneL  fuaX dep fua1		
local wagevar wage_g_ft_m	// Robustness checks only for monthly wage for fulltimers (wage_g_ft_m) 

foreach var of loc wagevar   {				
		foreach y of loc aggregateL {	
			foreach zone of loc zoneL {		
					foreach x of numlist 2/2 { // x regards type of hiring concept here (2= month/year).

							local TypeHHI  4digits 
							
							if "`y'"=="sircomt" &  "`zone'"=="fuaX" {
								local TypeHHI  4digits 2digits Arnold // Type of HHI that is used in the regression:
								*										1) the standard in the paper (LLM: 4 digit occupations by Fuax and HHI computed using share of new hires)
								*										2) LLM defined as 2 digit occupations by Fuax ; 3) HHI computed according to Arnold (2021)
							}
							
							foreach hhitype of loc TypeHHI { 			

			
						* input data
						use prewage_compact, clear

						disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
						disp "`var' HHI`x' `zone' `y'" 
						disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"

						disp "*********************************************************************"
						disp "******************* DATA LOAD & PREPARATION: final steps ************"
						disp "*********************************************************************"
						
						* when monthly wage for fulltimers (wage_g_ft_m) or daily wages of fulltimers (wage_g_ft) is the dep variable, keep only full time employees
						if "`var'"=="wage_g_ft" |"`var'"=="wage_g_ft_m" {
							keep if ftpt==1
						}

						
						* merge with presence previous year
						if "`y'"=="siren" {
							sort nninouv sir an
							merge m:1 nninouv sir an using P1siren, gen(_m3)
							drop if _m3==2
							drop _m3
						}
						if "`y'"=="sircomt" {
							sort nninouv sircom sir an
							merge m:1 nninouv sircom sir an using P1sircom, gen(_m3)
							drop if _m3==2
							drop _m3
						}
		
						*drop P1m   
						sort nninouv an
						merge m:1 nninouv an using P1, gen(_m3)
						drop if _m3==2
						drop _m3

						* generate indicators for being new hire and employed the year before (if new hire)	Question

						* using the month/year concept, then one would define new hires as
						ge Hirem=(P1msir!=1) 
						ge Emp1=(Hirem*P1m==1)
						
						drop P1*
		
						************************** merge with HHI data and instruments
						
						if "`hhitype'"=="4digits" {			// 4 digit HHI data
						*HHI
								sort `zone' pcs year			
								merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41 , gen(_m3)	
								keep if _m3==3
								drop _m3	
								* drop useless variables
								drop nb_E EmpH Z_P0 Hmax Emax
								
								* define logarithm of HHI 
								ge logShare_E=log(Share_E)  // share of new hires
								ge logEmpH=log(EmpH)		// share of employment
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs41	, gen(_m3)	
								drop if _m3==2
								drop _m3
								ren IV_S IV_HHI
						}
						
						if "`hhitype'"=="2digits" {			// 2 digit HHI data
						*HHI
								sort `zone' pcs year			
								merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs2d1 , gen(_m3)	
								keep if _m3==3
								drop _m3	
								
								* define logarithm of HHI 
								ge logShare_E=log(Share_E)  // share of new hires
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs2d1	, gen(_m3)	
								drop if _m3==2
								drop _m3
								ren IV_S IV_HHI
						}		
						
						if "`hhitype'"=="Arnold" {			// Arnold HHI data
						*HHI
							preserve
							use ../dta/HHI/ArnoldHHI, clear
							
							destring year, replace
							save ../dta/HHI/ArnoldHHI, replace
							restore
							* merge with Arnold HHI data
							sort `zone' pcs year		
							merge m:1 `zone' pcs year using ../dta/HHI/ArnoldHHI , gen(_m3)	
							keep if _m3==3
							drop _m3	
					
							* define logarithm of HHI
							ge logShare_A=log(HHI_a)
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI2_HPsircomtfuaX_pcs41	, gen(_m3)	
								drop if _m3==2
								drop _m3
								ren IV_S IV_HHI
						}						
					
						compress
						
						* redefinition of the certain fixed effects and the clustering variable (according to the correct geographical area
						if "`zone'"=="dep" {
							replace geo=nuts
							replace cluster=cluster2
						}
							if "`zone'"=="fua1" {
							replace geo=fua1_n
							replace cluster=cluster3
						}		
						
						* educ variable
						gen educ=.
						replace educ=1 if habil1==1 | habil1==2 // educ_bel_upsec
						replace educ=2 if habil1==0 | habil1==3 //educ_upsec
						replace educ=3 if habil1>=4 & habil1<=8 //educ_ab_upsec
						replace educ=. if habil1==9 | habil1==. //educ_missing
						
						/* List of interest variable and instruments
						logShare_E: log HHI
						logEmpH: log HHI based on employment
						logShare_A: log HHI based on Arnold (2021)
						Instruments:
						IV_mH based on log number of hiring firms in other regions same occupation
						IV_mE based on log number of employing firms in other regions same occupation
						IV_HHI based on log HHI in other regions same occupation 
						
						*/
						
						
						disp "*********************************************************************"
						disp "******************* REGRESSIONS *************************************"
						disp "*********************************************************************"
						
						* Model: individual, LLM, firmXmunicipalityXyear, plant and individual age fixed effects	
											
					
						
						disp "******************* OLS Model **************************************"
						
						disp "---------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.1: Labor market concentration and daily wages of full-timers – OLS estimates. -----------------------------------------------------------"
						disp "---------------------------------------------------------------------------------------------------------------------------------------------------------------"					
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH"
							reghdfe `var' ftpt Hire Emp1 logShare_E,  absorb($fixed)  cluster(cluster) 
						}					
						disp "******************* IV Models **************************************"
						
						 
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.2: Labor market concentration and daily wages of full-timers – First stage estimates. ------------------------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) first // focus on results from first stage
						}
						
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.3: Labor market concentration and daily wages of full-timers – IV estimates using the leave-one-out HHI as an instrument. ------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "IV_mH"
							ivreghdfe `var'  Hire Emp1  (logShare_E=IV_HHI),  absorb($fixed)  cluster(cluster) 
						
						}
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.4: Labor market concentration and daily wages of full-timers – HHI based on employment -----------------------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "IV_mE"
							ivreghdfe `var'  Hire Emp1 (logEmpH=IV_mE),  absorb($fixed)  cluster(cluster) 
						
						}
						
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.5: Labor market concentration and daily wages of full-timers – controlling for the ---------------------------------------------------"
						disp "-----------------------------------share of 4-digit occupations in new hires at the national level. --------------------------------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {
							
							* First, compute share of 4-digit occupations in new hires at the national level
							preserve
							use ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41, clear
							
							global Occ pcs
							global Year year
							global Hires Z_E
							
							collapse (sum) $Hires , by($Occ $Year)
							egen tot=sum($Hires) , by($Year)
							ge shocc= $Hires / tot
							keep $Occ $Year shocc
							sort  $Occ $Year
							save shocc, replace
							restore
							
							* second, merge this share with regression dataset
							preserve
							merge m:1 $Occ $Year using shocc.dta
							* third, run regressions
							
							global fixed = "id occ#geo firm#mun#an firm#nic age"
		
							disp "`var'  MODEL - control share occupations"
							disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 shocc (logShare_E=IV_mH), absorb($fixed)  cluster(cluster) 									
							restore						
						}										
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.6: Labor market concentration and daily wages of full-timers – Plausibly exogenous instrument regressions. ---------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {
							preserve
							
							global Dvar `var'
							global LHHI logShare_E
							global IV IV_mH
							global fixed "id occ#geo firm#mun#an firm#nic age ftpt Hire Emp1"
							global cluster "cluster"
							
							* reduced form
							reghdfe $Dvar $IV  , abs($fixed) cluster($cluster)  
							
							* derive minimum notional gamma (the one of the reduced form)
							global G=_b[ $IV ]
							global seG = _se[ $IV ]
							
							* partialling out key variables
							keep if $Dvar !=. & $LHHI !=. & $IV !=.
							reghdfe $Dvar 	, abs($fixed) residuals(Dvar_e)
							reghdfe $LHHI 	, abs($fixed) residuals(lhhi_e)
							reghdfe $IV 	, abs($fixed) residuals(IV_e)
							
							* using plausexog to quickly find a candidate for the minimum gamma for which beta is still significant
							scalar max = 0 
							local n = 0
							
							while `n'>$G {
								local n= `n' + ($G / 30)
								disp in ye `n'
								
								plausexog uci Dvar_e (lhhi_e= IV_e), gmin(`n') gmax(0) level(0.90) vce( cluster $cluster)
								scalar ub = e(ub_lhhi_e)
								scalar max1 = max
								scalar max= `n'
								if ub>0 {
										local n= $G - 1
										}
							}
							
							disp ub
							disp max1
							
							* refining the search for the minimum gamma for which beta is still significant
							ge Y1=.
							local n = max1
							
							while `n' <0 {
								disp "gamma = " `n'
								replace Y1 = $Dvar - ($IV * `n')
								ivreghdfe Y1 ($LHHI = $IV), abs($fixed) level(90) cluster($cluster)
								scalar ub= _b[ $LHHI ] + 1.64*_se[ $LHHI ]
								scalar gmin = `n'
								if ub<0 {
										local n=1
										}
								local n= `n' - ($G / 30)
								}
								
								* output for the table
								disp "reduced form gamma =" $G // to be reported in row (1)
								disp "standard error of reduced form gamma =" $seG // to be reported in row (1) below the gamma
								disp "min gamma =" gmin // to be reported in row (2)
								
								restore
						}							
						
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.8: Labor market concentration and daily wages of full-timers – IV estimates – Nationwide firms. --------------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="siren" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) 
						}				
				
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.9: Labor market concentration and daily wages of full-timers – IV estimates – HHI based on 2-digit occupations -----------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="2digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH_2d"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH_2d),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) 
						}				
	
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.10: Labor market concentration and daily wages of full-timers – IV estimates – Arnold's (2021) method --------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="Arnold" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mE"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_A=IV_mE),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) 
						}				

						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.11: Labor market concentration and daily wages of full-timers – IV estimates – Local labor markets based on FUAs. --------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="fua1" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) 
						}							
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						disp "------------- Table 2.12: Labor market concentration and daily wages of full-timers – IV estimates – Local labor markets based on NUTS-3 regions*. ---------"
						disp "--------------------------------------------------- * Districts in the case of Portugal --------------------------------------------------------------------"
						disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
						if "`y'"=="sircomt" &  "`zone'"=="dep" & "`hhitype'"=="4digits" {

							global fixed = "id occ#geo firm#mun#an firm#nic age"
							disp "`var' `zone' `y'"
							disp "IV_mH"
							ivreghdfe `var' ftpt Hire Emp1 (logShare_E=IV_mH),  absorb($fixed)  cluster(cluster) partial( ftpt Hire Emp1 ) 
						}						
						
					}
				}
			}
		}
}



log close
clear


set more off 

cap log c
log using ../log/Appendix2_Tables13to24.log, replace

************************************************************************************
*********************** CONTRACT REGRESSIONS - lines 437 to 770
************************************************************************************


* NEW HIRES SAMPLE

* the following big loop runs the contract regressions for
* category of hiring == 2: month/year concept 
* each different type of firm identifiers (firm, firmXmunicipality)
* each different type of geographical areas (Functional Areas, NUTS-3 (districts for PT), and FUAs)

* the macro aggregateL include the list of type of identifiers (firm or firmXmunicipality)
* the macro zoneL include the list of type of geographical areas (fuaX, dep, or fua1)
* please refer to the data construction programmes for the description of the variables

local aggregateL  sircomt siren 
local zoneL fuaX dep fua1   
local variable perm_m


foreach x of numlist 2/2 { 					// x regards type of hiring concept here (2= month/year).
		foreach zone of loc zoneL {		
			foreach y of loc aggregateL {
				foreach var of loc variable { 

					local TypeHHI  4digits 
							
					if "`y'"=="sircomt" &  "`zone'"=="fuaX"  {
							local TypeHHI  4digits 2digits Arnold // Type of HHI that is used in the regression:
							*										1) the standard in the paper (LLM: 4 digit occupations by Fuax and HHI computed using share of new hires)
							*										2) LLM defined as 2 digit occupations by Fuax ; 3) HHI computed according to Arnold (2021)
					}
					foreach hhitype of loc TypeHHI { 			

					* input data
					use precontract_compact, clear

					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					disp "HHI`x' `zone' `y'" 
					disp "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
					
					
					disp "*********************************************************************"
					disp "******************* DATA LOAD & PREPARATION: final steps ************"
					disp "*********************************************************************"
					
					*merge with presence previous year 
					if "`y'"=="siren" {
						sort nninouv sir an
						merge m:1 nninouv sir an using P1siren
						drop if _m==2
						drop _m
					}
					if "`y'"=="sircomt" {
						sort nninouv sircom sir an
						merge m:1 nninouv sircom sir an using P1sircom
						drop if _m==2
						drop _m
					}
	
					
					sort nninouv an
					merge m:1 nninouv an using P1
					drop if _m==2
					drop _m

					* generate indicators for being new hire (year and month/year definitions)	
					ge Hirem=(P1msir!=1)
					keep if Hirem==1
					* generate indicators for at work if new hire (year and month/year definitions)	
					ge Emp1=(Hirem*P1m==1)

					drop P1msir
	
					************************** merge with HHI data and instruments
						
						if "`hhitype'"=="4digits" {			// 4 digit HHI data
						*HHI
								sort `zone' pcs year			
								merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41 
								keep if _m==3
								drop _m	
								* drop useless variables
								drop nb_E EmpH Z_P0 Hmax Emax
								
								* define logarithm of HHI 
								ge logShare_E=log(Share_E)  // share of new hires
								ge logEmpH=log(EmpH)		// share of employment
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs41		
								drop if _m==2
								drop _m
								ren IV_S IV_HHI
						}
						
						if "`hhitype'"=="2digits" {			// 2 digit HHI data
						*HHI
								sort `zone' pcs year			
								merge m:1 `zone' pcs year using ../dta/HHI/HHI`x'_HP`y'`zone'_pcs2d1 	
								keep if _m==3
								drop _m
								
								* define logarithm of HHI 
								ge logShare_E=log(Share_E)  // share of new hires
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI`x'_HP`y'`zone'_pcs2d1		
								drop if _m==2
								drop _m
								ren IV_S IV_HHI
						}		
						
						if "`hhitype'"=="Arnold" {			// Arnold HHI data
						*HHI
							preserve
							use ../dta/HHI/ArnoldHHI, clear
							
							destring year, replace
							save ../dta/HHI/ArnoldHHI, replace
							restore
							* merge with Arnold HHI data
							sort `zone' pcs year		
							merge m:1 `zone' pcs year using ../dta/HHI/ArnoldHHI
							keep if _m==3
							drop _m	
					
							* define logarithm of HHI
							ge logShare_A=log(HHI_a)
						
						* Instruments
								merge m:1 `zone' pcs year using ../dta/HHI_IV/FIN_HHI2_HPsircomtfuaX_pcs41	
								drop if _m==2
								drop _m
								ren IV_S IV_HHI
						}						
					
					
					* redefine geo fixed effects and cluster variable if necessary
						if "`zone'"=="dep" {
						replace geo=nuts
						replace cluster=cluster2
					}
						if "`zone'"=="fua1" {
						replace geo=fua1_n
						replace cluster=cluster3
					}		
					recode sx(2=0) // sx=1 for men and sx =2 for women recode so that sx=0 for woman
										
				
					gen educ=.
					replace educ=1 if habil1==1 | habil1==2 // educ_bel_upsec
					replace educ=2 if habil1==0 | habil1==3 //educ_upsec
					replace educ=3 if habil1>=4 & habil1<=8 //educ_ab_upsec
					replace educ=4 if habil1==9 | habil1==. //educ_missing
																			
					/* List of interest variable and instruments
					logShare_E: log HHI
					Instruments:
					IV_mH based on log number of hiring firms in other regions same occupation
					IV_mE based on log number of employing firms in other regions same occupation
					IV_HHI based on log HHI in other regions same occupation
					*/
					
					disp "*********************************************************************"
					disp "******************* REGRESSIONS *************************************"
					disp "*********************************************************************"
					
					* Model 1: LLM, firmXmunicipalityXyear, plant and individual age, educ and gender fixed effects, plus a dummy for open-ended the year before

					rename perm perm_m
					global fixed = "occ#geo firm#mun#an firm#nic age educ"
					global EO = "Emp1"
				
					disp "************ All new hires with temp contract in June, July, August  *********************"
					global sample = "if Hirem==1&dtadm>=ym(year ,6)&dtadm<=ym(year ,8)"		
					
					
					
					
					disp "******************* OLS Model **************************************"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.13: Labor market concentration and probability of being hired on a permanent contract – OLS estimates – New hires only. --------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL 1"
					disp "OLS"
					reghdfe `var' ftpt sx logShare_E $EO  $sample , absorb($fixed)  cluster(cluster) 
					
					}
					disp "******************* IV Models **************************************"
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.14: Labor market concentration and probability of being hired on a permanent contract – IV estimates – New hires only. ------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mH"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first // focus on results from first stage
					}					
				
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.16: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "--------------------------------- IV estimates using the leave-one-out HHI as an instrument. ---------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_HHI"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_HHI) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first // focus on results from first stage
					}					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.17: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – HHI based on employment. -------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mE"
					ivreghdfe `var' sx ftpt $EO  (logEmpH=IV_mE) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) first // focus on results from first stage
					}	
					
					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.18: Labor market concentration and probability of being hired on a permanent contract – IV estimates ---------------------------------"
					disp "-------------------------------- controlling for the share of 4-digit occupations in new hires at the national level. --------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {
							
						* First, compute share of 4-digit occupations in new hires at the national level
						preserve
						use ../dta/HHI/HHI`x'_HP`y'`zone'_pcs41, clear
						
						global Occ pcs
						global Year year
						global Hires Z_E
							
						collapse (sum) $Hires , by($Occ $Year)
						egen tot=sum($Hires) , by($Year)
						ge shocc= $Hires / tot
						keep $Occ $Year shocc
						sort  $Occ $Year
						save shocc, replace
						restore
							
						* second, merge this share with regression dataset
						preserve
						merge m:1 $Occ $Year using shocc.dta
						* third, run regressions
							
	
						disp "`var'  MODEL - control share occupations"
						disp "IV_mH"
						ivreghdfe `var' sx ftpt $EO shocc (logShare_E=IV_mH) $sample , absorb($fixed)  cluster(cluster) 
						restore						
					}
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.20: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – Nationwide firms. --------------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="siren" &  "`zone'"=="fuaX" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mH"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) 
					}				
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.21: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – HHI based on 2-digit occupations. ----------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="2digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mH_2d"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH_2d) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) 
					}	
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.22: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – Arnold's (2021) method. --------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fuaX" & "`hhitype'"=="Arnold" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mE"
					ivreghdfe `var' sx ftpt $EO  (logShare_A=IV_mE) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) 
					}					
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.23: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – Local labor markets based on FUAs. ---------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="fua1" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mH"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) 
					}			
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					disp "------------- Table 2.24: Labor market concentration and probability of being hired on a permanent contract – New hires only -------------------------------"
					disp "------------------------------------------------ IV estimates – Local labor markets based on NUTS-3 regions*. -----------------------------------------------"
					disp "--------------------------------------------------- * Districts in the case of Portugal --------------------------------------------------------------------"
					disp "------------------------------------------------------------------------------------------------------------------------------------------------------------"
					if "`y'"=="sircomt" &  "`zone'"=="dep" & "`hhitype'"=="4digits" {

					disp "`var' `zone' `y' MODEL"
					disp "IV_mH"
					ivreghdfe `var' sx ftpt $EO  (logShare_E=IV_mH) $sample , 		absorb($fixed)  cluster(cluster) partial(sx ftpt $EO ) 
					}					
				}	
			}
		}
	}
}




log close
clear