
*** 3. REGRESSION ANALYSIS ***




*generate 10% random sample

use "$data\Final.dta", clear // around 100 GB

tostring prs_id, gen(digit)
gen last_digit=substr(digit,-2,2)
drop digit

destring last_digit, gen(digit)

tab digit, m

keep if inlist(digit,0,1,2,3,4,5,6,7,8,9)


drop last_digit digit

save "$data\Sample_10.dta", replace





*adjust variables for estimation


use "$data\Sample_10.dta", clear 


gen isco08_1_imp = floor(isco08_2_imp/10) 

quietly do "$prog\ISCO08-1.do"
label values isco08_1_imp isco08_1
format %50.0f isco08_1_imp

tab isco08_1_imp, m

label variable isco08_1_imp "Occupational Major Group (ISCO08-1)"





replace age = round(age,1)

gen young = (age<25)
gen old = (age>=25)


tab educ2_imp, m

tab female, m




gen skilled = .

replace skilled = 0 if inlist(educ2_imp, 1) // low education
replace skilled = 1 if inlist(educ2_imp, 2, 3) // medium or high education
replace skilled = . if inlist(educ2_imp, 0) 

label variable skilled "Skilled (0=No,1=Yes)"

label define skilled 0 "0 No" 1 "1 Yes" 
label values skilled skilled

tab skilled, m










gen ln_wage_day_imp = ln(wage_day_imp)


local varlist HHI_week_13_4_4 HHI_week_26_4_4 HHI_week_39_4_4 HHI_week_52_4_4 HHI_month_03_4_4 HHI_month_06_4_4 HHI_month_09_4_4 HHI_month_12_4_4 HHI_year_01_4_4 HHI_year_01_4_1 HHI_year_01_4_2 HHI_year_01_4_3 HHI_year_01_4_5 HHI_year_01_3_4 HHI_year_01_2_4 HHI_L_year_01_4_4 HHI_L_Arn_year_01_4_4 INS_L_Arn_year_01_4_4 
foreach x of local varlist {
    
	
	gen ln_`x' = ln(`x')
	
}




egen LM_4 = group(isco08_4_imp nuts07_3_fua_adj_work)
egen LM_1 = group(isco08_4_imp fua_work)
egen LM_5 = group(isco08_4_imp nuts07_3_fua_work)

egen LM_3_4 = group(isco08_3_imp nuts07_3_fua_adj_work)
egen LM_2_4 = group(isco08_2_imp nuts07_3_fua_adj_work)

egen LM_4_year = group(isco08_4_imp nuts07_3_fua_adj_work year)
egen LM_1_year = group(isco08_4_imp fua_work year)
egen LM_5_year = group(isco08_4_imp nuts07_3_fua_work year)

egen LM_3_4_year = group(isco08_3_imp nuts07_3_fua_adj_work year)
egen LM_2_4_year = group(isco08_2_imp nuts07_3_fua_adj_work year)




foreach x of numlist 1/6 { // regressor and instruments by CBA

	gen ln_HHI_y_01_c`x'0 = ln_HHI_year_01_4_4 * (1 - CBA_`x' ) 
	gen ln_INS_y_01_c`x'0 = ln_INS_loom_year_01_4_4 * (1 - CBA_`x' ) 
	gen ln_HHI_y_01_c`x'1 = ln_HHI_year_01_4_4 * CBA_`x'
	gen ln_INS_y_01_c`x'1 = ln_INS_loom_year_01_4_4 * CBA_`x'

}


foreach x of numlist 1/6 { // regressor and instruments by wagree

	gen ln_HHI_y_01_w`x'0 = ln_HHI_year_01_4_4 * (1 - wagree_`x' ) 
	gen ln_INS_y_01_w`x'0 = ln_INS_loom_year_01_4_4 * (1 - wagree_`x' ) 
	gen ln_HHI_y_01_w`x'1 = ln_HHI_year_01_4_4 * wagree_`x'
	gen ln_INS_y_01_w`x'1 = ln_INS_loom_year_01_4_4 * wagree_`x'

}



gen ln_HHI_y_01_b0 = ln_HHI_year_01_4_4 * (1 - wcounc )  // regressor and instruments by work council
gen ln_INS_y_01_b0 = ln_INS_loom_year_01_4_4 * (1 - wcounc ) 
gen ln_HHI_y_01_b1 = ln_HHI_year_01_4_4 * wcounc
gen ln_INS_y_01_b1 = ln_INS_loom_year_01_4_4 * wcounc


gen ln_HHI_y_01_h0 = ln_HHI_year_01_4_4 * (1 - hire_year_01 ) // regressor and instruments by hiring status
gen ln_INS_y_01_h0 = ln_INS_loom_year_01_4_4 * (1 - hire_year_01 ) 
gen ln_HHI_y_01_h1 = ln_HHI_year_01_4_4 * hire_year_01 
gen ln_INS_y_01_h1 = ln_INS_loom_year_01_4_4 * hire_year_01

gen ln_HHI_y_01_a0 = ln_HHI_year_01_4_4 * old  // regressor and instruments by age group
gen ln_INS_y_01_a0 = ln_INS_loom_year_01_4_4 * old  
gen ln_HHI_y_01_a1 = ln_HHI_year_01_4_4 * (1 - old )
gen ln_INS_y_01_a1 = ln_INS_loom_year_01_4_4 * (1 - old )

gen ln_HHI_y_01_g0 = ln_HHI_year_01_4_4 * (1 - female ) // regressor and instruments by gender
gen ln_INS_y_01_g0 = ln_INS_loom_year_01_4_4 * (1 - female ) 
gen ln_HHI_y_01_g1 = ln_HHI_year_01_4_4 * female
gen ln_INS_y_01_g1 = ln_INS_loom_year_01_4_4 * female

gen ln_HHI_y_01_s0 = ln_HHI_year_01_4_4 * (1 - skilled ) // regressor and instruments by education level
gen ln_INS_y_01_s0 = ln_INS_loom_year_01_4_4 * (1 - skilled ) 
gen ln_HHI_y_01_s1 = ln_HHI_year_01_4_4 * skilled
gen ln_INS_y_01_s1 = ln_INS_loom_year_01_4_4 * skilled


gen ln_HHI_y_01_n0 = ln_HHI_year_01_4_4 * (1 - foreign ) // regressor and instruments by nationality
gen ln_INS_y_01_n0 = ln_INS_loom_year_01_4_4 * (1 - foreign ) 
gen ln_HHI_y_01_n1 = ln_HHI_year_01_4_4 * foreign
gen ln_INS_y_01_n1 = ln_INS_loom_year_01_4_4 * foreign




rename employment_last_* emp_last_*



save "$data\Sample_10_V1.dta", replace






*** 3.1 DAILY WAGES (FOR REGULAR FULL-TIME WORKERS, 2012-2018) ***



log using "$log\Daily_Wages_10.log", replace name(Daily_Wages)


use "$data\Sample_10_V1.dta", clear

keep if regothft==1 // only regular full-time workers
drop if duration<30 // delete spells shorter than 30 days

sum wage_day_imp ln_wage_day_imp HHI_year_01_4_4 ln_HHI_year_01_4_4


gen ln_wage_day_imp_01 = .
gen ln_wage_day_imp_99 = .


foreach x of numlist 2012/2018 {

	_pctile ln_wage_day_imp if year==`x', nquantiles(100)
	return list

	global r01_wage_day = r(r1)
	di $r01_wage_day

	global r99_wage_day = r(r99)
	di $r99_wage_day

	replace ln_wage_day_imp_01 = $r01_wage_day if year==`x'
	replace ln_wage_day_imp_99 = $r99_wage_day if year==`x'

}

tabstat ln_wage_day_imp_01, by(year) statistics(min max)
tabstat ln_wage_day_imp_99, by(year) statistics(min max)


gen ln_wage_day_imp_trim = ln_wage_day_imp // trimming
replace ln_wage_day_imp_trim = . if ln_wage_day_imp<ln_wage_day_imp_01
replace ln_wage_day_imp_trim = . if ln_wage_day_imp>ln_wage_day_imp_99 & ln_wage_day_imp!=.



tab hire_year_01 emp_last_year_01, m cell


gen wage_day_imp_trim = exp(ln_wage_day_imp_trim)






*Table 1.1

sum wage_day_imp_trim // Daily Wage (Full-Timers), Full Sample: Mean = 116.3, SD = 60.46
*sum wage_day_imp_trim HHI_year_01_4_4 female age fulltime_imp educ2_imp_* hire_year_01 

sum wage_day_imp_trim if hire_year_01==1 // Daily Wage (Full-Timers), New Hires: Mean = 95.17, SD = 53.63
drop wage_day_imp_trim


*Table 2: Wages, Baseline IV

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, (3): -0.019***

count if !missing(ln_wage_day_imp_trim,ln_HHI_year_01_4_4,ln_INS_loom_year_01_4_4,hire_year_01,emp_last_year_01,prs_id,betnr,year,isco08_4_imp,nuts07_3_fua_adj_work,wz08_4_imp,age)


*Table 3: Wages, by Collective Bargaining

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 ln_HHI_y_01_w11 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_w11 ln_INS_y_01_b1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, interaction with CBA_1 dummy and work council share, Panel A. (1): -0.0224*** & 0.0112***
ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 ln_HHI_y_01_w21 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_w21 ln_INS_y_01_b1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, interaction with CBA_2 dummy and work council share, Panel A. (2): -0.0229*** & 0.0137***

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 ln_HHI_y_01_c11 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_c11 ln_INS_y_01_b1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, interaction with wagree_1 and work council share, Panel A. (2): -0.0164*** & 0.0037***
ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 ln_HHI_y_01_c21 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_c21 ln_INS_y_01_b1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, interaction with wagree_2 and work council share, Panel A. (4): -0.0161*** & 0.0044***


*Table 5: Wages, by Hiring Status

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_y_01_h0 ln_HHI_y_01_h1 = ln_INS_y_01_h0 ln_INS_y_01_h1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentiation by hiring status, (3): -0.016*** (new hire) & -0.020*** (incumbent)


*Figure 1, Panel A: Wages, by Gender

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_y_01_g0 ln_HHI_y_01_g1 = ln_INS_y_01_g0 ln_INS_y_01_g1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentiation by gender, (3): -0.020*** (male) & -0.018*** (female)


*Figure 2, Panel A: Wages, by Age Group

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_y_01_a0 ln_HHI_y_01_a1 = ln_INS_y_01_a0 ln_INS_y_01_a1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentiation by age group, (3): -0.020*** (youth) & -0.015*** (old)


*Figure 3: Wages, by Nationality

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_y_01_n0 ln_HHI_y_01_n1 = ln_INS_y_01_n0 ln_INS_y_01_n1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentiation by nationality, (3): -0.020*** (German) & -0.017*** (foreign)


*Figure 4: Wages, by Education Level

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_y_01_s0 ln_HHI_y_01_s1 = ln_INS_y_01_s0 ln_INS_y_01_s1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentiation by age group, (3): -0.016 (unskilled) & -0.020*** (skilled)


*Table 2.1: Wages, OLS					
					
reghdfe ln_wage_day_imp_trim ln_HHI_year_01_4_4 i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) vce(cluster LM_4_year) // OLS: common and non-common controls, (3): -0.0003


*Table 2.2: Wages, First-Stage Equation

reghdfe ln_HHI_year_01_4_4 ln_INS_loom_year_01_4_4  i.hire_year_01 i.emp_last_year_01 if !missing(ln_wage_day_imp_trim,ln_HHI_year_01_4_4,ln_INS_loom_year_01_4_4,hire_year_01,emp_last_year_01,prs_id,betnr,year,isco08_4_imp,nuts07_3_fua_adj_work,wz08_4_imp,age), absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) // first-stage regression for baseline IV estimation, (3): 0.726***


*Table 2.3: Wages, IV based on Leave-One-Out HHI 

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 = ln_HHI_loom_year_01_4_4 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, IV based on leave-one-out HHI, (3): -0.018***


*Table 2.4: Wages, HHI based on Employment

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_L_year_01_4_4 = ln_INS_L_loom_year_01_4_4 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, HHI based on employent (3): -0.026***


*Table 2.5: Wages, Additional 4-Digit Occupation Shares

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.hire_year_01 i.emp_last_year_01 c.share_isco08_4_ot, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, 4-digit shares, (3): -0.025***





*Table 2.6: Wages, Plausibly Exogenous Instrument Regressions

*using plausexog to quickly find a candidate for the minimum gamma for which beta is still significant

reghdfe ln_wage_day_imp_trim ln_INS_loom_year_01_4_4 i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95)   // (3): reduced-form effect: gamma_hat==-0.0141088, 
gen sample = 1 if e(sample)

global G = _b[ln_INS_loom_year_01_4_4]
global seG = _se[ln_INS_loom_year_01_4_4]

*global G = -.027124
*global seG = .0092442 

reghdfe ln_wage_day_imp_trim i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(ln_wage_day_imp_trim_e)  // save residuals conditional on fixed effects
reghdfe ln_HHI_year_01_4_4 i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(ln_HHI_year_01_4_4_e)  // save residuals conditional on fixed effects
reghdfe ln_INS_loom_year_01_4_4 i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(ln_INS_loom_year_01_4_4_e)  // save residuals conditional on fixed effects

scalar max = 0
*local n = 0
local n = ($G / 30) * 10

while `n'>$G {
	
	local n = `n' + ($G / 30)
	display in ye `n'
	
	plausexog uci ln_wage_day_imp_trim_e ( ln_HHI_year_01_4_4_e = ln_INS_loom_year_01_4_4_e ), gmin(`n') gmax(0) level(0.90) vce(cluster LM_4_year) 
	scalar ub = e(ub_ln_HHI_year_01_4_4_e)
	
	scalar max1 = max
	scalar max = `n'
	
	if ub>0 {
		
		local n = $G - 1
		
	}

}

disp ub
disp max1

*refining the search for the minimum gamma for which beta is still significant

cap drop Y1
gen Y1=.
local n = max1

while `n' < 0 {
	
	display "gamma = " `n'
	replace Y1 = ln_wage_day_imp_trim - ( ln_INS_loom_year_01_4_4 * `n' )
	ivreghdfe Y1 ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  
	scalar ub = _b[ln_HHI_year_01_4_4] + ( 1.64 * _se[ln_HHI_year_01_4_4] )
	scalar gmin = `n'
	
	if ub<0 {
		
		
		local n = 1
	}
	
	local n = `n' - ( $G / 30 )
	
}


display "reduced-form gamma = " $G // to be reported in row (1), (3): -0.0141***
display "standard error of reduced-form gamma " = $seG // to be reported in row (1) below the gamma, (3): -0.00015
display "min gamma = " gmin // to be reported in row (2), (3): -0.0113
display gmin / $G // to be reported in row (3), (3): 0.80




*Table 2.9: Wages, HHI for 2-digit Occupations

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_2_4 = ln_INS_loom_year_01_2_4 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_2_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_2_4_year) first  // IV: common and non-common controls, 2-digit, (3): -0.060***


*Table 2.10: Wages, Arnold-type HHI

rename ln_HHI_L_Arn_year_01_4_4 ln_HHI_L_Arn
rename ln_INS_L_loom_year_01_4_4 ln_INS_L_loom

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_L_Arn = ln_INS_L_loom ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, Arnold-type HHI w/o Arnold-type instrument, (3): -0.029***

rename ln_HHI_L_Arn ln_HHI_L_Arn_year_01_4_4 
rename ln_INS_L_loom ln_INS_L_loom_year_01_4_4 



*Table 2.11: Wages, FUAs only

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_1 = ln_INS_loom_year_01_4_1 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.fua_work i.wz08_4_imp i.age) cluster(LM_1_year)  first  // IV: common and non-common controls, only FUAs, (3): -0.017***


*Table 2.12: Wages, NUTS-3 Regions

ivreghdfe ln_wage_day_imp_trim ( ln_HHI_year_01_4_5 = ln_INS_loom_year_01_4_5 ) i.hire_year_01 i.emp_last_year_01, absorb(i.prs_id i.betnr#i.year i.isco08_4_imp#i.nuts07_3_adj_work i.wz08_4_imp i.age) cluster(LM_5_year)  first // IV: common and non-common controls, only 3-digit NUTS regions, (3): -0.021***





log close Daily_Wages








*** 3.2 HIRING WITH PERMANENT CONTRACT (2012-2018) ***




log using "$log\Fixed-Term_Contract_10.log", replace name(Fixed_Term_Contract)

use "$data\Sample_10_V1.dta", clear

drop if duration<30 // delete spells shorter than 30 days

*sum HHI_year_01_4_4 ln_HHI_year_01_4_4

gen fulltime_imp = 1 - parttime_imp
tab educ2_imp, m generate(educ2_imp_)


*Table 1.1

sum HHI_year_01_4_4 female age fulltime_imp educ2_imp_* hire_year_01 // see Table 1.1
sum HHI_year_01_4_4 female age fulltime_imp educ2_imp_* hire_year_01 emp_last_year_01 hire_year_01_perm if hire_year_01==1 // see Table 1.1
drop fulltime_imp educ2_imp_*

tab hire_year_01_perm, m
tab year hire_year_01_perm, m nofreq row
tab hire_year_01_perm
tab year hire_year_01_perm, nofreq row




*Table 6: Hiring on a Permanent Contract, Baseline IV

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, (2): -0.0353***

count if !missing(hire_year_01_perm,ln_HHI_year_01_4_4,ln_INS_loom_year_01_4_4,parttime_imp,female,educ2_imp,emp_last_year_01,betnr,year,isco08_4_imp,nuts07_3_fua_adj_work,wz08_4_imp,age)


*Table 8: Hiring on a Permanent Contract, By Collective Bargaining

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 ln_HHI_y_01_w21 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_w21 ln_INS_y_01_b1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first // IV: common and non-common controls, interaction with CBA_2 and work council share, Panel A (1): -0.0680*** & 0.0074

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 ln_HHI_y_01_c21 ln_HHI_y_01_b1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_c21 ln_INS_y_01_b1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first // IV: common and non-common controls, interaction with wagree_2 and work council share, Panel A (2): -0.0663*** & -0.0017


*Figure 1, Panel B: Hiring on a Permanent Contract, by Gender

*ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 ln_HHI_y_01_g1 = ln_INS_loom_year_01_4_4 ln_INS_y_01_g1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, interaction with gender (male=baseline category)
ivreghdfe hire_year_01_perm ( ln_HHI_y_01_g0 ln_HHI_y_01_g1 = ln_INS_y_01_g0 ln_INS_y_01_g1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentation by gender, (2): -0.0332*** (male) & -0.0391*** (female)


*Figure 2, Panel B: Hiring on a Permanent Contract, by Age Group

ivreghdfe hire_year_01_perm ( ln_HHI_y_01_a0 ln_HHI_y_01_a1 = ln_INS_y_01_a0 ln_INS_y_01_a1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentation by age group, (2): -0.0653*** (youth) & -0.0286*** (old)


*Figure 3: Hiring on a Permanent Contract, by Nationality

ivreghdfe hire_year_01_perm ( ln_HHI_y_01_n0 ln_HHI_y_01_n1 = ln_INS_y_01_n0 ln_INS_y_01_n1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentation by nationality, (2): -0.0362*** (German) & -0.0254*** (foreign)


*Figure 4: Hiring on a Permanent Contract, by Education Level

ivreghdfe hire_year_01_perm ( ln_HHI_y_01_s0 ln_HHI_y_01_s1 = ln_INS_y_01_s0 ln_INS_y_01_s1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, differentation by education level, (2): -0.0560*** (unskilled) & -0.0375*** (skilled)


	
*Table 2.13: Hiring on a Permanent Contract, OLS

*reghdfe hire_year_01_perm ln_HHI_year_01_4_4 i.parttime_imp, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) vce(cluster LM_4_year) // OLS: general controls
reghdfe hire_year_01_perm ln_HHI_year_01_4_4 i.parttime_imp  i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) vce(cluster LM_4_year) // OLS: common and non-common controls, (2): -0.0025**


*Table 2.14: Hiring on a Permanent Contract, First-Stage Equation

reghdfe ln_HHI_year_01_4_4 ln_INS_loom_year_01_4_4 i.parttime_imp i.female i.educ2_imp i.emp_last_year_01 if !missing(hire_year_01_perm,ln_HHI_year_01_4_4,ln_INS_loom_year_01_4_4,parttime_imp,female,educ2_imp,emp_last_year_01,betnr,year,isco08_4_imp,nuts07_3_fua_adj_work,wz08_4_imp,age), absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year)   // first-stage regression for baseline IV estimation, (2): 0.789***

		
*Table 2.16: Hiring on a Permanent Contract, IV based on Leave-One-Out HHI 

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 = ln_HHI_loom_year_01_4_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first // IV: common and non-common controls, IV based on leave-one-out HHI, (2): -0.0306***
	
	
*Table 2.17: Hiring on a Permanent Contract, HHI based on Employment

ivreghdfe hire_year_01_perm ( ln_HHI_L_year_01_4_4 = ln_INS_L_loom_year_01_4_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, HHI based on employment, (2): -0.0459***

	
*Table 2.18: Hiring on a Permanent Contract, Additional 4-Digit Occupation Shares

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01 c.share_isco08_4_ot, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, 4-digit shares, (2): -0.0334***



*Table 2.19: Hiring on a Permanent Contract, Plausibly Exogenous Instrument Regressions

*using plausexog to quickly find a candidate for the minimum gamma for which beta is still significant

reghdfe hire_year_01_perm ln_INS_loom_year_01_4_4 i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95)   // reduced-form effect: gamma_hat=-0.0278, input for paper
gen sample = 1 if e(sample)

global G = _b[ln_INS_loom_year_01_4_4]
global seG = _se[ln_INS_loom_year_01_4_4]

reghdfe hire_year_01_perm i.parttime_imp i.female i.educ2_imp i.emp_last_year_01 if sample==1, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(hire_year_01_perm_e)  // save residuals conditional on fixed effects
reghdfe ln_HHI_year_01_4_4 i.parttime_imp i.female i.educ2_imp i.emp_last_year_01 if sample==1, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(ln_HHI_year_01_4_4_e)  // save residuals conditional on fixed effects
reghdfe ln_INS_loom_year_01_4_4 i.parttime_imp i.female i.educ2_imp i.emp_last_year_01 if sample==1, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) level(95) residuals(ln_INS_loom_year_01_4_4_e)  // save residuals conditional on fixed effects


scalar max = 0
*local n = 0
local n = ($G / 30) * 10

while `n'>$G {
	
	local n = `n' + ($G / 30)
	display in ye `n'
	
	plausexog uci hire_year_01_perm_e ( ln_HHI_year_01_4_4_e = ln_INS_loom_year_01_4_4_e ), gmin(`n') gmax(0) level(0.90) vce(cluster LM_4_year) 
	scalar ub = e(ub_ln_HHI_year_01_4_4_e)
	
	scalar max1 = max
	scalar max = `n'
	
	if ub>0 {
		
		local n = $G - 1
		
	}

}

disp ub
disp max1

*refining the search for the minimum gamma for which beta is still significant

cap drop Y1
gen Y1=.
local n = max1



while `n' < 0 {
	
	display "gamma = " `n'
	replace Y1 = hire_year_01_perm - ( ln_INS_loom_year_01_4_4 * `n' )
	ivreghdfe Y1 ( ln_HHI_year_01_4_4 = ln_INS_loom_year_01_4_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first  // IV: common and non-common controls, 3-digit-occupation-by-year FE
	scalar ub = _b[ln_HHI_year_01_4_4] + ( 1.64 * _se[ln_HHI_year_01_4_4] )
	scalar gmin = `n'
	
	if ub<0 {
		
		
		local n = 1
	}
	
	local n = `n' - ( $G / 30 )
	
}


display "reduced-form gamma = " $G // to be reported in row (1), (2): -0.0278***
display "standard error of reduced-form gamma " = $seG // to be reported in row (1) below the gamma, (2): 0.0093
display "min gamma = " gmin // to be reported in row (2), (2): -0.0121
display gmin / $G // to be reported in row (3), (2): 0.4333




*Table 2.21: Hiring on a Permanent Contract, HHI for 2-digit Occupations

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_2_4 = ln_INS_loom_year_01_2_4 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_2_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_2_4_year) first  // IV: common and non-common controls, 2-digit, (2): -0.1258***


*Table 2.22: Hiring on a Permanent Contract, Arnold-type HHI 

rename ln_HHI_L_Arn_year_01_4_4 ln_HHI_L_Arn
rename ln_INS_L_loom_year_01_4_4 ln_INS_L_loom

ivreghdfe hire_year_01_perm ( ln_HHI_L_Arn = ln_INS_L_loom ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_fua_adj_work i.wz08_4_imp i.age) cluster(LM_4_year) first // IV: common and non-common controls, Arnold-type HHI w/o Arnold-type instrument, with 2018, (2): -0.0525***

rename ln_HHI_L_Arn ln_HHI_L_Arn_year_01_4_4 
rename ln_INS_L_loom ln_INS_L_loom_year_01_4_4 



*Table 2.23: Hiring on a Permanent Contract, FUAs only

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_1 = ln_INS_loom_year_01_4_1 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.fua_work i.wz08_4_imp i.age) cluster(LM_1_year) first  // IV: common and non-common controls, only FUAs, (2): -0.0347***


*Table 2.24: Hiring on a Permanent Contract, NUTS-3 Regions

ivreghdfe hire_year_01_perm ( ln_HHI_year_01_4_5 = ln_INS_loom_year_01_4_5 ) i.parttime_imp i.female i.educ2_imp i.emp_last_year_01, absorb(i.betnr#i.year i.isco08_4_imp#i.nuts07_3_adj_work i.wz08_4_imp i.age) cluster(LM_5_year) first  // IV: common and non-common controls, only 3-digit NUTS regions, (2): -0.0401***



log close Fixed_Term_Contract











*** 3.3 NUMBER OF OCCUPATIONS PER FIRM-BY-MUNICIPALITY COUPLE ***




log using "$log\Number_of_Occupations.log", replace name(Occupations)




*in the next 3 lines, include the name of your variables as indicated
global occ isco08_4_imp // replace OO with the varname of your occupation variable
global sircom betnr // replace SS with the varname containing firmXmunicipality identifiers 
global year year // replace TT with the varname containing years




use "$data\Sample_10_V1.dta", clear

drop if duration<30 // delete spells shorter than 30 days





*computing number of occupations at the firmXmunicipality-by-year level

preserve

	gen one=1
	collapse (count) one, by($occ $sircom $year)
	duplicates tag $sircom $year, gen(numb_occ) 
	replace numb_occ=numb_occ+1
	drop one
	sort $occ $sircom $year
	save "$data\numb_occ.dta", replace
	
restore


*calculating the mean over the distribution of individual observation

sort $occ $sircom $year
merge m:1 $occ $sircom $year using "$data\numb_occ.dta"
drop if _merge==2
drop _merge
sum numb_occ

* this is the mean
disp "mean number of occupations: " r(mean) // Footnote 18: 9.1
disp "std number of occupations: " r(sd) // 13.5




log close Occupations









